@@ -1,6 +1,6 @@
 /*  altairz80_dsk.c: MITS Altair 88-DISK Simulator
 
-    Copyright (c) 2002-2007, Peter Schorn
+    Copyright (c) 2002-2008, Peter Schorn
 
     Permission is hereby granted, free of charge, to any person obtaining a
     copy of this software and associated documentation files (the "Software"),
@@ -14,7 +14,7 @@
 
     THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
     IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
+    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
     PETER SCHORN BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
     IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
     CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
@@ -109,55 +109,55 @@
 */
 
 #include "altairz80_defs.h"
+#include <assert.h>
 
-#define UNIT_V_DSKWLK       (UNIT_V_UF + 0)         /* write locked                             */
-#define UNIT_DSKWLK         (1 << UNIT_V_DSKWLK)
-#define UNIT_V_DSK_VERBOSE  (UNIT_V_UF + 1)         /* verbose mode, i.e. show error messages   */
-#define UNIT_DSK_VERBOSE    (1 << UNIT_V_DSK_VERBOSE)
+/* Debug flags */
+#define IN_MSG              (1 << 0)
+#define OUT_MSG             (1 << 1)
+#define READ_MSG            (1 << 2)
+#define WRITE_MSG           (1 << 3)
+#define SECTOR_STUCK_MSG    (1 << 4)
+#define TRACK_STUCK_MSG     (1 << 5)
+#define VERBOSE_MSG         (1 << 6)
+
+#define UNIT_V_DSK_WLK      (UNIT_V_UF + 0)         /* write locked                             */
+#define UNIT_DSK_WLK        (1 << UNIT_V_DSK_WLK)
 #define DSK_SECTSIZE        137                     /* size of sector                           */
 #define DSK_SECT            32                      /* sectors per track                        */
 #define MAX_TRACKS          254                     /* number of tracks,
                                                     original Altair has 77 tracks only          */
 #define DSK_TRACSIZE        (DSK_SECTSIZE * DSK_SECT)
 #define MAX_DSK_SIZE        (DSK_TRACSIZE * MAX_TRACKS)
-#define TRACE_IN_OUT        1
-#define TRACE_READ_WRITE    2
-#define TRACE_SECTOR_STUCK  4
-#define TRACE_TRACK_STUCK   8
 #define NUM_OF_DSK_MASK     (NUM_OF_DSK - 1)
+#define BOOTROM_SIZE_DSK    256                     /* size of boot rom                         */
+
 
 int32 dsk10(const int32 port, const int32 io, const int32 data);
 int32 dsk11(const int32 port, const int32 io, const int32 data);
 int32 dsk12(const int32 port, const int32 io, const int32 data);
-static int32 dskseek(const UNIT *xptr);
 static t_stat dsk_boot(int32 unitno, DEVICE *dptr);
 static t_stat dsk_reset(DEVICE *dptr);
-static void writebuf(void);
-static t_stat dsk_set_verbose(UNIT *uptr, int32 value, char *cptr, void *desc);
-static void resetDSKWarningFlags(void);
-static int32 hasVerbose(void);
-static char* selectInOut(const int32 io);
 
-extern int32 PCX;
-extern int32 saved_PC;
-extern FILE *sim_log;
-extern char messageBuffer[];
+extern REG *sim_PC;
 extern UNIT cpu_unit;
+extern uint32 PCX;
 
-extern void printMessage(void);
-extern int32 install_bootrom(void);
+extern t_stat install_bootrom(int32 bootrom[], int32 size, int32 addr, int32 makeROM);
+extern uint32 sim_map_resource(uint32 baseaddr, uint32 size, uint32 resource_type,
+                               int32 (*routine)(const int32, const int32, const int32), uint8 unmap);
+void install_ALTAIRbootROM(void);
 
 /* global data on status */
 
-static int32 current_disk       = NUM_OF_DSK;       /* currently selected drive (values are 0 .. NUM_OF_DSK)
-    current_disk < NUM_OF_DSK implies that the corresponding disk is attached to a file */
+/* currently selected drive (values are 0 .. NUM_OF_DSK)
+   current_disk < NUM_OF_DSK implies that the corresponding disk is attached to a file */
+static int32 current_disk                   = NUM_OF_DSK;
 static int32 current_track  [NUM_OF_DSK]    = {0, 0, 0, 0, 0, 0, 0, 0};
 static int32 current_sector [NUM_OF_DSK]    = {0, 0, 0, 0, 0, 0, 0, 0};
 static int32 current_byte   [NUM_OF_DSK]    = {0, 0, 0, 0, 0, 0, 0, 0};
 static int32 current_flag   [NUM_OF_DSK]    = {0, 0, 0, 0, 0, 0, 0, 0};
 static uint8 tracks         [NUM_OF_DSK]    = { MAX_TRACKS, MAX_TRACKS, MAX_TRACKS, MAX_TRACKS,
                                                 MAX_TRACKS, MAX_TRACKS, MAX_TRACKS, MAX_TRACKS };
-static int32 trace_flag                     = 0;
 static int32 in9_count                      = 0;
 static int32 in9_message                    = FALSE;
 static int32 dirty                          = FALSE;    /* TRUE when buffer has unwritten data in it    */
@@ -170,7 +170,7 @@ static int32 warnDSK12                      = 0;
 static int8 dskbuf[DSK_SECTSIZE];                       /* data Buffer                                  */
 
 /* Altair MITS modified BOOT EPROM, fits in upper 256 byte of memory */
-int32 bootrom[BOOTROM_SIZE] = {
+int32 bootrom_dsk[BOOTROM_SIZE_DSK] = {
     0xf3, 0x06, 0x80, 0x3e, 0x0e, 0xd3, 0xfe, 0x05, /* ff00-ff07 */
     0xc2, 0x05, 0xff, 0x3e, 0x16, 0xd3, 0xfe, 0x3e, /* ff08-ff0f */
     0x12, 0xd3, 0xfe, 0xdb, 0xfe, 0xb7, 0xca, 0x20, /* ff10-ff17 */
@@ -225,7 +225,6 @@ static REG dsk_reg[] = {
     { BRDATA (CURBYTE,      current_byte,   10, 32, NUM_OF_DSK),    REG_CIRC + REG_RO   },
     { BRDATA (CURFLAG,      current_flag,   10, 32, NUM_OF_DSK),    REG_CIRC + REG_RO   },
     { BRDATA (TRACKS,       tracks,         10, 8,  NUM_OF_DSK),    REG_CIRC            },
-    { ORDATA (TRACE,        trace_flag, 8)                                              },
     { DRDATA (IN9COUNT,     in9_count, 4),                          REG_RO              },
     { DRDATA (IN9MESSAGE,   in9_message, 4),                        REG_RO              },
     { DRDATA (DIRTY,        dirty, 4),                              REG_RO              },
@@ -240,51 +239,36 @@ static REG dsk_reg[] = {
 };
 
 static MTAB dsk_mod[] = {
-    { UNIT_DSKWLK,      0,                  "write enabled",    "WRITEENABLED", NULL                },
-    { UNIT_DSKWLK,      UNIT_DSKWLK,        "write locked",     "LOCKED",       NULL                },
-    /* quiet, no warning messages           */
-    { UNIT_DSK_VERBOSE, 0,                  "QUIET",            "QUIET",        NULL                },
-    /* verbose, show warning messages   */
-    { UNIT_DSK_VERBOSE, UNIT_DSK_VERBOSE,   "VERBOSE",          "VERBOSE",      &dsk_set_verbose    },
+    { UNIT_DSK_WLK,     0,                  "WRTENB",    "WRTENB",  NULL                },
+    { UNIT_DSK_WLK,     UNIT_DSK_WLK,       "WRTLCK",    "WRTLCK",  NULL                },
     { 0 }
 };
 
+#define TRACE_PRINT(level, args)    if (dsk_dev.dctrl & level) {    \
+                                        printf args;                \
+                                    }
+
+/* Debug Flags */
+static DEBTAB dsk_dt[] = {
+    { "IN",             IN_MSG              },
+    { "OUT",            OUT_MSG             },
+    { "READ",           READ_MSG            },
+    { "WRITE",          WRITE_MSG           },
+    { "SECTOR_STUCK",   SECTOR_STUCK_MSG    },
+    { "TRACK_STUCK",    TRACK_STUCK_MSG     },
+    { "VERBOSE",        VERBOSE_MSG         },
+    { NULL,             0                   }
+};
+
 DEVICE dsk_dev = {
     "DSK", dsk_unit, dsk_reg, dsk_mod,
     8, 10, 31, 1, 8, 8,
     NULL, NULL, &dsk_reset,
     &dsk_boot, NULL, NULL,
-    NULL, 0, 0,
-    NULL, NULL, NULL
+    NULL, (DEV_DISABLE | DEV_DEBUG), 0,
+    dsk_dt, NULL, "Altair Floppy Disk DSK"
 };
 
-static void resetDSKWarningFlags(void) {
-    int32 i;
-    for (i = 0; i < NUM_OF_DSK; i++) {
-        warnLock[i]         = 0;
-        warnAttached[i]     = 0;
-    }
-    warnDSK10 = 0;
-    warnDSK11 = 0;
-    warnDSK12 = 0;
-}
-
-static t_stat dsk_set_verbose(UNIT *uptr, int32 value, char *cptr, void *desc) {
-    resetDSKWarningFlags();
-    return SCPE_OK;
-}
-
-/* returns TRUE iff there exists a disk with VERBOSE */
-static int32 hasVerbose(void) {
-    int32 i;
-    for (i = 0; i < NUM_OF_DSK; i++) {
-        if (((dsk_dev.units + i) -> flags) & UNIT_DSK_VERBOSE) {
-            return TRUE;
-        }
-    }
-    return FALSE;
-}
-
 static char* selectInOut(const int32 io) {
     return io == 0 ? "IN" : "OUT";
 }
@@ -293,36 +277,84 @@ static char* selectInOut(const int32 io) {
 /* reset routine */
 
 static t_stat dsk_reset(DEVICE *dptr) {
-    resetDSKWarningFlags();
+    int32 i;
+    for (i = 0; i < NUM_OF_DSK; i++) {
+        warnLock[i]     = 0;
+        warnAttached[i] = 0;
+    }
+    warnDSK10       = 0;
+    warnDSK11       = 0;
+    warnDSK12       = 0;
     current_disk    = NUM_OF_DSK;
-    trace_flag      = 0;
     in9_count       = 0;
     in9_message     = FALSE;
+    sim_map_resource(0x08, 1, RESOURCE_TYPE_IO, &dsk10, dptr->flags & DEV_DIS);
+    sim_map_resource(0x09, 1, RESOURCE_TYPE_IO, &dsk11, dptr->flags & DEV_DIS);
+    sim_map_resource(0x0A, 1, RESOURCE_TYPE_IO, &dsk12, dptr->flags & DEV_DIS);
     return SCPE_OK;
 }
 
+void install_ALTAIRbootROM(void) {
+    assert(install_bootrom(bootrom_dsk, BOOTROM_SIZE_DSK, ALTAIR_ROM_LOW, TRUE) == SCPE_OK);
+}
+
 /*  The boot routine modifies the boot ROM in such a way that subsequently
     the specified disk is used for boot purposes.
 */
 static t_stat dsk_boot(int32 unitno, DEVICE *dptr) {
-    if (cpu_unit.flags & (UNIT_ALTAIRROM | UNIT_BANKED)) {
-        if (install_bootrom()) {
-            printf("ALTAIR boot ROM installed.\n");
-        }
+    if (cpu_unit.flags & (UNIT_CPU_ALTAIRROM | UNIT_CPU_BANKED)) {
         /* check whether we are really modifying an LD A,<> instruction */
-        if ((bootrom[UNIT_NO_OFFSET_1 - 1] == LDA_INSTRUCTION) && (bootrom[UNIT_NO_OFFSET_2 - 1] == LDA_INSTRUCTION)) {
-            bootrom[UNIT_NO_OFFSET_1] = unitno & 0xff;                     /* LD A,<unitno>                */
-            bootrom[UNIT_NO_OFFSET_2] = 0x80 | (unitno & 0xff);    /* LD a,80h | <unitno>  */
+        if ((bootrom_dsk[UNIT_NO_OFFSET_1 - 1] == LDA_INSTRUCTION) && (bootrom_dsk[UNIT_NO_OFFSET_2 - 1] == LDA_INSTRUCTION)) {
+            bootrom_dsk[UNIT_NO_OFFSET_1] = unitno & 0xff;             /* LD A,<unitno>        */
+            bootrom_dsk[UNIT_NO_OFFSET_2] = 0x80 | (unitno & 0xff);    /* LD a,80h | <unitno>  */
         }
         else { /* Attempt to modify non LD A,<> instructions is refused. */
             printf("Incorrect boot ROM offsets detected.\n");
             return SCPE_IERR;
         }
+        install_ALTAIRbootROM();                                         /* install modified ROM */
     }
-    saved_PC = DEFAULT_ROM_LOW;
+    *((int32 *) sim_PC->loc) = ALTAIR_ROM_LOW;
     return SCPE_OK;
 }
 
+static int32 dskseek(const UNIT *xptr) {
+    return fseek(xptr -> fileref, DSK_TRACSIZE * current_track[current_disk] +
+        DSK_SECTSIZE * current_sector[current_disk], SEEK_SET);
+}
+
+/* precondition: current_disk < NUM_OF_DSK */
+static void writebuf(void) {
+    int32 i, rtn;
+    UNIT *uptr;
+    i = current_byte[current_disk];         /* null-fill rest of sector if any */
+    while (i < DSK_SECTSIZE)
+        dskbuf[i++] = 0;
+    uptr = dsk_dev.units + current_disk;
+    if (((uptr -> flags) & UNIT_DSK_WLK) == 0) { /* write enabled */
+        TRACE_PRINT(WRITE_MSG, ("DSK%i: " ADDRESS_FORMAT " OUT 0x0a (WRITE) D%d T%d S%d" NLP, current_disk, PCX,
+                                current_disk, current_track[current_disk], current_sector[current_disk]));
+        if (dskseek(uptr)) {
+            printf("DSK%i: " ADDRESS_FORMAT " fseek failed D%d T%d S%d" NLP, current_disk,
+                   PCX, current_disk, current_track[current_disk], current_sector[current_disk]);
+        }
+        rtn = fwrite(dskbuf, DSK_SECTSIZE, 1, uptr -> fileref);
+        if (rtn != 1) {
+            printf("DSK%i: " ADDRESS_FORMAT " fwrite failed T%d S%d Return=%d" NLP, current_disk,
+                   PCX, current_track[current_disk], current_sector[current_disk], rtn);
+        }
+    }
+    else if ( (dsk_dev.dctrl & VERBOSE_MSG) && (warnLock[current_disk] < warnLevelDSK) ) {
+        /* write locked - print warning message if required */
+        warnLock[current_disk]++;
+/*05*/  printf("DSK%i: " ADDRESS_FORMAT " Attempt to write to locked DSK%d - ignored." NLP,
+                current_disk, PCX, current_disk);
+    }
+    current_flag[current_disk]  &= 0xfe;    /* ENWD off */
+    current_byte[current_disk]  = 0xff;
+    dirty                       = FALSE;
+}
+
 /*  I/O instruction handlers, called from the CPU module when an
     IN or OUT instruction is issued.
 
@@ -347,9 +379,10 @@ int32 dsk10(const int32 port, const int32 io, const int32 data) {
     in9_count = 0;
     if (io == 0) {                                      /* IN: return flags */
         if (current_disk >= NUM_OF_DSK) {
-            if (hasVerbose() && (warnDSK10 < warnLevelDSK)) {
+            if ((dsk_dev.dctrl & VERBOSE_MSG) && (warnDSK10 < warnLevelDSK)) {
                 warnDSK10++;
-/*01*/          MESSAGE_1("Attempt of IN 0x08 on unattached disk - ignored.");
+/*01*/          printf("DSK%i: " ADDRESS_FORMAT " Attempt of IN 0x08 on unattached disk - ignored." NLP,
+                        current_disk, PCX);
             }
             return 0xff;                                /* no drive selected - can do nothing */
         }
@@ -357,18 +390,16 @@ int32 dsk10(const int32 port, const int32 io, const int32 data) {
     }
 
     /* OUT: Controller set/reset/enable/disable */
-    if (dirty) {    /* implies that current_disk < NUM_OF_DSK */
+    if (dirty)    /* implies that current_disk < NUM_OF_DSK */
         writebuf();
-    }
-    if (trace_flag & TRACE_IN_OUT) {
-        MESSAGE_2("OUT 0x08: %x", data);
-    }
+    TRACE_PRINT(OUT_MSG, ("DSK%i: " ADDRESS_FORMAT " OUT 0x08: %x" NLP, current_disk, PCX, data));
     current_disk = data & NUM_OF_DSK_MASK; /* 0 <= current_disk < NUM_OF_DSK */
     current_disk_flags = (dsk_dev.units + current_disk) -> flags;
     if ((current_disk_flags & UNIT_ATT) == 0) { /* nothing attached? */
-        if ( (current_disk_flags & UNIT_DSK_VERBOSE) && (warnAttached[current_disk] < warnLevelDSK) ) {
+        if ( (dsk_dev.dctrl & VERBOSE_MSG) && (warnAttached[current_disk] < warnLevelDSK) ) {
             warnAttached[current_disk]++;
-/*02*/MESSAGE_2("Attempt to select unattached DSK%d - ignored.", current_disk);
+/*02*/      printf("DSK%i: " ADDRESS_FORMAT " Attempt to select unattached DSK%d - ignored." NLP,
+                    current_disk, PCX, current_disk);
         }
         current_disk = NUM_OF_DSK;
     }
@@ -386,9 +417,10 @@ int32 dsk10(const int32 port, const int32 io, const int32 data) {
 
 int32 dsk11(const int32 port, const int32 io, const int32 data) {
     if (current_disk >= NUM_OF_DSK) {
-        if (hasVerbose() && (warnDSK11 < warnLevelDSK)) {
+        if ((dsk_dev.dctrl & VERBOSE_MSG) && (warnDSK11 < warnLevelDSK)) {
             warnDSK11++;
-/*03*/      MESSAGE_2("Attempt of %s 0x09 on unattached disk - ignored.", selectInOut(io));
+/*03*/      printf("DSK%i: " ADDRESS_FORMAT " Attempt of %s 0x09 on unattached disk - ignored." NLP,
+                 current_disk, PCX, selectInOut(io));
         }
         return 0;               /* no drive selected - can do nothing */
     }
@@ -396,73 +428,60 @@ int32 dsk11(const int32 port, const int32 io, const int32 data) {
     /* now current_disk < NUM_OF_DSK */
     if (io == 0) {  /* read sector position */
         in9_count++;
-        if ((trace_flag & TRACE_SECTOR_STUCK) && (in9_count > 2 * DSK_SECT) && (!in9_message)) {
+        if ((dsk_dev.dctrl & SECTOR_STUCK_MSG) && (in9_count > 2 * DSK_SECT) && (!in9_message)) {
             in9_message = TRUE;
-            MESSAGE_2("Looping on sector find %d.", current_disk);
+            printf("DSK%i: " ADDRESS_FORMAT " Looping on sector find." NLP,
+                    current_disk, PCX);
         }
-        if (trace_flag & TRACE_IN_OUT) {
-            MESSAGE_1("IN 0x09");
-        }
-        if (dirty) {/* implies that current_disk < NUM_OF_DSK */
+        TRACE_PRINT(IN_MSG, ("DSK%i: " ADDRESS_FORMAT " IN 0x09" NLP,  current_disk, PCX));
+        if (dirty)  /* implies that current_disk < NUM_OF_DSK */
             writebuf();
-        }
         if (current_flag[current_disk] & 0x04) {    /* head loaded? */
             current_sector[current_disk]++;
-            if (current_sector[current_disk] >= DSK_SECT) {
+            if (current_sector[current_disk] >= DSK_SECT)
                 current_sector[current_disk] = 0;
-            }
             current_byte[current_disk] = 0xff;
             return (((current_sector[current_disk] << 1) & 0x3e)    /* return 'sector true' bit = 0 (true) */
                 | 0xc0);                                            /* set on 'unused' bits */
-        } else {
+        } else
             return 0;                                               /* head not loaded - return 0 */
-        }
     }
 
     in9_count = 0;
     /* drive functions */
 
-    if (trace_flag & TRACE_IN_OUT) {
-        MESSAGE_2("OUT 0x09: %x", data);
-    }
+    TRACE_PRINT(OUT_MSG, ("DSK%i: " ADDRESS_FORMAT " OUT 0x09: %x" NLP, current_disk, PCX, data));
     if (data & 0x01) {      /* step head in                             */
-        if (trace_flag & TRACE_TRACK_STUCK) {
-            if (current_track[current_disk] == (tracks[current_disk] - 1)) {
-                MESSAGE_2("Unnecessary step in for disk %d", current_disk);
-            }
+        if ((dsk_dev.dctrl & TRACK_STUCK_MSG) && (current_track[current_disk] == (tracks[current_disk] - 1))) {
+            printf("DSK%i: " ADDRESS_FORMAT " Unnecessary step in." NLP,
+                    current_disk, PCX);
         }
         current_track[current_disk]++;
-        if (current_track[current_disk] > (tracks[current_disk] - 1)) {
+        if (current_track[current_disk] > (tracks[current_disk] - 1))
             current_track[current_disk] = (tracks[current_disk] - 1);
-        }
-        if (dirty) {        /* implies that current_disk < NUM_OF_DSK   */
+        if (dirty)          /* implies that current_disk < NUM_OF_DSK   */
             writebuf();
-        }
         current_sector[current_disk]    = 0xff;
         current_byte[current_disk]      = 0xff;
     }
 
     if (data & 0x02) {      /* step head out                            */
-        if (trace_flag & TRACE_TRACK_STUCK) {
-            if (current_track[current_disk] == 0) {
-                MESSAGE_2("Unnecessary step out for disk %d", current_disk);
-            }
+        if ((dsk_dev.dctrl & TRACK_STUCK_MSG) && (current_track[current_disk] == 0)) {
+           printf("DSK%i: " ADDRESS_FORMAT " Unnecessary step out." NLP, current_disk, PCX);
         }
         current_track[current_disk]--;
         if (current_track[current_disk] < 0) {
             current_track[current_disk] = 0;
             current_flag[current_disk] |= 0x40; /* track 0 if there     */
         }
-        if (dirty) {        /* implies that current_disk < NUM_OF_DSK   */
+        if (dirty)          /* implies that current_disk < NUM_OF_DSK   */
             writebuf();
-        }
         current_sector[current_disk]    = 0xff;
         current_byte[current_disk]      = 0xff;
     }
 
-    if (dirty) {            /* implies that current_disk < NUM_OF_DSK   */
+    if (dirty)              /* implies that current_disk < NUM_OF_DSK   */
         writebuf();
-    }
 
     if (data & 0x04) {      /* head load                                */
         current_flag[current_disk] |= 0x04;         /* turn on head loaded bit          */
@@ -487,19 +506,15 @@ int32 dsk11(const int32 port, const int32 io, const int32 data) {
 
 /* Disk Data In/Out */
 
-static int32 dskseek(const UNIT *xptr) {
-    return fseek(xptr -> fileref, DSK_TRACSIZE * current_track[current_disk] +
-        DSK_SECTSIZE * current_sector[current_disk], SEEK_SET);
-}
-
 int32 dsk12(const int32 port, const int32 io, const int32 data) {
     int32 i;
     UNIT *uptr;
 
     if (current_disk >= NUM_OF_DSK) {
-        if (hasVerbose() && (warnDSK12 < warnLevelDSK)) {
+        if ((dsk_dev.dctrl & VERBOSE_MSG) && (warnDSK12 < warnLevelDSK)) {
             warnDSK12++;
-/*04*/      MESSAGE_2("Attempt of %s 0x0a on unattached disk - ignored.", selectInOut(io));
+/*04*/      printf("DSK%i: " ADDRESS_FORMAT " Attempt of %s 0x0a on unattached disk - ignored." NLP,
+                    current_disk, PCX, selectInOut(io));
         }
         return 0;
     }
@@ -510,12 +525,11 @@ int32 dsk12(const int32 port, const int32 io, const int32 data) {
     if (io == 0) {
         if (current_byte[current_disk] >= DSK_SECTSIZE) {
             /* physically read the sector */
-            if (trace_flag & TRACE_READ_WRITE) {
-                MESSAGE_4("IN 0x0a (READ) D%d T%d S%d", current_disk, current_track[current_disk], current_sector[current_disk]);
-            }
-            for (i = 0; i < DSK_SECTSIZE; i++) {
+            TRACE_PRINT(READ_MSG,
+                        ("DSK%i: " ADDRESS_FORMAT " IN 0x0a (READ) D%d T%d S%d" NLP, current_disk,
+                         PCX, current_disk, current_track[current_disk], current_sector[current_disk]));
+            for (i = 0; i < DSK_SECTSIZE; i++)
                 dskbuf[i] = 0;
-            }
             dskseek(uptr);
             fread(dskbuf, DSK_SECTSIZE, 1, uptr -> fileref);
             current_byte[current_disk] = 0;
@@ -523,9 +537,8 @@ int32 dsk12(const int32 port, const int32 io, const int32 data) {
         return dskbuf[current_byte[current_disk]++] & 0xff;
     }
     else {
-        if (current_byte[current_disk] >= DSK_SECTSIZE) {
+        if (current_byte[current_disk] >= DSK_SECTSIZE)
             writebuf();     /* from above we have that current_disk < NUM_OF_DSK */
-        }
         else {
             dirty = TRUE;   /* this guarantees for the next call to writebuf that current_disk < NUM_OF_DSK */
             dskbuf[current_byte[current_disk]++] = data & 0xff;
@@ -533,34 +546,3 @@ int32 dsk12(const int32 port, const int32 io, const int32 data) {
         return 0;   /* ignored since OUT */
     }
 }
-
-/* precondition: current_disk < NUM_OF_DSK */
-static void writebuf(void) {
-    int32 i, rtn;
-    UNIT *uptr;
-    i = current_byte[current_disk];         /* null-fill rest of sector if any */
-    while (i < DSK_SECTSIZE) {
-        dskbuf[i++] = 0;
-    }
-    uptr = dsk_dev.units + current_disk;
-    if (((uptr -> flags) & UNIT_DSKWLK) == 0) { /* write enabled */
-        if (trace_flag & TRACE_READ_WRITE) {
-            MESSAGE_4("OUT 0x0a (WRITE) D%d T%d S%d", current_disk, current_track[current_disk], current_sector[current_disk]);
-        }
-        if (dskseek(uptr)) {
-            MESSAGE_4("fseek failed D%d T%d S%d", current_disk, current_track[current_disk], current_sector[current_disk]);
-        }
-        rtn = fwrite(dskbuf, DSK_SECTSIZE, 1, uptr -> fileref);
-        if (rtn != 1) {
-            MESSAGE_4("fwrite failed T%d S%d Return=%d", current_track[current_disk], current_sector[current_disk], rtn);
-        }
-    }
-    else if ( ((uptr -> flags) & UNIT_DSK_VERBOSE) && (warnLock[current_disk] < warnLevelDSK) ) {
-        /* write locked - print warning message if required */
-        warnLock[current_disk]++;
-/*05*/  MESSAGE_2("Attempt to write to locked DSK%d - ignored.", current_disk);
-    }
-    current_flag[current_disk]  &= 0xfe;    /* ENWD off */
-    current_byte[current_disk]  = 0xff;
-    dirty                       = FALSE;
-}
