@@ -1,6 +1,6 @@
 /* hp2100_cpu3.c: HP 2100/1000 FFP/DBI instructions
 
-   Copyright (c) 2005-2006, J. David Bryan
+   Copyright (c) 2005-2008, J. David Bryan
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -25,6 +25,12 @@
 
    CPU3         Fast FORTRAN and Double Integer instructions
 
+   11-Sep-08    JDB     Moved microcode function prototypes to hp2100_cpu1.h
+   05-Sep-08    JDB     Removed option-present tests (now in UIG dispatchers)
+   05-Aug-08    JDB     Updated mp_dms_jmp calling sequence
+   27-Feb-08    JDB     Added DBI self-test instruction
+   23-Oct-07    JDB     Fixed unsigned-divide bug in .DDI
+   17-Oct-07    JDB     Fixed unsigned-multiply bug in .DMP
    16-Oct-06    JDB     Calls FPP for extended-precision math
    12-Oct-06    JDB     Altered DBLE, DDINT for F-Series FFP compatibility
    26-Sep-06    JDB     Moved from hp2100_cpu1.c to simplify extensions
@@ -54,10 +60,6 @@
 #endif                                                  /* end of int64 support */
 
 
-t_stat cpu_ffp (uint32 IR, uint32 intrq);               /* Fast FORTRAN Processor */
-t_stat cpu_dbi (uint32 IR, uint32 intrq);               /* Double-Integer instructions */
-
-
 /* Fast FORTRAN Processor.
 
    The Fast FORTRAN Processor (FFP) is a set of FORTRAN language accelerators
@@ -105,37 +107,38 @@ t_stat cpu_dbi (uint32 IR, uint32 intrq);               /* Double-Integer instru
    almost all use .ENTR.  Supporting the latter even on systems that do not
    support the former still allows such systems to boot.
 
-   Notes:
+   Implementation notes:
 
-     1. The "$SETP" instruction is sometimes listed as ".SETP" in the
-        documentation.
+    1. The "$SETP" instruction is sometimes listed as ".SETP" in the
+       documentation.
 
-     2. Extended-precision arithmetic routines (e.g., .XMPY) exist on the
-        1000-F, but they are assigned instruction codes in the single-precision
-        floating-point module range.  They are replaced by several double
-        integer instructions, which we dispatch to the double integer handler.
+    2. Extended-precision arithmetic routines (e.g., .XMPY) exist on the 1000-F,
+       but they are assigned instruction codes in the single-precision
+       floating-point module range.  They are replaced by several double integer
+       instructions, which we dispatch to the double integer handler.
 
-     3. The software implementation of ..MAP supports 1-, 2-, or 3-dimensional
-        arrays, designated by setting A = -1, 0, and +1, respectively.  The
-        firmware implementation supports only 2- and 3-dimensional access.
+    3. The software implementation of ..MAP supports 1-, 2-, or 3-dimensional
+       arrays, designated by setting A = -1, 0, and +1, respectively.  The
+       firmware implementation supports only 2- and 3-dimensional access.
 
-     4. The documentation for ..MAP for the 2100 FFP shows A = 0 or -1 for two
-        or three dimensions, respectively, but the 1000 FFP shows A = 0 or +1.
-        The firmware actually only checks the LSB of A.
+    4. The documentation for ..MAP for the 2100 FFP shows A = 0 or -1 for two or
+       three dimensions, respectively, but the 1000 FFP shows A = 0 or +1.  The
+       firmware actually only checks the LSB of A.
 
-     5. The .DFER and .XFER implementations for the 2100 FFP return X+4 and Y+4
-        in the A and B registers, whereas the 1000 FFP returns X+3 and Y+3.
+    5. The .DFER and .XFER implementations for the 2100 FFP return X+4 and Y+4
+       in the A and B registers, whereas the 1000 FFP returns X+3 and Y+3.
 
-     6. The .XFER implementation for the 2100 FFP returns to P+2, whereas the
-        1000 implementation returns to P+1.
+    6. The .XFER implementation for the 2100 FFP returns to P+2, whereas the
+       1000 implementation returns to P+1.
 
-     7. The firmware implementations of DBLE, .BLE, and DDINT clear the overflow
-        flag.  The software implementations do not change overflow.
+    7. The firmware implementations of DBLE, .BLE, and DDINT clear the overflow
+       flag.  The software implementations do not change overflow.
 
-     8. The M/E-Series FFP arithmetic instructions (.XADD, etc.) return negative
-        infinity on negative overflow and positive infinity on positive
-        overflow.  The equivalent F-Series instructions return positive infinity
-        on both.
+    8. The M/E-Series FFP arithmetic instructions (.XADD, etc.) return negative
+       infinity on negative overflow and positive infinity on positive overflow.
+       The equivalent F-Series instructions return positive infinity on both.
+
+    9. The protected memory lower bound for the .GOTO instruction is 2.
 
    Additional references:
     - DOS/RTE Relocatable Library Reference Manual (24998-90001, Oct-1981)
@@ -179,9 +182,6 @@ int32 i;
 
 #endif                                                  /* end of int64 support */
 
-if ((cpu_unit.flags & UNIT_FFP) == 0)                   /* FFP option installed? */
-    return stop_inst;
-
 entry = IR & 037;                                       /* mask to entry point */
 
 if (UNIT_CPU_MODEL != UNIT_1000_F) {                    /* 2100/M/E-Series? */
@@ -422,7 +422,7 @@ switch (entry) {                                        /* decode IR<4:0> */
             break;
             }
 
-        mp_dms_jmp (MA);                                /* validate jump addr */
+        mp_dms_jmp (MA, 2);                             /* validate jump addr */
         PCQ_ENTRY;                                      /* record last PC */
         PC = MA;                                        /* jump */
         BR = op[0].word;                                /* (for 2100 FFP compat) */
@@ -575,18 +575,14 @@ return reason;
    savings to allow programs to load in E-Series systems, in addition to
    accelerating these common operations.
 
-   M-Series microcode was never offered by HP.  However, it costs us nothing to
-   enable double-integer instructions for M-Series simulations.  This has the
-   concomitant advantage that it allows RTE-6/VM to run under SIMH (for
-   simulation, we must SET CPU 1000-M, because RTE-6/VM looks for the OS and VM
-   microcode -- which we do not implement yet -- if it detects an E- or F-Series
-   machine).
+   There was no equivalent M-Series microcode, due to the limited micromachine
+   address space on that system.
 
    Option implementation by CPU was as follows:
 
       2114    2115    2116    2100   1000-M  1000-E  1000-F
      ------  ------  ------  ------  ------  ------  ------
-      N/A     N/A     N/A     N/A     N/A    93575A   std
+      N/A     N/A     N/A     N/A     N/A    93585A   std
 
    The routines are mapped to instruction codes as follows:
 
@@ -610,27 +606,25 @@ return reason;
    floating-point processor and the Fast FORTRAN Processor ranges.  They are
    dispatched from those respective simulators for processing here.
 
-   Notes:
+   Implementation notes:
 
-     1. The E-Series opcodes are listed in Appendix C of the Macro/1000 manual.
-        These should be the same opcodes as given in the 93585A manual listed
-        below, but no copy of the reference below has been located to confirm
-        the proper opcodes.  This module should be corrected if needed when such
-        documentation is found.
+    1. Opcodes 105335-105337 are NOPs in the microcode.  They generate
+       unimplemented instructions stops under simulation.
 
-     2. The action of the self-test instruction (105320) is unknown.  At the
-        moment, we take an unimplemented instruction trap for this.  When
-        documentation explaining the action is located, it will be implemented.
+    2. This is an implementation of Revision 2 of the microcode, which was
+       released as ROM part numbers 93585-80003, 93585-80005, and 93585-80001
+       (Revision 1 substituted -80002 for -80005).
 
-     3. The F-Series firmware executes .DMP and .DDI/.DDIR by floating the
-        32-bit double integer to a 48-bit extended-precision number, calling the
-        FPP to execute the extended-precision multiply/divide, and then fixing
-        the product to a 32-bit double integer.  We simulate these directly with
-        64- or 32-bit integer arithmetic.
+    3. The F-Series firmware executes .DMP and .DDI/.DDIR by floating the 32-bit
+       double integer to a 48-bit extended-precision number, calling the FPP to
+       execute the extended-precision multiply/divide, and then fixing the
+       product to a 32-bit double integer.  We simulate these directly with 64-
+       or 32-bit integer arithmetic.
 
    Additional references:
-    - 93575A Double Integer Instructions Installation and Reference Manual
-      (93575-90007)
+    - 93585A Microcode Source (93585-18002 Rev. 2005)
+    - 93585A Double Integer Instructions Installation and Reference Manual
+             (93585-90007)
 */
 
 static const OP_PAT op_dbi[16] = {
@@ -647,9 +641,6 @@ OPS op;
 uint32 entry, t;
 t_stat reason = SCPE_OK;
 
-if ((cpu_unit.flags & UNIT_DBI) == 0)                   /* DBI option installed? */
-    return stop_inst;
-
 entry = IR & 017;                                       /* mask to entry point */
 
 if (op_dbi[entry] != OP_N)
@@ -659,8 +650,11 @@ if (op_dbi[entry] != OP_N)
 switch (entry) {                                        /* decode IR<3:0> */
 
     case 000:                                           /* [test] 105320 (OP_N) */
-        t = (AR << 16) | BR;                            /* set t for nop */
-        reason = stop_inst;                             /* function unknown; not impl. */
+        XR = 2;                                         /* set revision */
+        BR = 0377;                                      /* side effect of microcode */
+        SR = 0102077;                                   /* set "pass" code */
+        PC = (PC + 1) & VAMASK;                         /* return to P+1 */
+        t = (AR << 16) | BR;                            /* set t for return */
         break;
 
     case 001:                                           /* .DAD 105321 (OP_JD) */
@@ -677,8 +671,8 @@ switch (entry) {                                        /* decode IR<3:0> */
 
             t_int64 t64;
 
-            t64 = (t_int64) op[0].dword *               /* multiply values */
-                  (t_int64) op[1].dword;
+            t64 = (t_int64) INT32 (op[0].dword) *       /* multiply signed values */
+                  (t_int64) INT32 (op[1].dword);
             O = ((t64 < -(t_int64) 0x80000000) ||       /* overflow if out of range */
                  (t64 >  (t_int64) 0x7FFFFFFF));
             if (O)
@@ -752,7 +746,8 @@ switch (entry) {                                        /* decode IR<3:0> */
         if (O)
             t = ~SIGN32;                                /* rtn max pos for ovf */
         else
-            t = op[0].dword / op[1].dword;              /* else return quotient */
+            t = (uint32) (INT32 (op[0].dword) /         /* else return quotient */
+                          INT32 (op[1].dword));
         break;
 
     case 006:                                           /* .DDIR 105326 (OP_JD) */
@@ -806,7 +801,7 @@ switch (entry) {                                        /* decode IR<3:0> */
         goto DSB;                                       /* continue at .DSB */
 
     default:                                            /* others undefined */
-        t = (AR << 16) | BR;                            /* set t for nop */
+        t = (AR << 16) | BR;                            /* set t for NOP */
         reason = stop_inst;
         }
 
