@@ -1,6 +1,6 @@
 /* hp2100_fp.c: HP 2100 floating point instructions
 
-   Copyright (c) 2002-2006, Robert M. Supnik
+   Copyright (c) 2002-2008, Robert M. Supnik
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -23,6 +23,8 @@
    used in advertising or otherwise to promote the sale, use or other dealings
    in this Software without prior written authorization from Robert M Supnik.
 
+   21-Jan-08    JDB     Corrected fp_unpack mantissa high-word return
+                        (from Mark Pizzolato)
    01-Dec-06    JDB     Reworked FFP helpers for 1000-F support, deleted f_pwr2
    22-Jul-05    RMS     Fixed compiler warning in Solaris (from Doug Glyn)
    25-Feb-05    JDB     Added FFP helpers f_pack, f_unpack, f_pwr2
@@ -32,15 +34,6 @@
    21-Oct-02    RMS     Recoded for compatibility with 21MX microcode algorithms
 
 
-   Implementation note: The 2100/1000-M/E Fast FORTRAN Processor (FFP) and 1000
-   F-Series Floating Point Processor (FPP) simulations require that the host
-   compiler support 64-bit integers and the HAVE_INT64 symbol be defined during
-   compilation.  If this symbol is defined, two-word floating-point operations
-   are handled in the FPP code, and this module is not used.  If it is not
-   defined, then FFP and FPP operations are not available, and this module
-   provides the floating-point support.
-
-
    The HP2100 uses a unique binary floating point format:
 
      15 14                                         0
@@ -77,9 +70,20 @@
      inputs may cause the packup code to produce the wrong sign.
    - "Unclean" zeros (zero fraction, non-zero exponent) are processed
      like normal operands.
+
+   Implementation notes:
+
+    1. The 2100/1000-M/E Fast FORTRAN Processor (FFP) and 1000 F-Series Floating
+       Point Processor (FPP) simulations require that the host compiler support
+       64-bit integers and the HAVE_INT64 symbol be defined during compilation.
+       If this symbol is defined, two-word floating-point operations are handled
+       in the FPP code, and this module is not used.  If it is not defined, then
+       FFP and FPP operations are not available, and this module provides the
+       floating-point support.
 */
 
 #include "hp2100_defs.h"
+#include "hp2100_cpu.h"
 #include "hp2100_cpu1.h"
 #include "hp2100_fp.h"
 
@@ -120,8 +124,6 @@ struct ufp {                                            /* unpacked fp */
 
 #define FR_NEG(v)       ((~(v) + 1) & DMASK32)
 
-extern uint16 ABREG[2];
-
 uint32 UnpackFP (struct ufp *fop, uint32 opnd);
 void NegFP (struct ufp *fop);
 void NormFP (struct ufp *fop);
@@ -397,7 +399,7 @@ uint32 operand;
 
 operand = ((uint32) packed.fpk[0] << 16) | packed.fpk[1];
 UnpackFP (&fop, operand);
-mantissa->fpk[0] = (uint16) fop.fr >> 16;
+mantissa->fpk[0] = (uint16) (fop.fr >> 16);
 mantissa->fpk[1] = (uint16) fop.fr;
 *exponent = fop.exp;
 return 0;
