@@ -1,6 +1,6 @@
 /* i7094_cd.c: IBM 711/721 card reader/punch
 
-   Copyright (c) 2003-2006, Robert M. Supnik
+   Copyright (c) 2003-2008, Robert M. Supnik
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -26,6 +26,7 @@
    cdr          711 card reader
    cdp          721 card punch
 
+   19-Jan-07    RMS     Added UNIT_TEXT
    13-Jul-06    RMS     Fixed problem with 80 column full cards
 
    Cards are represented as ASCII text streams terminated by newlines.
@@ -106,7 +107,7 @@ extern uint32 col_masks[12];
 DIB cdr_dib = { &cdr_chsel, NULL };
 
 UNIT cdr_unit = {
-    UDATA (&cdr_svc, UNIT_SEQ+UNIT_ATTABLE+UNIT_ROABLE, 0)
+    UDATA (&cdr_svc, UNIT_SEQ+UNIT_ATTABLE+UNIT_ROABLE+UNIT_TEXT, 0)
     };
 
 REG cdr_reg[] = {
@@ -144,7 +145,7 @@ DEVICE cdr_dev = {
 DIB cdp_dib = { &cdp_chsel, &cdp_chwr };
 
 UNIT cdp_unit = {
-    UDATA (&cdp_svc, UNIT_SEQ+UNIT_ATTABLE, 0)
+    UDATA (&cdp_svc, UNIT_SEQ+UNIT_ATTABLE+UNIT_TEXT, 0)
     };
 
 REG cdp_reg[] = {
@@ -181,7 +182,8 @@ DEVICE cdp_dev = {
 
 t_stat cdr_chsel (uint32 ch, uint32 sel, uint32 unit)
 {
-if (sel & CHSL_NDS) return ch6_end_nds (ch);            /* nds? nop */
+if (sel & CHSL_NDS)                                     /* nds? nop */
+    return ch6_end_nds (ch);
 
 switch (sel) {                                          /* case on data sel */
 
@@ -209,7 +211,8 @@ uint32 i, col, row, bufw, colbin;
 char cdr_cbuf[(2 * CD_CHRLNT) + 2];
 t_uint64 dat = 0;
 
-if ((uptr->flags & UNIT_ATT) == 0) return SCPE_UNATT;   /* not attached? */
+if ((uptr->flags & UNIT_ATT) == 0)                      /* not attached? */
+    return SCPE_UNATT;
 switch (cdr_sta) {                                      /* case on state */
 
     case CDS_INIT:                                      /* initial state */
@@ -274,7 +277,8 @@ t_stat cdr_reset (DEVICE *dptr)
 {
 uint32 i;
 
-for (i = 0; i < CD_BINLNT; i++) cdr_bbuf[i] = 0;        /* clear buffer */
+for (i = 0; i < CD_BINLNT; i++)                         /* clear buffer */
+    cdr_bbuf[i] = 0;
 cdr_sta = 0;                                            /* clear state */
 cdr_bptr = 0;                                           /* clear buf ptr */
 sim_cancel (&cdr_unit);                                 /* stop reader */
@@ -309,9 +313,11 @@ return SCPE_OK;
 
 t_stat cd_attach (UNIT *uptr, char *cptr)
 {
-t_stat r = attach_unit (uptr, cptr);
+t_stat r;
 
-if (r != SCPE_OK) return r;                             /* attach */
+r = attach_unit (uptr, cptr);
+if (r != SCPE_OK)                                       /* attach */
+    return r;
 if (sim_switches & SWMASK ('T'))                        /* text? */
     uptr->flags = uptr->flags & ~UNIT_CBN;
 else if (sim_switches & SWMASK ('C'))                   /* column binary? */
@@ -334,7 +340,8 @@ return (uptr->flags & UNIT_ATT)? SCPE_NOFNC: SCPE_OK;
 
 t_stat cdp_chsel (uint32 ch, uint32 sel, uint32 unit)
 {
-if (sel & CHSL_NDS) return ch6_end_nds (ch);            /* nds? nop */
+if (sel & CHSL_NDS)                                     /* nds? nop */
+    return ch6_end_nds (ch);
 
 switch (sel) {                                          /* case on cmd */
 
@@ -392,7 +399,8 @@ switch (cdp_sta) {                                      /* case on state */
     case CDS_DATA:                                      /* data state */
         if (!ch6_qconn (CH_A, U_CDP))                   /* chan disconnect? */
             return cdp_card_end (uptr);                 /* write card */
-        if (cdp_chob_v) cdp_chob_v = 0;                 /* valid? clear */
+        if (cdp_chob_v)                                 /* valid? clear */
+            cdp_chob_v = 0;
         else ind_ioc = 1;                               /* no, io check */
         ch6_req_wr (CH_A, U_CDP);                       /* req channel */
         sim_activate (uptr, (cdp_bptr & 1)? cdp_tleft: cdp_tright);
@@ -417,8 +425,10 @@ uint32 i, col, row, bufw, colbin;
 char *pch, bcd, cdp_cbuf[(2 * CD_CHRLNT) + 2];
 t_uint64 dat;
 
-if ((uptr->flags & UNIT_ATT) == 0) return SCPE_UNATT;   /* not attached? */
-if (uptr->flags & UNIT_PCA) pch = bcd_to_ascii_a;
+if ((uptr->flags & UNIT_ATT) == 0)                      /* not attached? */
+    return SCPE_UNATT;
+if (uptr->flags & UNIT_PCA)
+    pch = bcd_to_ascii_a;
 else pch = bcd_to_ascii_h;
 for (col = 0; col < ((2 * CD_CHRLNT) + 1); col++)
     cdp_cbuf[col] = ' ';                                /* clear char buf */
@@ -427,7 +437,8 @@ for (col = 0; col < 72; col++) {                        /* process 72 columns */
     dat = bit_masks[35 - (col % 36)];                   /* mask for column */
     for (row = 0; row < 12; row++) {                    /* proc 12 rows */
         bufw = (row * 2) + (col / 36);                  /* index to buffer */
-        if (cdp_bbuf[bufw] & dat) colbin |= col_masks[row];
+        if (cdp_bbuf[bufw] & dat)
+            colbin |= col_masks[row];
         }
     if (cdp_unit.flags & UNIT_CBN) {                    /* column binary? */
         cdp_cbuf[2 * col] = pch[(colbin >> 6) & 077];
@@ -443,12 +454,12 @@ for (i = ((2 * CD_CHRLNT) + 1); (i > 0) &&
 cdp_cbuf[i++] = '\n';                                   /* append nl */
 cdp_cbuf[i++] = 0;                                      /* append nul */
 fputs (cdp_cbuf, uptr->fileref);                        /* write card */
+uptr->pos = ftell (uptr->fileref);                      /* update position */
 if (ferror (uptr->fileref)) {                           /* error? */
     perror ("CDP I/O error");
     clearerr (uptr->fileref);
     return SCPE_IOERR;
     }
-uptr->pos = ftell (uptr->fileref);                      /* update position */
 cdp_sta = CDS_END;                                      /* end state */
 sim_cancel (uptr);                                      /* cancel current */
 sim_activate (uptr, cdp_tstop);                         /* long timer */
@@ -461,7 +472,8 @@ t_stat cdp_reset (DEVICE *dptr)
 {
 uint32 i;
 
-for (i = 0; i < 24; i++) cdp_bbuf[i] = 0;               /* clear buffer */
+for (i = 0; i < 24; i++)                                /* clear buffer */
+    cdp_bbuf[i] = 0;
 cdp_sta = 0;                                            /* clear state */
 cdp_bptr = 0;                                           /* clear buf ptr */
 cdp_chob = 0;
@@ -492,7 +504,8 @@ uint32 i;
 char bcd;
 
 for (i = 0, bcd = 0; i < 12; i++) {                     /* 'sum' rows */
-    if (cb & (1 << i)) bcd |= row_val[i];
+    if (cb & (1 << i))
+        bcd |= row_val[i];
     }
 return bcd;
 }
