@@ -1,6 +1,6 @@
 /* nova_qty.c: NOVA multiplexor (QTY/ALM) simulator
 
-   Copyright (c) 2000-2005, Robert M. Supnik
+   Copyright (c) 2000-2008, Robert M. Supnik
    Written by Bruce Ray and used with his gracious permission.
 
    Permission is hereby granted, free of charge, to any person obtaining a
@@ -26,6 +26,7 @@
 
    qty          multiplexor: QTY = 4060, ALM = 42xx
 
+   04-Jul-07    BKR     fixed QTY output line number calculation (affected higher line numbers),
    25-Mar-04    RMS     Updated for V3.2
    12-Jan-04    BKR     Initial release
                         includes both original DG "quad" multiplexor (QTY)
@@ -108,8 +109,6 @@ extern int32    sim_switches ;
 extern FILE *   sim_log ;
 extern int32    tmxr_poll ;                             /* calibrated delay */
 
-t_stat  qty_summary ( FILE * st, UNIT * uptr, int32 val, void * desc ) ;
-t_stat  qty_show    ( FILE * st, UNIT * uptr, int32 val, void * desc ) ;
 t_stat  qty_setnl   ( UNIT * uptr, int32 val, char * cptr, void * desc ) ;
 
 t_stat  qty_attach  ( UNIT * uptr, char * cptr ) ;
@@ -157,8 +156,6 @@ UNIT    qty_unit =
         UDATA (&qty_svc, (UNIT_ATTABLE), 0)
         } ;
 
-REG qty_nlreg = { DRDATA (NLINES, qty_desc.lines, 7), PV_LEFT };
-
 REG qty_reg[] =  /*  ('alm_reg' should be similar to this except for device code related items)  */
         {
         { ORDATA (BUF, qty_unit.buf, 8) },
@@ -178,14 +175,15 @@ MTAB    qty_mod[] =
         { UNIT_8B, 0, "7b", "7B", NULL },
         { UNIT_8B, UNIT_8B, "8b", "8B", NULL },
         { MTAB_XTD | MTAB_VDV, 1, NULL, "DISCONNECT",
-            &tmxr_dscln, NULL, &qty_desc },
-        { UNIT_ATT, UNIT_ATT, "connections", NULL, NULL, &qty_summary },
+            &tmxr_dscln, NULL, (void *)&qty_desc },
+        { UNIT_ATT, UNIT_ATT, "connections", NULL,
+          NULL, &tmxr_show_summ, (void *)&qty_desc },
         { MTAB_XTD | MTAB_VDV | MTAB_NMO, 1, "CONNECTIONS", NULL,
-            NULL, &qty_show, NULL },
+            NULL, &tmxr_show_cstat, (void *)&qty_desc },
         { MTAB_XTD | MTAB_VDV | MTAB_NMO, 0, "STATISTICS", NULL,
-            NULL, &qty_show, NULL },
-        { MTAB_XTD | MTAB_VDV | MTAB_VAL, 0, "lines", "LINES",
-            &qty_setnl, NULL, &qty_nlreg },
+            NULL, &tmxr_show_cstat, (void *)&qty_desc },
+        { MTAB_XTD | MTAB_VDV, 0, "LINES", "LINES",
+            &qty_setnl, &tmxr_show_lines, (void *) &qty_desc },
         { 0 }
         } ;
 
@@ -198,16 +196,6 @@ DEVICE  qty_dev =
         &qty_dib, (DEV_DISABLE | DEV_DIS | DEV_NET)
         };
 
-
-        /*  <define these in 'nova_defs.h' someday...>  */
-        /*  (need to mask off non-interrupt bit devices)  */
- 
-#define DEV_SET_BUSY( dibp )        dev_busy = dev_busy |  ( (dibp)->mask ) ;
-#define DEV_CLEAR_BUSY( dibp )      dev_busy = dev_busy & ~( (dibp)->mask ) ;
-#define DEV_SET_DONE( dibp )        dev_done = dev_done |  ( (dibp)->mask ) ;  int_req = int_req & ~( (dibp)->mask ) ;
-#define DEV_CLEAR_DONE( dibp )      dev_done = dev_done & ~( (dibp)->mask ) ;  int_req = int_req & ~( (dibp)->mask ) ;
-#define DEV_UPDATE_INTR             int_req = (int_req & ~INT_DEV) | (dev_done & ~dev_disable) ;
-
 #define DG_RETURN( status, data )   (int32)(((status) << IOT_V_REASON) | ((data) & 0x0FFFF) )
 
 /*
@@ -466,17 +454,17 @@ int qty_update_status( DIB * dibp, TMXR * tmxr_desc )
             }
         }
     /*  <we could check each line for TX busy to set DEV_SET_BUSY)?>  */
-    DEV_CLEAR_BUSY( dibp )
-    DEV_CLEAR_DONE( dibp )
+    DEV_CLR_BUSY( INT_QTY ) ;
+    DEV_CLR_DONE( INT_QTY ) ;
     if ( txbusy )
         {
-        DEV_SET_BUSY( dibp ) ;
+        DEV_SET_BUSY( INT_QTY ) ;
         }
     if ( status & (QTY_S_RI | QTY_S_TI) )
         {
-        DEV_SET_DONE( dibp )
+        DEV_SET_DONE( INT_QTY ) ;
         }
-    DEV_UPDATE_INTR                                     /*  update final intr status  */
+    DEV_UPDATE_INTR ;                                   /*  update final intr status  */
         return ( status ) ;
     }   /*  end of 'qty_update_status'  */
 
@@ -568,9 +556,9 @@ t_stat qty_common_reset( DIB * dibp, UNIT * unitp, DEVICE * dptr )
         else qty_dev.flags |= DEV_DIS;
         }
     qty_clear( TRUE ) ;
-    DEV_CLEAR_BUSY( dibp )                              /*  clear busy  */
-    DEV_CLEAR_DONE( dibp )                              /*  clear done, int */
-    DEV_UPDATE_INTR
+    DEV_CLR_BUSY( INT_QTY ) ;                              /*  clear busy  */
+    DEV_CLR_DONE( INT_QTY ) ;                              /*  clear done, int */
+    DEV_UPDATE_INTR ;
     if ( QTY_MASTER_ACTIVE(&qty_desc) )
         {
         sim_activate( unitp, tmxr_poll ) ;
@@ -692,7 +680,7 @@ int32 qty( int32 pulse, int32 code, int32 AC )
         break ;
 
     case ioDOA :    /*  send character to QTY  */
-        line = QTY_LINE_EXTRACT( iodata ) ;
+        line = QTY_LINE_EXTRACT( AC ) ;
         if ( line < qty_max )
             if ( QTY_LINE_BIT_SET(line,QTY_L_TXE) )
             {
@@ -759,50 +747,6 @@ int32 qty( int32 pulse, int32 code, int32 AC )
     return ( DG_RETURN( ioresult, iodata ) ) ;
     }   /*  end of 'qty'  */
 
-    /*--------------------------------------------------------------*/
-    /*                            qty_summary                       */
-    /*--------------------------------------------------------------*/
-
-t_stat qty_summary( FILE * st, UNIT * uptr, int32 val, void * desc )
-    {
-    int32   i, t ;
-
-    for (i = t = 0 ; i < qty_desc.lines ; ++i )
-        if ( qty_ldsc[i].conn )
-        {
-        ++t ;
-        }
-    fprintf( st, "%d connection%s", t, ((t)? "s" : "") ) ;
-    return ( SCPE_OK ) ;
-    }   /*  end of 'qty_summ'  */
-
-
-    /*--------------------------------------------------------------*/
-    /*                             qty_show                         */
-    /*--------------------------------------------------------------*/
-
-t_stat qty_show( FILE * st, UNIT * uptr, int32 val, void * desc )
-    {
-    int32   i, t ;
-
-    for (i = t = 0 ; i < qty_desc.lines ; ++i )
-        if ( qty_ldsc[i].conn )
-        {
-        t = 1; 
-        if ( val )
-            {
-            tmxr_fconns( st, &qty_ldsc[i], i ) ;
-            }
-        else
-            {
-            tmxr_fstats( st, &qty_ldsc[i], i ) ;
-            }
-        }
-    if ( t == 0 ) fprintf( st, "none connected\n" ) ;
-    return ( SCPE_OK ) ;
-    }   /*  end of 'qty_show'  */
-
-
     /*--------------------------------------------------------------*/
     /*                             qty_setnl                        */
     /*--------------------------------------------------------------*/
@@ -979,7 +923,7 @@ int32 alm( int32 pulse, int32 code, int32 AC )
         /*  (mask with 'alm_line_mask' in case ALM mask is different than QTY */
         alm_section = 0 ;
         if ( ! ( iodata & QTY_S_RI) )
-            if ( iodata & QTY_S_TI )
+          if ( iodata & QTY_S_TI )
             {
             alm_section = 1 ;                           /*  receiver quiet - transmitter done  */
             }
@@ -1100,7 +1044,7 @@ int32 alm( int32 pulse, int32 code, int32 AC )
                  *  clear device busy
                  */
         for ( a = 0 ; a < qty_max ; ++a )
-            if ( 1 )
+          if ( 1 /* (not yet optimized) */ )
             {
             QTY_LINE_CLEAR_BIT( a, (QTY_L_RXBZ | QTY_L_RXDN | QTY_L_TXBZ | QTY_L_TXDN) ) ;
             }
@@ -1112,7 +1056,7 @@ int32 alm( int32 pulse, int32 code, int32 AC )
 
     case iopC :
         for ( a = 0 ; a < qty_max ; ++a )
-            if ( 1 )
+          if ( 1 /* (not yet optimized) */ )
             {
             QTY_LINE_CLEAR_BIT( a, (QTY_L_RXBZ | QTY_L_RXDN | QTY_L_TXBZ | QTY_L_TXDN) ) ;
             }
