@@ -1,6 +1,6 @@
 /* nova_sys.c: NOVA simulator interface
 
-   Copyright (c) 1993-2005, Robert M. Supnik
+   Copyright (c) 1993-2008, Robert M. Supnik
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -23,6 +23,10 @@
    used in advertising or otherwise to promote the sale, use or other dealings
    in this Software without prior written authorization from Robert M Supnik.
 
+   04-Jul-07    BKR     DEC's IOF/ION changed to DG's INTDS/INTEN mnemonic,
+                        Fixed QTY/ADCV device name,
+                        RDSW changed to DDG's READS mnemonic,
+                        fixed/enhanced 'load' command for DG-compatible binary tape format
    26-Mar-04    RMS     Fixed warning with -std=c99
    14-Jan-04    BKR     Added support for QTY and ALM
    04-Jan-04    RMS     Fixed 64b issues found by VMS 8.1
@@ -45,13 +49,6 @@
 
 extern DEVICE cpu_dev;
 extern UNIT cpu_unit;
-#if defined (ECLIPSE)
-extern DEVICE map_dev;
-extern DEVICE fpu_dev;
-extern DEVICE pit_dev;
-extern int32 Usermap;
-extern int32 MapStat;
-#endif
 extern DEVICE ptr_dev;
 extern DEVICE ptp_dev;
 extern DEVICE plt_dev;
@@ -69,6 +66,20 @@ extern DEVICE alm_dev;
 extern REG cpu_reg[];
 extern uint16 M[];
 extern int32 saved_PC;
+extern int32 AMASK;
+
+#if defined (ECLIPSE)
+
+extern DEVICE map_dev;
+extern DEVICE fpu_dev;
+extern DEVICE pit_dev;
+extern int32 Usermap;
+extern int32 MapStat;
+
+#endif
+
+extern int32 sim_switches;
+
 
 /* SCP data structures
 
@@ -120,8 +131,7 @@ const char *sim_stop_messages[] = {
     "HALT instruction",
     "Breakpoint",
     "Nested indirect address limit exceeded",
-    "Nested indirect interrupt address limit exceeded",
-    "Nested indirect trap address limit exceeded",
+    "Nested indirect interrupt or trap address limit exceeded",
     "Read breakpoint",
     "Write breakpoint"
     };
@@ -147,29 +157,57 @@ const char *sim_stop_messages[] = {
    If the word count is [-21,-n], then the block is repeated data.
    If the word count is 1, the block is the start address.
    If the word count is >1, the block is an error block.
+
+Notes:
+    'start' block terminates loading.
+    'start' block starting address 1B0 = do not auto-start, 0B0 = auto-start.
+    'start' block starting address is saved in 'save_PC' so a "continue"
+      should start the program.
+
+    specify -i switch ignores checksum errors
+
+
+internal state machine:
+
+    0,1 get byte count (low and high), ignore leader bytes (<000>)
+    2,3 get origin
+    4,5 get checksum
+    6,7 process data block
+    8   process 'ignore' (error) block
 */
 
 t_stat sim_load (FILE *fileref, char *cptr, char *fnam, int flag)
 {
-int32 data, csum, count, state, i;
-uint32 origin;
+int32	data, csum, count, state, i;
+int32	origin;
+int	pos ;
+int	block_start ;
+int	done ;
 
-if ((*cptr != 0) || (flag != 0)) return SCPE_ARG;
+if ((*cptr != 0) || (flag != 0))
+    return ( SCPE_ARG ) ;
 state = 0;
-while ((i = getc (fileref)) != EOF) {
+block_start = -1 ;
+done  = 0 ;
+for ( pos = 0 ; (! done) && ((i=getc(fileref)) != EOF) ; ++pos )
+    {
+    i &= 0x00FF ;                                       /* (insure no sign extension) */
     switch (state) {
         case 0:                                         /* leader */
             count = i;
-            state = (count != 0);
+            state = (count != 0) ;
+        if ( state )
+        block_start = pos ;
             break;
         case 1:                                         /* high count */
-            csum = count = (i << 8) | count;
+            csum = count = (i << 8) | count ;
             state = 2;
             break;
         case 2:                                         /* low origin */
             origin = i;
             state = 3;
-            break;
+        break ;
+
         case 3:                                         /* high origin */
             origin = (i << 8) | origin;
             csum = csum + origin;
@@ -180,56 +218,88 @@ while ((i = getc (fileref)) != EOF) {
             state = 5;
             break;
         case 5:                                         /* high checksum */
-            csum = csum + (i << 8);
-            if (count == 1) saved_PC = origin;          /* count = 1? */
-            if (count <= 1) {                           /* count = 0/1? */
-                if (csum & 0177777) return SCPE_CSUM;
-                state = 0;
-                break;
-				}
-            if (count < 0100000) {                      /* count > 1 */
-                state = 8;
-                break;
-				}
-            count = 0200000 - count;
-            state = 6;
+            csum = (csum + (i << 8)) & 0xFFFF ;
+            if (count == 1)
+                {
+                /*  'start' block  */
+                /*  do any auto-start check or inhibit check  */
+                saved_PC = (origin & 077777) ;              /*  0B0 = auto-start program    */
+                                                            /*  1B0 = do not auto start */
+                state	= 0 ;                               /*  indicate okay state */
+                done	= 1 ;                               /*  we're done! */
+                if ( ! (origin & 0x8000) )
+                    {
+                    printf( "auto start @ %05o \n", (origin & 0x7FFF) ) ;
+                    }
+                break ;
+                }
+        if ( ((count & 0x8000) == 0) && (count > 1))
+            {
+            /*  'ignore' block  */
+            state = 8 ;
+            }
+        /*  'data' or 'repeat' block  */
+        count = 0200000 - count ;
+        if ( count <= 020 )
+            {
+            /*  'data' block  */
+            state = 6 ;
+            break ;
+            }
+        /*  'repeat' block (multiple data)  */
+
+            if (count > 020) {                           /* large block */
+                for (count = count - 1; count > 1; count--) {
+                    if (origin >= AMASK /* MEMSIZE? */)
+                        {
+                        return ( SCPE_NXM );
+                        }
+                    M[origin] = data;
+                    origin = origin + 1;
+                    }
+                state = 0 ;
+                }
+            state = 0;
             break;
         case 6:                                         /* low data  */
-            data = i;
+            data  = i;
             state = 7;
             break;
         case 7:                                         /* high data */
             data = (i << 8) | data;
-            csum = csum + data;
-            if (count > 20) {                           /* large block */
-                for (count = count - 1; count == 1; count--) {
-                    if (origin >= MEMSIZE) return SCPE_NXM;
-                    M[origin] = data;
-                    origin = origin + 1;
-                    }
-                }
-            if (origin >= MEMSIZE) return SCPE_NXM;
+            csum = (csum + data) & 0xFFFF ;
+
+            if (origin >= AMASK /* MEMSIZE? */)
+                return SCPE_NXM;
             M[origin] = data;
             origin = origin + 1;
             count = count - 1;
             if (count == 0) {
-                if (csum & 0177777) return SCPE_CSUM;
+                if ( csum )
+                    {
+                    printf( "checksum error: block start at %d [0x%x] \n", block_start, block_start ) ;
+                    printf( "calculated: 0%o [0x%4x]\n", csum, csum ) ;
+                    if ( ! (sim_switches & SWMASK('I')) )
+                        return SCPE_CSUM;
+                    }
                 state = 0;
                 break;
                 }
             state = 6;
             break;
-        case 8:                                         /* error block */
-            if (i == 0377) state = 0;
+        case 8:                                         /* error (ignore) block */
+            if (i == 0377)                              /*  (wait for 'RUBOUT' char)  */
+                state = 0;
             break;
             }                                           /* end switch */
         }                                               /* end while */
 
 /* Ok to find end of tape between blocks or in error state */
 
-return ((state == 0) || (state == 8))? SCPE_OK: SCPE_FMT;
+return ( ((state == 0) || (state == 8)) ? SCPE_OK : SCPE_FMT ) ;
 }
 
+
 /* Symbol tables */
 
 #define I_V_FL          18                              /* flag bits */
@@ -382,8 +452,8 @@ static const char *opcode[] = {
  "ANDL#", "ANDZL#", "ANDOL#", "ANDCL#",
  "ANDR#", "ANDZR#", "ANDOR#", "ANDCR#",
  "ANDS#", "ANDZS#", "ANDOS#", "ANDCS#",
- "ION", "IOF",
- "RDSW", "INTA", "MSKO", "IORST", "HALT",
+ "INTEN", "INTDS",
+ "READS", "INTA", "MSKO", "IORST", "HALT",
 #if !defined (ECLIPSE)
  "MUL", "DIV", "MULS", "DIVS",
  "PSHA", "POPA", "SAV", "RET",
@@ -517,7 +587,7 @@ static const int32 opc_val[] = {
  0061001+I_R, 0060001+I_R, 0061201+I_R, 0060201+I_R,
  0060401+I_BY, 0062001+I_BY,
 #endif
- 0060000+I_D, 0060100+I_D, 0060200+I_D, 0060300+I_D,
+ 0060000+I_RD, 0060100+I_RD, 0060200+I_RD, 0060300+I_RD,
  0060400+I_RD, 0060500+I_RD, 0060600+I_RD, 0060700+I_RD,
  0061000+I_RD, 0061100+I_RD, 0061200+I_RD, 0061300+I_RD,
  0061400+I_RD, 0061500+I_RD, 0061600+I_RD, 0061700+I_RD,
@@ -541,7 +611,7 @@ static const char *device[] = {
  "ERCC", "MAP",
 #endif
  "TTI", "TTO", "PTR", "PTP", "RTC", "PLT", "CDR", "LPT",
- "DSK", "MTA", "DCM", "ADCV", "DKP", "CAS",
+ "DSK", "MTA", "DCM", "QTY" /* "ADCV" */, "DKP", "CAS",
  "TTI1", "TTO1", "CPU",
  NULL
  };
@@ -575,10 +645,12 @@ t_stat fprint_addr (FILE *of, t_addr addr, int32 ind, int32 mode,
 {
 int32 dsign, dmax;
 
-if (ext) dmax = AMASK + 1;                              /* get max disp */
+if (ext)                                                /* get max disp */
+    dmax = AMASK + 1;
 else dmax = I_M_DISP + 1;
 dsign = dmax >> 1;                                      /* get disp sign */
-if (ind) fprintf (of, "@");                             /* indirect? */
+if (ind)                                                /* indirect? */
+    fprintf (of, "@");
 switch (mode & 03) {                                    /* mode */
 
     case 0:                                             /* absolute */
@@ -587,22 +659,26 @@ switch (mode & 03) {                                    /* mode */
 
     case 1:                                             /* PC rel */
         if (disp & dsign) {
-            if (cflag) fprintf (of, "%-o", (addr - (dmax - disp)) & AMASK);
+            if (cflag)
+                fprintf (of, "%-o", (addr - (dmax - disp)) & AMASK);
             else fprintf (of, ".-%-o", dmax - disp);
             }
         else {
-            if (cflag) fprintf (of, "%-o", (addr + disp) & AMASK);
+            if (cflag)
+                fprintf (of, "%-o", (addr + disp) & AMASK);
             else fprintf (of, ".+%-o", disp);
             }
         break;
 
     case 2:                                             /* AC2 rel */
-        if (disp & dsign) fprintf (of, "-%-o,2", dmax - disp);
+        if (disp & dsign)
+            fprintf (of, "-%-o,2", dmax - disp);
         else fprintf (of, "%-o,2", disp);
         break;
 
     case 3:                                             /* AC3 rel */
-        if (disp & dsign) fprintf (of, "-%-o,3", dmax - disp);
+        if (disp & dsign)
+            fprintf (of, "-%-o,3", dmax - disp);
         else fprintf (of, "%-o,3", disp);
         break;
         }                                               /* end switch */
@@ -641,7 +717,8 @@ if (sw & SWMASK ('C')) {                                /* character? */
     fprintf (of, (c2 < 040)? "<%03o>": "%c", c2);
     return SCPE_OK;
     }
-if (!(sw & SWMASK ('M'))) return SCPE_ARG;              /* mnemonic? */
+if (!(sw & SWMASK ('M')))                               /* mnemonic? */
+    return SCPE_ARG;
 
 /* Instruction decode */
 
@@ -704,7 +781,8 @@ for (i = 0; opc_val[i] >= 0; i++) {                     /* loop thru ops */
 
         case I_V_RR:                                    /* operate */
             fprintf (of, "%s %-o,%-o", opcode[i], src, dst);
-            if (skp) fprintf (of, ",%s", skip[skp-1]);
+            if (skp)
+                fprintf (of, ",%s", skip[skp-1]);
             break;
 
         case I_V_BY:                                    /* byte */
@@ -787,7 +865,8 @@ int32 d, r, x, pflag;
 char gbuf[CBUFSIZE];
 int32 dmax, dsign;
 
-if (ext) dmax = AMASK + 1;                              /* get max disp */
+if (ext)                                                /* get max disp */
+    dmax = AMASK + 1;
 else dmax = I_M_DISP + 1;
 dsign = dmax >> 1;                                      /* get disp sign */
 val[0] = 0;                                             /* no indirect */
@@ -815,25 +894,29 @@ else if (*cptr == '-') {                                /* - sign? */
 if (*cptr != 0) {                                       /* number? */
     cptr = get_glyph (cptr, gbuf, ',');                 /* get glyph */
     d = (int32) get_uint (gbuf, 8, AMASK, &r);
-    if (r != SCPE_OK) return NULL;
+    if (r != SCPE_OK)
+        return NULL;
     pflag = pflag | A_NUM;
     }
 if (*cptr != 0) {                                       /* index? */
     cptr = get_glyph (cptr, gbuf, 0);                   /* get glyph */
     x = (int32) get_uint (gbuf, 8, I_M_DST, &r);
-    if ((r != SCPE_OK) || (x < 2)) return NULL;
+    if ((r != SCPE_OK) || (x < 2))
+        return NULL;
     pflag = pflag | A_NX;
     }
 
 switch (pflag) {                                        /* case on flags */
 
     case A_NUM: case A_NUM+A_SI:                        /* ~CPU, (+)num */
-        if (d < dmax) val[2] = d;
+        if (d < dmax)
+            val[2] = d;
         else return NULL;
         break;
 
     case A_NUM+A_FL: case A_NUM+A_SI+A_FL:              /* CPU, (+)num */
-        if (d < dmax) val[2] = d;
+        if (d < dmax)
+            val[2] = d;
         else if (((d >= (((int32) addr - dsign) & AMASK)) &&
                   (d < (((int32) addr + dsign) & AMASK))) ||
                   (d >= ((int32) addr + (-dsign & AMASK)))) {
@@ -852,8 +935,10 @@ switch (pflag) {                                        /* case on flags */
     case A_NX+A_SI+A_MI+A_NUM:                          /* -num, ndx */
     case A_NX+A_SI+A_MI+A_NUM+A_FL:
         val[1] = x;                                     /* set mode */
-        if (((pflag & A_MI) == 0) && (d < dsign)) val[2] = d;
-        else if ((pflag & A_MI) && (d <= dsign)) val[2] = (dmax - d);
+        if (((pflag & A_MI) == 0) && (d < dsign))
+            val[2] = d;
+        else if ((pflag & A_MI) && (d <= dsign))
+            val[2] = (dmax - d);
         else return NULL;
         break;
 
@@ -882,10 +967,12 @@ t_stat r;
 
 cptr = get_glyph (cptr, gbuf, ',');                     /* get register */
 val[0] = (int32) get_uint (gbuf, 8, I_M_SRC, &r);
-if (r != SCPE_OK) return NULL;
+if (r != SCPE_OK)
+    return NULL;
 cptr = get_glyph (cptr, gbuf, term);                    /* get register */
 val[1] = (int32) get_uint (gbuf, 8, I_M_DST, &r);
-if (r != SCPE_OK) return NULL;
+if (r != SCPE_OK)
+    return NULL;
 return cptr;
 }
 
@@ -910,12 +997,14 @@ char gbuf[CBUFSIZE];
 cflag = (uptr == NULL) || (uptr == &cpu_unit);
 while (isspace (*cptr)) cptr++;                         /* absorb spaces */
 if ((sw & SWMASK ('A')) || ((*cptr == '\'') && cptr++)) { /* ASCII char? */
-    if (cptr[0] == 0) return SCPE_ARG;                  /* must have 1 char */
+    if (cptr[0] == 0)                                   /* must have 1 char */
+        return SCPE_ARG;
     val[0] = (t_value) cptr[0];
     return SCPE_OK;
     }
 if ((sw & SWMASK ('C')) || ((*cptr == '"') && cptr++)) { /* ASCII string? */
-    if (cptr[0] == 0) return SCPE_ARG;                  /* must have 1 char */
+    if (cptr[0] == 0)                                   /* must have 1 char */
+        return SCPE_ARG;
     val[0] = ((t_value) cptr[0] << 8) + (t_value) cptr[1];
     return SCPE_OK;
     }
@@ -925,7 +1014,8 @@ if ((sw & SWMASK ('C')) || ((*cptr == '"') && cptr++)) { /* ASCII string? */
 rtn = SCPE_OK;                                          /* assume 1 word */
 cptr = get_glyph (cptr, gbuf, 0);                       /* get opcode */
 for (i = 0; (opcode[i] != NULL) && (strcmp (opcode[i], gbuf) != 0) ; i++) ;
-if (opcode[i] == NULL) return SCPE_ARG;
+if (opcode[i] == NULL)
+    return SCPE_ARG;
 val[0] = opc_val[i] & 0177777;                          /* get value */
 j = (opc_val[i] >> I_V_FL) & I_M_FL;                    /* get class */
 
@@ -937,23 +1027,27 @@ switch (j) {                                            /* case on class */
     case I_V_R:                                         /* IOT reg */
         cptr = get_glyph (cptr, gbuf, 0);               /* get register */
         d = (int32) get_uint (gbuf, 8, I_M_DST, &r);
-        if (r != SCPE_OK) return SCPE_ARG;
+        if (r != SCPE_OK)
+            return SCPE_ARG;
         val[0] = val[0] | (d << I_V_DST);               /* put in place */
         break;
 
     case I_V_RD:                                        /* IOT reg,dev */
         cptr = get_glyph (cptr, gbuf, ',');             /* get register */
         d = (int32) get_uint (gbuf, 8, I_M_DST, &r);
-        if (r != SCPE_OK) return SCPE_ARG;
+        if (r != SCPE_OK)
+            return SCPE_ARG;
         val[0] = val[0] | (d << I_V_DST);               /* put in place */
     case I_V_D:                                         /* IOT dev */
         cptr = get_glyph (cptr, gbuf, 0);               /* get device */
         for (i = 0; (device[i] != NULL) &&
                     (strcmp (device[i], gbuf) != 0); i++);
-        if (device[i] != NULL) val[0] = val[0] | dev_val[i];
+        if (device[i] != NULL)
+            val[0] = val[0] | dev_val[i];
         else {
             d = (int32) get_uint (gbuf, 8, I_M_DEV, &r);
-            if (r != SCPE_OK) return SCPE_ARG;
+            if (r != SCPE_OK)
+                return SCPE_ARG;
             val[0] = val[0] | (d << I_V_DEV);
             }
         break;
@@ -961,57 +1055,67 @@ switch (j) {                                            /* case on class */
     case I_V_RM:                                        /* reg, addr */
         cptr = get_glyph (cptr, gbuf, ',');             /* get register */
         d = (int32) get_uint (gbuf, 8, I_M_DST, &r);
-        if (r != SCPE_OK) return SCPE_ARG;
+        if (r != SCPE_OK)
+            return SCPE_ARG;
         val[0] = val[0] | (d << I_V_DST);               /* put in place */
     case I_V_M:                                         /* addr */
         cptr = get_addr (cptr, addr, FALSE, cflag, amd);
-        if (cptr == NULL) return SCPE_ARG;
+        if (cptr == NULL)
+            return SCPE_ARG;
         val[0] = val[0] | (amd[0] << I_V_IND) | (amd[1] << I_V_MODE) | amd[2];
         break;
 
     case I_V_RR:                                        /* operate */
         cptr = get_2reg (cptr, ',', amd);               /* get 2 reg */
-        if (cptr == NULL) return SCPE_ARG;
+        if (cptr == NULL)
+            return SCPE_ARG;
         val[0] = val[0] | (amd[0] << I_V_SRC) | (amd[1] << I_V_DST);
         if (*cptr != 0) {                               /* skip? */
             cptr = get_glyph (cptr, gbuf, 0);           /* get skip */
             for (i = 0; (skip[i] != NULL) &&
                 (strcmp (skip[i], gbuf) != 0); i++) ;
-            if (skip[i] == NULL) return SCPE_ARG;
+            if (skip[i] == NULL)
+                return SCPE_ARG;
             val[0] = val[0] | (i + 1);
             }                                           /* end if */
         break;
 
     case I_V_BY:                                        /* byte */
         cptr = get_2reg (cptr, 0, amd);                 /* get 2 reg */
-        if (cptr == NULL) return SCPE_ARG;
+        if (cptr == NULL)
+            return SCPE_ARG;
         val[0] = val[0] | (amd[0] << I_V_PULSE) | (amd[1] << I_V_DST);
         break;
 
     case I_V_2AC:                                       /* reg, reg */
         cptr = get_2reg (cptr, 0, amd);                 /* get 2 reg */
-        if (cptr == NULL) return SCPE_ARG;
+        if (cptr == NULL)
+            return SCPE_ARG;
         val[0] = val[0] | (amd[0] << I_V_SRC) | (amd[1] << I_V_DST);
         break;
 
     case I_V_RSI:                                       /* reg, short imm */
         cptr = get_glyph (cptr, gbuf, ',');             /* get immediate */
         d = (int32) get_uint (gbuf, 8, I_M_SRC + 1, &r);
-        if ((d == 0) || (r != SCPE_OK)) return SCPE_ARG;
+        if ((d == 0) || (r != SCPE_OK))
+            return SCPE_ARG;
         val[0] = val[0] | ((d - 1) << I_V_SRC);         /* put in place */
         cptr = get_glyph (cptr, gbuf, 0);               /* get register */
         d = (int32) get_uint (gbuf, 8, I_M_DST, &r);
-        if (r != SCPE_OK) return SCPE_ARG;
+        if (r != SCPE_OK)
+            return SCPE_ARG;
         val[0] = val[0] | (d << I_V_DST);               /* put in place */
         break;
 
     case I_V_RLI:                                       /* reg, long imm */
         cptr = get_glyph (cptr, gbuf, ',');             /* get immediate */
         val[1] = (int32) get_uint (gbuf, 8, DMASK, &r);
-        if (r != SCPE_OK) return SCPE_ARG;
+        if (r != SCPE_OK)
+            return SCPE_ARG;
         cptr = get_glyph (cptr, gbuf, 0);               /* get register */
         d = (int32) get_uint (gbuf, 8, I_M_DST, &r);
-        if (r != SCPE_OK) return SCPE_ARG;
+        if (r != SCPE_OK)
+            return SCPE_ARG;
         val[0] = val[0] | (d << I_V_DST);               /* put in place */
         rtn = -1;
         break;
@@ -1019,18 +1123,21 @@ switch (j) {                                            /* case on class */
     case I_V_LI:                                        /* long imm */
         cptr = get_glyph (cptr, gbuf, 0);               /* get immediate */
         val[1] = (int32) get_uint (gbuf, 8, DMASK, &r);
-        if (r != SCPE_OK) return SCPE_ARG;
+        if (r != SCPE_OK)
+            return SCPE_ARG;
         rtn = -1;
         break;
 
     case I_V_RLM:                                       /* reg, long mem */
         cptr = get_glyph (cptr, gbuf, ',');             /* get register */
         d = (int32) get_uint (gbuf, 8, I_M_DST, &r);
-        if (r != SCPE_OK) return SCPE_ARG;
+        if (r != SCPE_OK)
+            return SCPE_ARG;
         val[0] = val[0] | (d << I_V_DST);               /* put in place */
     case I_V_LM:                                        /* long mem */
         cptr = get_addr (cptr, addr, TRUE, cflag, amd);
-        if (cptr == NULL) return SCPE_ARG;
+        if (cptr == NULL)
+            return SCPE_ARG;
         val[0] = val[0] | (amd[1] << I_V_MODE);
         val[1] = (amd[0] << A_V_IND) | amd[2];
         rtn = -1;
@@ -1039,10 +1146,12 @@ switch (j) {                                            /* case on class */
     case I_V_FRM:                                       /* flt reg, long mem */
         cptr = get_glyph (cptr, gbuf, ',');             /* get register */
         d = (int32) get_uint (gbuf, 8, I_M_DST, &r);
-        if (r != SCPE_OK) return SCPE_ARG;
+        if (r != SCPE_OK)
+            return SCPE_ARG;
         val[0] = val[0] | (d << I_V_DST);               /* put in place */
         cptr = get_addr (cptr, addr, TRUE, cflag, amd);
-        if (cptr == NULL) return SCPE_ARG;
+        if (cptr == NULL)
+            return SCPE_ARG;
         val[0] = val[0] | (amd[1] << I_V_SRC);
         val[1] = (amd[0] << A_V_IND) | amd[2];
         rtn = -1;
@@ -1050,7 +1159,8 @@ switch (j) {                                            /* case on class */
 
     case I_V_FST:                                       /* flt status */
         cptr = get_addr (cptr, addr, TRUE, cflag, amd);
-        if (cptr == NULL) return SCPE_ARG;
+        if (cptr == NULL)
+            return SCPE_ARG;
         val[0] = val[0] | (amd[1] << I_V_DST);
         val[1] = (amd[0] << A_V_IND) | amd[2];
         rtn = -1;
@@ -1058,15 +1168,18 @@ switch (j) {                                            /* case on class */
 
     case I_V_XP:                                        /* XOP */
         cptr = get_2reg (cptr, ',', amd);               /* get 2 reg */
-        if (cptr == NULL) return SCPE_ARG;
+        if (cptr == NULL)
+            return SCPE_ARG;
         val[0] = val[0] | (amd[0] << I_V_SRC) | (amd[1] << I_V_DST);    
         cptr = get_glyph (cptr, gbuf, 0);               /* get argument */
         d = (int32) get_uint (gbuf, 8, I_M_XOP, &r);
-        if (r != SCPE_OK) return SCPE_ARG;
+        if (r != SCPE_OK)
+            return SCPE_ARG;
         val[0] = val[0] | (d << I_V_XOP);
         break;
         }                                               /* end case */
 
-if (*cptr != 0) return SCPE_ARG;                        /* any leftovers? */
+if (*cptr != 0)                                         /* any leftovers? */
+    return SCPE_ARG;
 return rtn;
 }
