@@ -1,6 +1,6 @@
 /* pdp10_tim.c: PDP-10 tim subsystem simulator
 
-   Copyright (c) 1993-2006, Robert M Supnik
+   Copyright (c) 1993-2008, Robert M Supnik
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -25,6 +25,7 @@
 
    tim          timer subsystem
 
+   18-Jun-07    RMS     Added UNIT_IDLE flag
    03-Nov-06    RMS     Rewritten to support idling
    29-Oct-06    RMS     Added clock coscheduling function
    02-Feb-04    RMS     Exported variables needed by Ethernet simulator
@@ -104,7 +105,7 @@ extern t_stat wr_nop (int32 data, int32 PA, int32 access);
 
 DIB tcu_dib = { IOBA_TCU, IOLN_TCU, &tcu_rd, &wr_nop, 0 };
 
-UNIT tim_unit = { UDATA (&tim_svc, 0, 0), TIM_WAIT_T10 };
+UNIT tim_unit = { UDATA (&tim_svc, UNIT_IDLE, 0), TIM_WAIT_T10 };
 
 REG tim_reg[] = {
     { BRDATA (TIMEBASE, tim_base, 8, 36, 2) },
@@ -198,7 +199,7 @@ tim_ttg = tim_period;                                   /* reload */
 apr_flg = apr_flg | APRF_TIM;                           /* request interrupt */
 if (Q_ITS) {                                            /* ITS? */
     if (pi_act == 0)
-	quant = (quant + TIM_ITS_QUANT) & DMASK;
+	    quant = (quant + TIM_ITS_QUANT) & DMASK;
     if (TSTS (pcst)) {                                  /* PC sampling? */
         WriteP ((a10) pcst & AMASK, pager_PC);          /* store sample */
         pcst = AOB (pcst);                              /* add 1,,1 */
@@ -215,7 +216,8 @@ int32 clk_cosched (int32 wait)
 {
 int32 t;
 
-if (tim_mult == TIM_MULT_T20) return wait;
+if (tim_mult == TIM_MULT_T20)
+    return wait;
 t = sim_is_active (&tim_unit);
 return (t? t - 1: wait);
 }
@@ -258,7 +260,8 @@ else {
     uptr->wait = TIM_WAIT_T10;
     tmr_poll = TIM_WAIT_T10;
     tim_mult = TIM_MULT_T10;
-    if (Q_ITS) uptr->flags = uptr->flags | UNIT_Y2K;
+    if (Q_ITS)
+        uptr->flags = uptr->flags | UNIT_Y2K;
     else uptr->flags = uptr->flags & ~UNIT_Y2K;
     }
 tmxr_poll = tmr_poll * tim_mult;
@@ -274,9 +277,10 @@ struct tm *tptr;
 
 curtim = time (NULL);                                   /* get time */
 tptr = localtime (&curtim);                             /* decompose */
-if (tptr == NULL) return SCPE_NXM;                      /* Y2K prob? */
+if (tptr == NULL)
+    return SCPE_NXM; 
 if ((tptr->tm_year > 99) && !(tim_unit.flags & UNIT_Y2K))
-    tptr->tm_year = 99; 
+    tptr->tm_year = 99;                                 /* Y2K prob? */
 
 switch ((PA >> 1) & 03) {                               /* decode PA<3:1> */
 
