@@ -1,6 +1,6 @@
 /* pdp11_cpumod.c: PDP-11 CPU model-specific features
 
-   Copyright (c) 2004-2005, Robert M Supnik
+   Copyright (c) 2004-2008, Robert M Supnik
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -25,6 +25,10 @@
 
    system       PDP-11 model-specific registers
 
+   20-May-08    RMS     Added JCSR default for KDJ11B, KDJ11E
+   22-Apr-08    RMS     Fixed write behavior of 11/70 MBRK, LOSIZE, HISIZE
+                        (found by Walter Mueller)
+   29-Apr-07    RMS     Don't run bus setup routine during RESTORE
    30-Aug-05    RMS     Added additional 11/60 registers
    16-Aug-05    RMS     Fixed C++ declaration and cast problems
    15-Feb-05    RMS     Fixed bug in SHOW MODEL (from Sergey Okhapkin)
@@ -45,13 +49,15 @@
 /* Byte write macros for system registers */
 
 #define ODD_IGN(cur) \
-    if ((access == WRITEB) && (pa & 1)) return SCPE_OK
+    if ((access == WRITEB) && (pa & 1)) \
+        return SCPE_OK
 #define ODD_WO(cur) \
-    if ((access == WRITEB) && (pa & 1)) cur = cur << 8
+    if ((access == WRITEB) && (pa & 1)) \
+        cur = cur << 8
 #define ODD_MRG(prv,cur) \
-    if (access == WRITEB) cur = \
-        ((pa & 1)? (((prv) & 0377) | ((cur) & 0177400)) : \
-        (((prv) & 0177400) | ((cur) & 0377)))
+    if (access == WRITEB) \
+        cur =((pa & 1)? (((prv) & 0377) | ((cur) & 0177400)) : \
+                        (((prv) & 0177400) | ((cur) & 0377)))
 
 int32 SR = 0;                                           /* switch register */
 int32 DR = 0;                                           /* display register */
@@ -64,6 +70,7 @@ int32 CCR = 0;                                          /* cache control reg */
 int32 HITMISS = 0;                                      /* hit/miss reg */
 int32 MAINT = 0;                                        /* maint reg */
 int32 JCSR = 0;                                         /* J11 control */
+int32 JCSR_dflt = 0;                                    /* J11 boot ctl def */
 int32 JPCR = 0;                                         /* J11 page ctrl */
 int32 JASR = 0;                                         /* J11 addtl status */
 int32 UDCR = 0;                                         /* UBA diag ctrl */
@@ -83,6 +90,7 @@ extern FILE *sim_log;
 extern int32 STKLIM, PIRQ;
 extern uint32 cpu_model, cpu_type, cpu_opt;
 extern int32 clk_fie, clk_fnxm, clk_tps, clk_default;
+extern int32 sim_switches;
 
 t_stat CPU24_rd (int32 *data, int32 addr, int32 access);
 t_stat CPU24_wr (int32 data, int32 addr, int32 access);
@@ -116,6 +124,8 @@ t_stat sys_reset (DEVICE *dptr);
 int32 toy_read (void);
 void toy_write (int32 bit);
 uint8 toy_set (int32 val);
+t_stat sys_set_jclk_dflt (UNIT *uptr, int32 val, char *cptr, void *desc);
+t_stat sys_show_jclk_dflt (FILE *st, UNIT *uptr, int32 val, void *desc);
 
 extern t_stat PSW_rd (int32 *data, int32 addr, int32 access);
 extern t_stat PSW_wr (int32 data, int32 addr, int32 access);
@@ -241,6 +251,10 @@ static const char *opt_name[] = {
     "RH11", "RH70",     "PARITY", "NOPARITY", "Unibus map", "No map", NULL
     };
 
+static const char *jcsr_val[4] = {
+    "LINE", "50HZ", "60HZ", "800HZ"
+    };
+
 /* SYSTEM data structures
 
    sys_dev      SYSTEM device descriptor
@@ -262,6 +276,7 @@ REG sys_reg[] = {
     { ORDATA (WCS, WCS, 16) },
     { ORDATA (SYSID, SYSID, 16) },
     { ORDATA (JCSR, JCSR, 16) },
+    { ORDATA (JCSR_DFLT, JCSR_dflt, 16), REG_HRO },
     { ORDATA (JPCR, JPCR, 16) },
     { ORDATA (JASR, JASR, 16) },
     { ORDATA (UDCR, UDCR, 16) },
@@ -274,8 +289,14 @@ REG sys_reg[] = {
     { NULL}
     };
 
+MTAB sys_mod[] = {
+    { MTAB_XTD|MTAB_VDV|MTAB_NMO, 0, "JCLK_DFLT", "JCLK_DFLT",
+      &sys_set_jclk_dflt, &sys_show_jclk_dflt },
+    { 0 }
+    };
+
 DEVICE sys_dev = {
-    "SYSTEM", &sys_unit, sys_reg, NULL,
+    "SYSTEM", &sys_unit, sys_reg, sys_mod,
     1, 0, 0, 0, 0, 0,
     NULL, NULL, &sys_reset,
     NULL, NULL, NULL,
@@ -309,8 +330,10 @@ t_stat REG_wr (int32 data, int32 pa, int32 access)
 {
 int32 reg = pa & 07;
 
-if (access == WRITE) R[reg] = data;
-else if (pa & 1) R[reg] = (R[reg] & 0377) | (data << 8);
+if (access == WRITE)
+    R[reg] = data;
+else if (pa & 1)
+    R[reg] = (R[reg] & 0377) | (data << 8);
 else R[reg] = (R[reg] & ~0377) | data;
 return SCPE_OK;
 }
@@ -539,7 +562,11 @@ t_stat CPU70_rd (int32 *data, int32 pa, int32 access)
 {
 switch ((pa >> 1) & 017) {                              /* decode pa<4:1> */
 
-    case 000: case 001: case 011:                       /* LO,HI ERR, HI SIZE */
+    case 000:                                           /* low error */
+        *data = 0;
+        return SCPE_OK;
+
+    case 001:                                           /* high error */
         *data = 0;
         return SCPE_OK;
 
@@ -559,10 +586,14 @@ switch ((pa >> 1) & 017) {                              /* decode pa<4:1> */
         *data = HITMISS;
         return SCPE_OK;
 
-    case 010:                                           /* lower size */
+    case 010:                                           /* low size */
         *data = (MEMSIZE >> 6) - 1;
         return SCPE_OK;
 
+    case 011:                                           /* high size */
+        *data = 0;
+        return SCPE_OK;
+
     case 012:                                           /* system ID */
         *data = SYSID;
         return SCPE_OK;
@@ -608,12 +639,19 @@ switch ((pa >> 1) & 017) {                              /* decode pa<4:1> */
     case 005:                                           /* Hit/miss */
         return SCPE_OK;
 
+    case 010:                                           /* low size */
+        return SCPE_OK;
+
+    case 011:                                           /* high size */
+        return SCPE_OK;
+
     case 013:                                           /* CPUERR */
         CPUERR = 0;
         return SCPE_OK;
 
     case 014:                                           /* MBRK */
-        MBRK = data;
+        ODD_IGN (data);
+        MBRK = data & MBRK70_WR;
         return SCPE_OK;
 
     case 015:                                           /* PIRQ */
@@ -646,14 +684,19 @@ switch ((pa >> 1) & 017) {                              /* decode pa<4:1> */
 
     case 004:                                           /* MAINT */
         *data = MAINT | MAINT_NOFPA | MAINT_BPOK | (UNIBUS? MAINT_U: MAINT_Q);
-        if (CPUT (CPUT_53)) *data |= MAINT_KDJD | MAINT_POROM;
-        if (CPUT (CPUT_73)) *data |= MAINT_KDJA | MAINT_POODT;
-        if (CPUT (CPUT_73B|CPUT_83|CPUT_84)) *data |= MAINT_KDJB | MAINT_POROM;
-        if (CPUT (CPUT_93|CPUT_94)) *data |= MAINT_KDJE | MAINT_POROM;
+        if (CPUT (CPUT_53))
+            *data |= MAINT_KDJD | MAINT_POROM;
+        if (CPUT (CPUT_73))
+            *data |= MAINT_KDJA | MAINT_POODT;
+        if (CPUT (CPUT_73B|CPUT_83|CPUT_84))
+            *data |= MAINT_KDJB | MAINT_POROM;
+        if (CPUT (CPUT_93|CPUT_94))
+            *data |= MAINT_KDJE | MAINT_POROM;
         return SCPE_OK;
 
     case 005:                                           /* Hit/miss */
-        if (CPUT (CPUT_73B)) *data = 0;                 /* must be 0 for 73B */
+        if (CPUT (CPUT_73B))                            /* must be 0 for 73B */
+            *data = 0;
         else *data = HITMISS | 010;                     /* must be nz for 11/8X */
         return SCPE_OK;
 
@@ -778,12 +821,15 @@ switch ((pa >> 1) & 03) {                               /* decode pa<2:1> */
     case 0:                                             /* CSR */
         ODD_MRG (JCSR, data);
         JCSR = (JCSR & ~CSRJB_WR) | (data & CSRJB_WR);
-        if (JCSR & CSRJ_LTCI) clk_fie = 1;              /* force LTC int enb? */
+        if (JCSR & CSRJ_LTCI)                           /* force LTC int enb? */
+            clk_fie = 1;
         else clk_fie = 0;
-        if (JCSR & CSRJ_LTCD) clk_fnxm = 1;             /* force LTC reg nxm? */
+        if (JCSR & CSRJ_LTCD)                           /* force LTC reg nxm? */
+            clk_fnxm = 1;
         else clk_fnxm = 0;
         t = CSRJ_LTCSEL (JCSR);                         /* get freq sel */
-        if (t) clk_tps = clk_tps_map[t];
+        if (t)
+            clk_tps = clk_tps_map[t];
         else clk_tps = clk_default;
         return SCPE_OK;
 
@@ -866,12 +912,15 @@ switch ((pa >> 1) & 03) {                               /* decode pa<2:1> */
     case 0:                                             /* CSR */
         ODD_MRG (JCSR, data);
         JCSR = (JCSR & ~CSRJE_WR) | (data & CSRJE_WR);
-        if (JCSR & CSRJ_LTCI) clk_fie = 1;              /* force LTC int enb? */
+        if (JCSR & CSRJ_LTCI)                           /* force LTC int enb? */
+            clk_fie = 1;
         else clk_fie = 0;
-        if (JCSR & CSRJ_LTCD) clk_fnxm = 1;             /* force LTC reg nxm? */
+        if (JCSR & CSRJ_LTCD)                           /* force LTC reg nxm? */
+            clk_fnxm = 1;
         else clk_fnxm = 0;
         t = CSRJ_LTCSEL (JCSR);                         /* get freq sel */
-        if (t) clk_tps = clk_tps_map[t];
+        if (t)
+            clk_tps = clk_tps_map[t];
         else clk_tps = clk_default;
         return SCPE_OK;
 
@@ -982,9 +1031,11 @@ int32 bit;
 
 if (toy_state == 0) {
     curr = time (NULL);                                 /* get curr time */
-    if (curr == (time_t) -1) return 0;                  /* error? */
+    if (curr == (time_t) -1)                            /* error? */
+        return 0;
     ctm = localtime (&curr);                            /* decompose */
-    if (ctm == NULL) return 0;                          /* error? */
+    if (ctm == NULL)                                    /* error? */
+        return 0;
     toy_data[TOY_HSEC] = 0x50;
     toy_data[TOY_SEC] = toy_set (ctm->tm_sec);
     toy_data[TOY_MIN] = toy_set (ctm->tm_min);
@@ -1035,12 +1086,16 @@ return SCPE_OK;
 
 t_stat cpu_set_model (UNIT *uptr, int32 val, char *cptr, void *desc)
 {
-if (cptr != NULL) return SCPE_ARG;
-if (val >= MOD_MAX) return SCPE_IERR;
-if (val == (int32) cpu_model) return SCPE_OK;
+if (cptr != NULL)
+    return SCPE_ARG;
+if (val >= MOD_MAX)
+    return SCPE_IERR;
+if (val == (int32) cpu_model)
+    return SCPE_OK;
 if (MEMSIZE > cpu_tab[val].maxm)
     cpu_set_size (uptr, cpu_tab[val].maxm, NULL, NULL);
-if (MEMSIZE > cpu_tab[val].maxm) return SCPE_INCOMP;
+if (MEMSIZE > cpu_tab[val].maxm)
+    return SCPE_INCOMP;
 cpu_model = val;
 cpu_type = 1u << cpu_model;
 cpu_opt = cpu_tab[cpu_model].std;
@@ -1056,8 +1111,9 @@ uint32 i, all_opt;
 fprintf (st, "%s", cpu_tab[cpu_model].name);
 all_opt = cpu_tab[cpu_model].opt;
 for (i = 0; opt_name[2 * i] != NULL; i++) {
-    if ((all_opt >> i) & 1) fprintf (st, ", %s",
-        ((cpu_opt >> i) & 1)? opt_name[2 * i]: opt_name[(2 * i) + 1]);
+    if ((all_opt >> i) & 1)
+        fprintf (st, ", %s",
+                ((cpu_opt >> i) & 1)? opt_name[2 * i]: opt_name[(2 * i) + 1]);
     }   
 return SCPE_OK;
 }
@@ -1066,16 +1122,20 @@ return SCPE_OK;
 
 t_stat cpu_set_opt (UNIT *uptr, int32 val, char *cptr, void *desc)
 {
-if (cptr) return SCPE_ARG;
-if ((val & cpu_tab[cpu_model].opt) == 0) return SCPE_ARG;
+if (cptr)
+    return SCPE_ARG;
+if ((val & cpu_tab[cpu_model].opt) == 0)
+    return SCPE_ARG;
 cpu_opt = cpu_opt | val;
 return SCPE_OK;
 }
 
 t_stat cpu_clr_opt (UNIT *uptr, int32 val, char *cptr, void *desc)
 {
-if (cptr) return SCPE_ARG;
-if ((val & cpu_tab[cpu_model].opt) == 0) return SCPE_ARG;
+if (cptr)
+    return SCPE_ARG;
+if ((val & cpu_tab[cpu_model].opt) == 0)
+    return SCPE_ARG;
 cpu_opt = cpu_opt & ~val;
 return SCPE_OK;
 }
@@ -1088,19 +1148,25 @@ int32 mc = 0;
 uint32 i, clim;
 uint16 *nM;
 
-if ((val <= 0) || (val > (int32) cpu_tab[cpu_model].maxm) ||
-    ((val & 07777) != 0)) return SCPE_ARG;
-for (i = val; i < MEMSIZE; i = i + 2) mc = mc | M[i >> 1];
+if ((val <= 0) ||
+    (val > (int32) cpu_tab[cpu_model].maxm) ||
+    ((val & 07777) != 0))
+    return SCPE_ARG;
+for (i = val; i < MEMSIZE; i = i + 2)
+    mc = mc | M[i >> 1];
 if ((mc != 0) && !get_yn ("Really truncate memory [N]?", FALSE))
     return SCPE_OK;
 nM = (uint16 *) calloc (val >> 1, sizeof (uint16));
-if (nM == NULL) return SCPE_MEM;
+if (nM == NULL)
+    return SCPE_MEM;
 clim = (((t_addr) val) < MEMSIZE)? val: MEMSIZE;
-for (i = 0; i < clim; i = i + 2) nM[i >> 1] = M[i >> 1];
+for (i = 0; i < clim; i = i + 2)
+    nM[i >> 1] = M[i >> 1];
 free (M);
 M = nM;
 MEMSIZE = val;
-cpu_set_bus (cpu_opt);
+if (!(sim_switches & SIM_SW_REST))                      /* unless restore, */
+    cpu_set_bus (cpu_opt);                              /* alter periph config */
 return SCPE_OK;
 }
 
@@ -1111,7 +1177,8 @@ t_stat cpu_set_bus (int32 opt)
 DEVICE *dptr;
 uint32 i, mask;
 
-if (opt & BUS_U) mask = DEV_UBUS;                       /* Unibus variant? */
+if (opt & BUS_U)                                        /* Unibus variant? */
+    mask = DEV_UBUS;
 else if (MEMSIZE <= UNIMEMSIZE)                         /* 18b Qbus devices? */
     mask = DEV_QBUS | DEV_Q18;
 else mask = DEV_QBUS;                                   /* must be 22b */
@@ -1120,7 +1187,8 @@ for (i = 0; (dptr = sim_devices[i]) != NULL; i++) {
         !(dptr->flags & DEV_DIS) &&                     /* enabled? */
         ((dptr->flags & mask) == 0)) {                  /* not allowed? */
         printf ("Disabling %s\n", sim_dname (dptr));
-        if (sim_log) fprintf (sim_log, "Disabling %s\n", sim_dname (dptr));
+        if (sim_log)
+            fprintf (sim_log, "Disabling %s\n", sim_dname (dptr));
         dptr->flags = dptr->flags | DEV_DIS;
         }
     }
@@ -1137,10 +1205,13 @@ CCR = 0;
 HITMISS = 0;
 CPUERR = 0;
 MEMERR = 0;
-if (!CPUT (CPUT_J)) MAINT = 0;
+if (!CPUT (CPUT_J))
+    MAINT = 0;
 MBRK = 0;
 WCS = 0;
-JCSR = 0;
+if (CPUT (CPUT_JB|CPUT_JE))
+    JCSR = JCSR_dflt;
+else JCSR = 0;
 JPCR = 0;
 JASR = 0;
 UDCR = 0;
@@ -1149,7 +1220,34 @@ UCSR = 0;
 uba_last = 0;
 DR = 0;
 toy_state = 0;
-for (i = 0; i < UBM_LNT_LW; i++) ub_map[i] = 0;
-for (i = 0; i < TOY_LNT; i++) toy_data[i] = 0;
+for (i = 0; i < UBM_LNT_LW; i++)
+    ub_map[i] = 0;
+for (i = 0; i < TOY_LNT; i++)
+    toy_data[i] = 0;
+return SCPE_OK;
+}
+
+/* Set/show JCLK default values */
+
+t_stat sys_set_jclk_dflt (UNIT *uptr, int32 val, char *cptr, void *desc)
+{
+uint32 i;
+
+if ((CPUT (CPUT_JB|CPUT_JE)) && cptr) {
+    for (i = 0; i < 4; i++) {
+        if (strncmp (cptr, jcsr_val[i], strlen (cptr)) == 0) {
+            JCSR_dflt = i << CSRJ_V_LTCSEL;
+            return SCPE_OK;
+            }
+        }
+    }
+return SCPE_ARG;
+}
+
+t_stat sys_show_jclk_dflt (FILE *st, UNIT *uptr, int32 val, void *desc)
+{
+if (CPUT (CPUT_JB|CPUT_JE))
+    fprintf (st, "JCLK default=%s\n", jcsr_val[CSRJ_LTCSEL (JCSR_dflt)]);
+else fprintf (st, "Not implemented\n");
 return SCPE_OK;
 }
