@@ -1,6 +1,6 @@
 /* pdp11_defs.h: PDP-11 simulator definitions
 
-   Copyright (c) 1993-2006, Robert M Supnik
+   Copyright (c) 1993-2008, Robert M Supnik
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -26,6 +26,12 @@
    The author gratefully acknowledges the help of Max Burnet, Megan Gentry,
    and John Wilson in resolving questions about the PDP-11
 
+   19-Nov-08    RMS     Moved I/O support routines to I/O library
+   16-May-08    RMS     Added KE11A, DC11 support
+   02-Feb-08    RMS     Fixed DMA memory address limit test (found by John Dundas)
+   25-Jan-08    RMS     Added RC11, KG11A support (from John Dundas)
+   16-Dec-06    RMS     Added TA11 support
+   29-Oct-06    RMS     Added clock coscheduling
    06-Jul-06    RMS     Added multiple KL11/DL11 support
    26-Jun-06    RMS     Added RF11 support
    24-May-06    RMS     Added 11/44 DR support (from CIS diagnostic)
@@ -90,7 +96,7 @@
 #define MAXMEMSIZE      020000000                       /* 2**22 */
 #define PAMASK          (MAXMEMSIZE - 1)                /* 2**22 - 1 */
 #define MEMSIZE         (cpu_unit.capac)
-#define ADDR_IS_MEM(x)  (((t_addr) (x)) < MEMSIZE)
+#define ADDR_IS_MEM(x)  (((t_addr) (x)) < cpu_memsize)  /* use only in sim! */
 #define DMASK           0177777
 
 /* CPU models */
@@ -467,7 +473,8 @@ typedef struct {
 #define DZ_MUXES        4                               /* max # of DZ muxes */
 #define DZ_LINES        8                               /* lines per DZ mux */
 #define VH_MUXES        4                               /* max # of VH muxes */
-#define TTX_LINES       16                              /* max # of KL11/DL11's */
+#define DLX_LINES       16                              /* max # of KL11/DL11's */
+#define DCX_LINES       16                              /* max # of DC11's */
 #define MT_MAXFR        (1 << 16)                       /* magtape max rec */
 #define AUTO_LNT        34                              /* autoconfig ranks */
 #define DIB_MAX         100                             /* max DIBs */
@@ -519,6 +526,8 @@ typedef struct pdp_dib DIB;
 #define IOLN_VH         020
 #define IOBA_UBM        (IOPAGEBASE + 010200)           /* Unibus map */
 #define IOLN_UBM        (UBM_LNT_LW * sizeof (int32))
+#define	IOBA_KG         (IOPAGEBASE + 010700)           /* KG11-A */
+#define	IOLN_KG         006
 #define IOBA_RQ         (IOPAGEBASE + 012150)           /* RQDX3 */
 #define IOLN_RQ         004
 #define IOBA_SUP        (IOPAGEBASE + 012200)           /* supervisor APR's */
@@ -541,6 +550,8 @@ typedef struct pdp_dib DIB;
 #define IOLN_TS         004
 #define IOBA_PCLK       (IOPAGEBASE + 012540)           /* KW11P */
 #define IOLN_PCLK       006
+#define IOBA_DC         (IOPAGEBASE + 014000)           /* DC11 */
+#define IOLN_DC         (DCX_LINES * 010)
 #define IOBA_RL         (IOPAGEBASE + 014400)           /* RL11 */
 #define IOLN_RL         012
 #define IOBA_XQ         (IOPAGEBASE + 014440)           /* DEQNA/DELQA */
@@ -551,8 +562,8 @@ typedef struct pdp_dib DIB;
 #define IOLN_TQ         004
 #define IOBA_XU         (IOPAGEBASE + 014510)           /* DEUNA/DELUA */
 #define IOLN_XU         010
-#define IOBA_TTIX       (IOPAGEBASE + 016500)           /* extra KL11/DL11 */
-#define IOLN_TTIX       (TTX_LINES * 010)
+#define IOBA_DL         (IOPAGEBASE + 016500)           /* extra KL11/DL11 */
+#define IOLN_DL         (DLX_LINES * 010)
 #define IOBA_RP         (IOPAGEBASE + 016700)           /* RP/RM */
 #define IOLN_RP         054
 #define IOBA_CR         (IOPAGEBASE + 017160)           /* CD/CR/CM */
@@ -561,14 +572,22 @@ typedef struct pdp_dib DIB;
 #define IOLN_RX         004
 #define IOBA_RY         (IOPAGEBASE + 017170)           /* RY11 */
 #define IOLN_RY         004
+#define IOBA_KE         (IOPAGEBASE + 017300)           /* KE11-A */
+#define IOLN_KE         020
 #define IOBA_TC         (IOPAGEBASE + 017340)           /* TC11 */
 #define IOLN_TC         012
+#define IOBA_QDSS       (IOPAGEBASE + 017400)           /* QDSS */
+#define IOLN_QDSS       002
 #define IOBA_RK         (IOPAGEBASE + 017400)           /* RK11 */
 #define IOLN_RK         020
+#define IOBA_RC         (IOPAGEBASE + 017440)           /* RC11/RS64 */
+#define IOLN_RC         020
 #define IOBA_HK         (IOPAGEBASE + 017440)           /* RK611 */
 #define IOLN_HK         040
 #define IOBA_RF         (IOPAGEBASE + 017460)           /* RF11 */
 #define IOLN_RF         020
+#define IOBA_TA         (IOPAGEBASE + 017500)           /* TA11 */
+#define IOLN_TA         004
 #define IOBA_LPT        (IOPAGEBASE + 017514)           /* LP11 */
 #define IOLN_LPT        004
 #define IOBA_CTL        (IOPAGEBASE + 017520)           /* board ctrl */
@@ -613,7 +632,8 @@ typedef struct pdp_dib DIB;
 #define INT_V_CLK       0                               /* BR6 */
 #define INT_V_PCLK      1
 #define INT_V_DTA       2
-#define INT_V_PIR6      3
+#define INT_V_TA        3
+#define INT_V_PIR6      4
 
 #define INT_V_RK        0                               /* BR5 */
 #define INT_V_RL        1
@@ -631,7 +651,8 @@ typedef struct pdp_dib DIB;
 #define INT_V_XU        13
 #define INT_V_TU        14
 #define INT_V_RF        15
-#define INT_V_PIR5      16
+#define INT_V_RC        16
+#define INT_V_PIR5      17
 
 #define INT_V_TTI       0                               /* BR4 */
 #define INT_V_TTO       1
@@ -641,9 +662,11 @@ typedef struct pdp_dib DIB;
 #define INT_V_VHRX      5
 #define INT_V_VHTX      6  
 #define INT_V_CR        7
-#define INT_V_TTIX      8
-#define INT_V_TTOX      9
-#define INT_V_PIR4      10
+#define INT_V_DLI       8
+#define INT_V_DLO       9
+#define INT_V_DCI       10
+#define INT_V_DCO       11
+#define INT_V_PIR4      12
 
 #define INT_V_PIR3      0                               /* BR3 */
 #define INT_V_PIR2      0                               /* BR2 */
@@ -653,6 +676,7 @@ typedef struct pdp_dib DIB;
 #define INT_CLK         (1u << INT_V_CLK)
 #define INT_PCLK        (1u << INT_V_PCLK)
 #define INT_DTA         (1u << INT_V_DTA)
+#define INT_TA          (1u << INT_V_TA)
 #define INT_PIR6        (1u << INT_V_PIR6)
 #define INT_RK          (1u << INT_V_RK)
 #define INT_RL          (1u << INT_V_RL)
@@ -670,6 +694,7 @@ typedef struct pdp_dib DIB;
 #define INT_XU          (1u << INT_V_XU)
 #define INT_TU          (1u << INT_V_TU)
 #define INT_RF          (1u << INT_V_RF)
+#define INT_RC          (1u << INT_V_RC)
 #define INT_PIR5        (1u << INT_V_PIR5)
 #define INT_PTR         (1u << INT_V_PTR)
 #define INT_PTP         (1u << INT_V_PTP)
@@ -679,8 +704,10 @@ typedef struct pdp_dib DIB;
 #define INT_VHRX        (1u << INT_V_VHRX)
 #define INT_VHTX        (1u << INT_V_VHTX)
 #define INT_CR          (1u << INT_V_CR)
-#define INT_TTIX        (1u << INT_V_TTIX)
-#define INT_TTOX        (1u << INT_V_TTOX)
+#define INT_DLI         (1u << INT_V_DLI)
+#define INT_DLO         (1u << INT_V_DLO)
+#define INT_DCI         (1u << INT_V_DCI)
+#define INT_DCO         (1u << INT_V_DCO)
 #define INT_PIR4        (1u << INT_V_PIR4)
 #define INT_PIR3        (1u << INT_V_PIR3)
 #define INT_PIR2        (1u << INT_V_PIR2)
@@ -689,6 +716,7 @@ typedef struct pdp_dib DIB;
 #define IPL_CLK         6                               /* int pri levels */
 #define IPL_PCLK        6
 #define IPL_DTA         6
+#define IPL_TA          6
 #define IPL_RK          5
 #define IPL_RL          5
 #define IPL_RX          5
@@ -705,6 +733,7 @@ typedef struct pdp_dib DIB;
 #define IPL_XU          5
 #define IPL_TU          5
 #define IPL_RF          5
+#define IPL_RC          5
 #define IPL_PTR         4
 #define IPL_PTP         4
 #define IPL_TTI         4
@@ -713,8 +742,10 @@ typedef struct pdp_dib DIB;
 #define IPL_VHRX        4
 #define IPL_VHTX        4
 #define IPL_CR          4
-#define IPL_TTIX        4
-#define IPL_TTOX        4
+#define IPL_DLI         4
+#define IPL_DLO         4
+#define IPL_DCI         4
+#define IPL_DCO         4
 
 #define IPL_PIR7        7
 #define IPL_PIR6        6
@@ -741,6 +772,7 @@ typedef struct pdp_dib DIB;
 #define VEC_LPT         0200
 #define VEC_RF          0204
 #define VEC_HK          0210
+#define VEC_RC          0210
 #define VEC_RK          0220
 #define VEC_DTA         0214
 #define VEC_TM          0224
@@ -749,10 +781,13 @@ typedef struct pdp_dib DIB;
 #define VEC_CR          0230
 #define VEC_RP          0254
 #define VEC_TQ          0260
+#define VEC_TA          0260
 #define VEC_RX          0264
 #define VEC_RY          0264
-#define VEC_TTIX        0300
-#define VEC_TTOX        0304
+#define VEC_DLI         0300
+#define VEC_DLO         0304
+#define VEC_DCI         0300
+#define VEC_DCO         0304
 #define VEC_DZRX        0300
 #define VEC_DZTX        0304
 #define VEC_VHRX        0310
@@ -791,14 +826,6 @@ int32 Map_ReadW (uint32 ba, int32 bc, uint16 *buf);
 int32 Map_WriteB (uint32 ba, int32 bc, uint8 *buf);
 int32 Map_WriteW (uint32 ba, int32 bc, uint16 *buf);
 
-t_stat set_addr (UNIT *uptr, int32 val, char *cptr, void *desc);
-t_stat show_addr (FILE *st, UNIT *uptr, int32 val, void *desc);
-t_stat set_addr_flt (UNIT *uptr, int32 val, char *cptr, void *desc);
-t_stat set_vec (UNIT *uptr, int32 val, char *cptr, void *desc);
-t_stat show_vec (FILE *st, UNIT *uptr, int32 val, void *desc);
-t_stat auto_config (char *name, int32 nctrl);
-t_stat build_ubus_tab (DEVICE *dptr, DIB *dibp);
-
 int32 mba_rdbufW (uint32 mbus, int32 bc, uint16 *buf);
 int32 mba_wrbufW (uint32 mbus, int32 bc, uint16 *buf);
 int32 mba_chbufW (uint32 mbus, int32 bc, uint16 *buf);
@@ -810,4 +837,8 @@ void mba_set_don (uint32 mbus);
 void mba_set_enbdis (uint32 mb, t_bool dis);
 t_stat mba_show_num (FILE *st, UNIT *uptr, int32 val, void *desc);
 
+int32 clk_cosched (int32 wait);
+
+#include "pdp11_io_lib.h"
+
 #endif
