@@ -1,6 +1,6 @@
 /* pdp11_hk.c - RK611/RK06/RK07 disk controller
 
-   Copyright (c) 1993-2005, Robert M Supnik
+   Copyright (c) 1993-2008, Robert M Supnik
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -25,6 +25,8 @@
 
    hk           RK611/RK06/RK07 disk
 
+   29-Apr-07    RMS     NOP and DCLR (at least) do not check drive type
+                        MR2 and MR3 only updated on NOP
    17-Nov-05    RMS     Removed unused variable
    13-Nov-05    RMS     Fixed overlapped seek interaction with NOP, DCLR, PACK
    16-Aug-05    RMS     Fixed C++ declaration and cast problems
@@ -314,6 +316,12 @@ extern uint16 *M;
 #define RDH2_V_DHA      5                               /* decoded head */
 #define RDH2_GOOD       0140000                         /* good sector flags */
 
+/* Debug detail levels */
+
+#define HKDEB_OPS       001                             /* transactions */
+#define HKDEB_RRD       002                             /* reg reads */
+#define HKDEB_RWR       004                             /* reg writes */
+
 extern int32 int_req[IPL_HLVL];
 extern FILE *sim_deb;
 
@@ -338,7 +346,7 @@ int32 hk_min2wait = 300;                                /* min time to 2nd int *
 int16 hkdb[3] = { 0 };                                  /* data buffer silo */
 int16 hk_off[HK_NUMDR] = { 0 };                         /* saved offset */
 int16 hk_dif[HK_NUMDR] = { 0 };                         /* cylinder diff */
-static int32 reg_in_drive[16] = {
+static uint8 reg_in_drive[16] = {
  0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
 
 DEVICE hk_dev;
@@ -358,8 +366,6 @@ void hk_go (int32 drv);
 t_stat hk_set_size (UNIT *uptr, int32 val, char *cptr, void *desc);
 t_stat hk_set_bad (UNIT *uptr, int32 val, char *cptr, void *desc);
 
-extern t_stat pdp11_bad_block (UNIT *uptr, int32 sec, int32 wds);
-
 /* HK data structures
 
    hk_dev       HK device descriptor
@@ -453,12 +459,20 @@ MTAB hk_mod[] = {
     { 0 }
     };
 
+DEBTAB hk_deb[] = {
+    { "OPS", HKDEB_OPS },
+    { "RRD", HKDEB_RRD },
+    { "RWR", HKDEB_RWR },
+    { NULL, 0 }
+    };
+
 DEVICE hk_dev = {
     "HK", hk_unit, hk_reg, hk_mod,
     HK_NUMDR, DEV_RDX, 24, 1, DEV_RDX, 16,
     NULL, NULL, &hk_reset,
     &hk_boot, &hk_attach, &hk_detach,
-    &hk_dib, DEV_DISABLE | DEV_UBUS | DEV_Q18 | DEV_DEBUG
+    &hk_dib, DEV_DISABLE | DEV_UBUS | DEV_Q18 | DEV_DEBUG, 0,
+    hk_deb, NULL, 0
     };
 
 /* I/O dispatch routines, I/O addresses 17777440 - 17777476 */
@@ -509,8 +523,10 @@ switch (j) {                                            /* decode PA<4:1> */
 
     case 007:                                           /* HKAS */
         *data = hkof;
-        for (i = 0; i < HK_NUMDR; i++)
-            if (hkds[i] & DS_ATA) *data = *data | (AS_U0 << i);
+        for (i = 0; i < HK_NUMDR; i++) {
+            if (hkds[i] & DS_ATA)
+                *data = *data | (AS_U0 << i);
+            }
         break;
 
     case 010:                                           /* HKDC */
@@ -538,14 +554,16 @@ switch (j) {                                            /* decode PA<4:1> */
         break;
 
     case 016:                                           /* HKMR2 */
-        *data = hkmr2 = hk_rdmr2 (GET_MS (hkmr));
+        *data = hkmr2;
         break;
 
     case 017:                                           /* HKMR3 */
-        *data = hkmr3 = hk_rdmr3 (GET_MS (hkmr));
+        *data = hkmr3;
         break;
         }
 
+if (DEBUG_PRI (hk_dev, HKDEB_RRD))
+    fprintf (sim_deb, ">>HK%d read: reg%d=%o\n", drv, j, *data);
 return SCPE_OK;
 }
 
@@ -560,11 +578,13 @@ j = (PA >> 1) & 017;                                    /* get reg offset */
 if ((hkcs1 & CS1_GO) &&                                 /* busy? */
     !(((j == 0) && (data & CS1_CCLR)) ||                /* not cclr or sclr? */
       ((j == 4) && (data & CS2_CLR)))) {
-        hkcs2 = hkcs2 | CS2_PGE;                        /* prog error */
-        update_hkcs (0, drv);
-        return SCPE_OK;
-        }
+    hkcs2 = hkcs2 | CS2_PGE;                            /* prog error */
+    update_hkcs (0, drv);
+    return SCPE_OK;
+    }
 
+if (DEBUG_PRI (hk_dev, HKDEB_RWR))
+    fprintf (sim_deb, ">>HK%d write: reg%d=%o\n", drv, j, data);
 switch (j) {                                            /* decode PA<4:1> */
 
     case 000:                                           /* HKCS1 */
@@ -579,17 +599,19 @@ switch (j) {                                            /* decode PA<4:1> */
             for (i = 0; i < HK_NUMDR; i++) {            /* stop data xfr */
                 if (sim_is_active (&hk_unit[i]) &&
                     ((uptr->FNC & CS1_M_FNC) >= FNC_XFER))
-                sim_cancel (&hk_unit[i]);
+                    sim_cancel (&hk_unit[i]);
                 }
             drv = 0;
             break;
             }
         if (data & CS1_IE) {                            /* setting IE? */
-            if (data & CS1_DONE) SET_INT (HK);          /* write to DONE+IE? */
+            if (data & CS1_DONE)                        /* write to DONE+IE? */
+                SET_INT (HK);
             }
         else CLR_INT (HK);                              /* no, clr intr */
         hkcs1 = (hkcs1 & ~CS1_RW) | (data & CS1_RW);    /* merge data */
-        if (SC02C) hkspr = (hkspr & ~CS1_M_UAE) | GET_UAE (hkcs1);
+        if (SC02C)
+            hkspr = (hkspr & ~CS1_M_UAE) | GET_UAE (hkcs1);
         if ((data & CS1_GO) && !(hkcs1 & CS1_ERR))      /* go? */
             hk_go (drv);
         break;  
@@ -607,7 +629,8 @@ switch (j) {                                            /* decode PA<4:1> */
         break;
 
     case 004:                                           /* HKCS2 */
-        if (data & CS2_CLR) hk_reset (&hk_dev);         /* init? */
+        if (data & CS2_CLR)                             /* init? */
+            hk_reset (&hk_dev);
         else hkcs2 = (hkcs2 & ~CS2_RW) | (data & CS2_RW) | CS2_IR;
         drv = GET_UNIT (hkcs2);
         break;
@@ -622,7 +645,8 @@ switch (j) {                                            /* decode PA<4:1> */
 
     case 011:                                           /* spare */
         hkspr = data;
-        if (SC02C) hkcs1 = PUT_UAE (hkcs1, hkspr & 03); /* SC02C? upd UAE */
+        if (SC02C)                                      /* SC02C? upd UAE */
+            hkcs1 = PUT_UAE (hkcs1, hkspr & 03);
         break;
 
     case 012:                                           /* HKDB */
@@ -648,35 +672,40 @@ void hk_go (int32 drv)
 int32 fnc, t;
 UNIT *uptr;
 
-static int32 fnc_nxf[16] = {
+static uint8 fnc_cdt[16] = {
+    0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1
+    };
+
+static uint8 fnc_nxf[16] = {
     0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 1, 0, 0, 0
     };
-static int32 fnc_att[16] = {
+static uint8 fnc_att[16] = {
     0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0
     };
-static int32 fnc_rdy[16] = {
+static uint8 fnc_rdy[16] = {
     0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0
     };
-static int32 fnc_cyl[16] = {
+static uint8 fnc_cyl[16] = {
     0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 0, 0, 0
     };
 
 fnc = GET_FNC (hkcs1);
-if (DEBUG_PRS (hk_dev)) fprintf (sim_deb,
-    ">>HK%d go: fnc=%o, ds=%o, cyl=%o, da=%o, ba=%o, wc=%o\n",
-    drv, fnc, hkds[drv], hkdc, hkda, hkba, hkwc);
+if (DEBUG_PRI (hk_dev, HKDEB_OPS))
+    fprintf (sim_deb, ">>HK%d strt: fnc=%o, cs1=%o, cs2=%o, ds=%o, er=%o, cyl=%o, da=%o, ba=%o, wc=%o\n",
+             drv, fnc, hkcs1, hkcs2, hkds[drv], hker[drv], hkdc, hkda, hkba, hkwc);
 uptr = hk_dev.units + drv;                              /* get unit */
-if (fnc != FNC_NOP) hkmr = hkmr & ~MR_MS;               /* !nop, clr msg sel */
+if (fnc != FNC_NOP)                                     /* !nop, clr msg sel */
+    hkmr = hkmr & ~MR_MS;
 if (uptr->flags & UNIT_DIS) {                           /* nx unit? */
     hkcs2 = hkcs2 | CS2_NED;                            /* set error flag */
     update_hkcs (CS1_DONE, drv);                        /* done */
     return;
     }
-if (((hkcs1 & CS1_DT) != 0) !=                          /* dtype mismatch? */
-    ((uptr->flags & UNIT_DTYPE) != 0)) {
-        hk_cmderr (ER_DTY, drv);                        /* type error */
-        return;
-        }
+if (fnc_cdt[fnc] &&                                     /* need dtype match? */
+    (((hkcs1 & CS1_DT) != 0) != ((uptr->flags & UNIT_DTYPE) != 0))) {
+    hk_cmderr (ER_DTY, drv);                            /* type error */
+    return;
+    }
 if (fnc_nxf[fnc] && ((hkds[drv] & DS_VV) == 0)) {       /* need vol valid? */
     hk_cmderr (ER_NXF, drv);                            /* non exec func */
     return;
@@ -685,7 +714,8 @@ if (fnc_att[fnc] && !(uptr->flags & UNIT_ATT)) {        /* need attached? */
     hk_cmderr (ER_UNS, drv);                            /* unsafe */
     return;
     }
-if (fnc_rdy[fnc] && sim_is_active (uptr)) return;       /* need inactive? */
+if (fnc_rdy[fnc] && sim_is_active (uptr))               /* need inactive? */
+    return;
 if (fnc_cyl[fnc] &&                                     /* need valid cyl */
    ((GET_CY (hkdc) >= HK_CYL (uptr)) ||                 /* bad cylinder */
     (GET_SF (hkda) >= HK_NUMSF) ||                      /* bad surface */
@@ -699,10 +729,15 @@ switch (fnc) {                                          /* case on function */
 
 /* Instantaneous functions (unit may be busy, can't schedule thread) */
 
+    case FNC_NOP:                                       /* no operation */
+        hkmr2 = hk_rdmr2 (GET_MS (hkmr));               /* get serial msgs */
+        hkmr3 = hk_rdmr3 (GET_MS (hkmr));
+        update_hkcs (CS1_DONE, drv);                    /* done */
+        break;
+
     case FNC_DCLR:                                      /* drive clear */
         hkds[drv] &= ~DS_ATA;                           /* clr ATA */        
         hker[drv] = 0;                                  /* clear errors */
-    case FNC_NOP:                                       /* no operation */
         update_hkcs (CS1_DONE, drv);                    /* done */
         break;
 
@@ -740,7 +775,7 @@ switch (fnc) {                                          /* case on function */
     case FNC_READH:                                     /* read headers */
         hk_dif[drv] = hkdc - uptr->CYL;                 /* cyl diff */
         t = abs (hk_dif[drv]);                          /* |cyl diff| */
-        sim_activate (uptr, hk_rwait + (hk_swait * t)); /* Schedule */
+        sim_activate (uptr, hk_rwait + (hk_swait * t)); /* schedule */
         uptr->FNC = fnc;                                /* save function */
         uptr->CYL = hkdc;                               /* update cyl */
         return;
@@ -807,7 +842,8 @@ switch (fnc) {                                          /* case on function */
             dc = (fnc == FNC_SEEK)? hkdc: 0;            /* get cyl */
             hk_dif[drv] = dc - uptr->CYL;               /* cyl diff */
             t = abs (hk_dif[drv]) * hk_swait;           /* |cyl diff| */
-            if (t < hk_min2wait) t = hk_min2wait;       /* min time */
+            if (t < hk_min2wait)                        /* min time */
+                t = hk_min2wait;
             uptr->CYL = dc;                             /* save cyl */          
             sim_activate (uptr, t);                     /* schedule */
             update_hkcs (CS1_DONE, drv);                /* done */
@@ -831,7 +867,8 @@ switch (fnc) {                                          /* case on function */
             }
     case FNC_WCHK:                                      /* write check */
     case FNC_READ:                                      /* read */
-        if (SC02C) ba = ((hkspr & XM_MMASK) << 16) | hkba;      /* 22b addr? */
+        if (SC02C)                                      /* 22b addr? */
+            ba = ((hkspr & XM_MMASK) << 16) | hkba;
         else ba = (GET_UAE (hkcs1) << 16) | hkba;       /* no, 18b addr */
         da = GET_DA (hkdc, hkda) * HK_NUMWD;            /* get disk addr */
         wc = 0200000 - hkwc;                            /* get true wc */
@@ -853,7 +890,8 @@ switch (fnc) {                                          /* case on function */
                     wc = 0;                             /* NXM, no xfr */
                     hkcs2 = hkcs2 | CS2_NEM;            /* set nxm err */
                     }
-                for (i = 0; i < wc; i++) hkxb[i] = comp;
+                for (i = 0; i < wc; i++)
+                    hkxb[i] = comp;
                 }
             else {                                      /* normal */
                 if (t = Map_ReadW (ba, wc << 1, hkxb)) { /* get buf */
@@ -863,7 +901,8 @@ switch (fnc) {                                          /* case on function */
                 ba = ba + (wc << 1);                    /* adv ba */
                 }
             awc = (wc + (HK_NUMWD - 1)) & ~(HK_NUMWD - 1);
-            for (i = wc; i < awc; i++) hkxb[i] = 0;     /* fill buf */
+            for (i = wc; i < awc; i++)                  /* fill buf */
+                hkxb[i] = 0;
             if (wc && !err) {                           /* write buf */
                 fxwrite (hkxb, sizeof (uint16), wc, uptr->fileref);
                 err = ferror (uptr->fileref);
@@ -872,7 +911,8 @@ switch (fnc) {                                          /* case on function */
         else if (uptr->FNC == FNC_READ) {               /* read? */
             i = fxread (hkxb, sizeof (uint16), wc, uptr->fileref);
             err = ferror (uptr->fileref);
-            for ( ; i < wc; i++) hkxb[i] = 0;           /* fill buf */
+            for ( ; i < wc; i++)                        /* fill buf */
+                hkxb[i] = 0;
             if (hkcs2 & CS2_UAI) {                      /* no addr inc? */
                 if (t = Map_WriteW (ba, 2, &hkxb[wc - 1])) {
                     wc = 0;                             /* NXM, no xfr */
@@ -890,7 +930,8 @@ switch (fnc) {                                          /* case on function */
         else {                                          /* wchk */                  
             i = fxread (hkxb, sizeof (uint16), wc, uptr->fileref);
             err = ferror (uptr->fileref);
-            for ( ; i < wc; i++) hkxb[i] = 0;           /* fill buf */
+            for ( ; i < wc; i++)                        /* fill buf */
+                hkxb[i] = 0;
             awc = wc;
             for (wc = 0; wc < awc; wc++) {              /* loop thru buf */
                 if (Map_ReadW (ba, 2, &comp)) {         /* read word */
@@ -901,7 +942,8 @@ switch (fnc) {                                          /* case on function */
                     hkcs2 = hkcs2 | CS2_WCE;            /* set error */
                     break;
                     }
-                if ((hkcs2 & CS2_UAI) == 0) ba = ba + 2;
+                if ((hkcs2 & CS2_UAI)
+                    == 0) ba = ba + 2;
                 }
             }                                           /* end else wchk */
 
@@ -929,9 +971,6 @@ switch (fnc) {                                          /* case on function */
         break;
         }                                               /* end case func */
 
-if (DEBUG_PRS (hk_dev)) fprintf (sim_deb,
-    ">>HK%d done: fnc=%o, cs1 = %o, cs2 = %o, ds=%o, cyl=%o, da=%o, ba=%o, wc=%o\n",
-    drv, fnc, hkcs1, hkcs2, hkds[drv], hkdc, hkda, hkba, hkwc);
 return SCPE_OK;
 }
 
@@ -948,7 +987,8 @@ void update_hkcs (int32 flag, int32 drv)
 int32 i;
 
 update_hkds (drv);                                      /* upd drv status */
-if (flag & CS1_DONE) hkcs1 = hkcs1 & ~CS1_GO;           /* clear go */
+if (flag & CS1_DONE)                                    /* clear go */
+    hkcs1 = hkcs1 & ~CS1_GO;
 if (hkcs1 & CS1_IE) {                                   /* intr enable? */
     if (((flag & CS1_DONE) && ((hkcs1 & CS1_DONE) == 0)) ||
         ((flag & CS1_DI) && (hkcs1 & CS1_DONE)))        /* done 0->1 or DI? */
@@ -961,6 +1001,10 @@ for (i = 0; i < HK_NUMDR; i++) {                        /* if ATA, set DI */
     }
 if (hker[drv] | (hkcs1 & (CS1_PAR | CS1_CTO)) |         /* if err, set ERR */
     (hkcs2 & CS2_ERR)) hkcs1 = hkcs1 | CS1_ERR;
+if ((flag & CS1_DONE) &&                                /* set done && debug? */
+    (DEBUG_PRI (hk_dev, HKDEB_OPS)))
+    fprintf (sim_deb, ">>HK%d done: fnc=%o, cs1=%o, cs2=%o, ds=%o, er=%o, cyl=%o, da=%o, ba=%o, wc=%o\n",
+             drv, GET_FNC (hkcs1), hkcs1, hkcs2, hkds[drv], hker[drv], hkdc, hkda, hkba, hkwc);
 return;
 }
 
@@ -976,8 +1020,10 @@ hkds[drv] = (hkds[drv] & (DS_VV | DS_PIP | DS_ATA)) | DS_VLD | DS_DRA;
 if (hk_unit[drv].flags & UNIT_ATT) {                    /* attached? */
     if (!sim_is_active (&hk_unit[drv]))                 /* not busy? */
         hkds[drv] = hkds[drv] | DS_RDY;                 /* set RDY */
-    if (hker[drv]) hkds[drv] = hkds[drv] | DS_ATA;      /* err? set ATA */
-    if (hk_off[drv]) hkds[drv] = hkds[drv] | DS_OF;     /* offset? set OF */
+    if (hker[drv])                                      /* err? set ATA */
+        hkds[drv] = hkds[drv] | DS_ATA;
+    if (hk_off[drv])                                    /* offset? set OF */
+        hkds[drv] = hkds[drv] | DS_OF;
     if (hk_unit[drv].flags & UNIT_WPRT)                 /* write locked? */
         hkds[drv] = hkds[drv] | DS_WRL;                 /* set WRL */
     }
@@ -985,7 +1031,8 @@ else {
     hkds[drv] = hkds[drv] & ~(DS_PIP | DS_VV);          /* no, clr PIP,VV */
     hker[drv] = 0;                                      /* no errors */
     }
-if (hk_unit[drv].flags & UNIT_RK07) hkds[drv] = hkds[drv] | DS_DT;
+if (hk_unit[drv].flags & UNIT_RK07)
+    hkds[drv] = hkds[drv] | DS_DT;
 return;
 }
 
@@ -1034,18 +1081,22 @@ switch (msg) {
                 ((hk_off[drv])? A0_OF: 0) |
                 ((uptr->flags & UNIT_RK07)? A0_DT: 0) |
                 ((hkds[drv] & DS_VV)? A0_VV: 0) | A0_DRA;
-        if (uptr->flags & UNIT_ATT) v = v | A0_SPO |
-                (!sim_is_active (uptr)? A0_RDY: 0);
+        if (uptr->flags & UNIT_ATT)
+            v = v | A0_SPO | (!sim_is_active (uptr)? A0_RDY: 0);
         break;
 
     case 1:                                             /* message A1 */
         if (uptr->flags & UNIT_ATT) {
             if (sim_is_active (uptr)) {
-                if (fnc == FNC_UNLOAD) v = v | A1_UNL;
-                else if (fnc == FNC_RECAL) v = v | A1_RTZ;
+                if (fnc == FNC_UNLOAD)
+                    v = v | A1_UNL;
+                else if (fnc == FNC_RECAL)
+                    v = v | A1_RTZ;
                 else if (fnc == FNC_SEEK) {
-                    if (hk_dif[drv] < 0) v = v | A1_REV;
-                    if (hk_dif[drv] > 0) v = v | A1_FWD;
+                    if (hk_dif[drv] < 0)
+                        v = v | A1_REV;
+                    if (hk_dif[drv] > 0)
+                        v = v | A1_FWD;
                     }
                 }
             v = v | (A1_SPD|A1_CAR|A1_DOR|A1_HHM|A1_SRV);
@@ -1116,15 +1167,18 @@ CLR_INT (HK);                                           /* clear intr req */
 for (i = 0; i < HK_NUMDR; i++) {                        /* stop operations */
     uptr = hk_dev.units + i;
     sim_cancel (uptr);
-    if (uptr->flags & UNIT_ATT) hkds[i] = hkds[i] & DS_VV;
+    if (uptr->flags & UNIT_ATT)
+        hkds[i] = hkds[i] & DS_VV;
     else hkds[i] = 0;
     uptr->CYL = uptr->FNC = 0;                          /* clear state */
     hk_dif[i] = 0;
     hk_off[i] = 0;
     hker[i] = 0;
     }                                                   /* clear errors */
-if (hkxb == NULL) hkxb = (uint16 *) calloc (HK_MAXFR, sizeof (uint16));
-if (hkxb == NULL) return SCPE_MEM;
+if (hkxb == NULL)
+    hkxb = (uint16 *) calloc (HK_MAXFR, sizeof (uint16));
+if (hkxb == NULL)
+    return SCPE_MEM;
 return SCPE_OK;
 }
 
@@ -1137,7 +1191,8 @@ t_stat r;
 
 uptr->capac = HK_SIZE (uptr);
 r = attach_unit (uptr, cptr);                           /* attach unit */
-if (r != SCPE_OK) return r;                             /* error? */
+if (r != SCPE_OK)                                       /* error? */
+    return r;
 drv = (uint32) (uptr - hk_dev.units);                   /* get drv number */
 hkds[drv] = DS_ATA | DS_RDY | ((uptr->flags & UNIT_WPRT)? DS_WRL: 0);
 hker[drv] = 0;                                          /* upd drv status */
@@ -1148,10 +1203,12 @@ update_hkcs (CS1_DI, drv);                              /* upd ctlr status */
 
 p = sim_fsize (uptr->fileref);                          /* get file size */
 if (p == 0) {                                           /* new disk image? */
-    if (uptr->flags & UNIT_RO) return SCPE_OK;
+    if (uptr->flags & UNIT_RO)
+        return SCPE_OK;
     return pdp11_bad_block (uptr, HK_NUMSC, HK_NUMWD);
     }
-if ((uptr->flags & UNIT_AUTO) == 0) return SCPE_OK;     /* autosize? */
+if ((uptr->flags & UNIT_AUTO) == 0)                     /* autosize? */
+    return SCPE_OK;
 if (p > (RK06_SIZE * sizeof (uint16))) {
     uptr->flags = uptr->flags | UNIT_RK07;
     uptr->capac = RK07_SIZE;
@@ -1169,7 +1226,8 @@ t_stat hk_detach (UNIT *uptr)
 {
 uint32 drv;
 
-if (!(uptr->flags & UNIT_ATT)) return SCPE_OK;          /* attached? */
+if (!(uptr->flags & UNIT_ATT))                          /* attached? */
+    return SCPE_OK;
 drv = (uint32) (uptr - hk_dev.units);                   /* get drv number */
 hkds[drv] = (hkds[drv] & ~(DS_RDY | DS_WRL | DS_VV | DS_OF)) | DS_ATA;
 if (sim_is_active (uptr)) {                             /* unit active? */
@@ -1186,7 +1244,8 @@ return detach_unit (uptr);
 
 t_stat hk_set_size (UNIT *uptr, int32 val, char *cptr, void *desc)
 {
-if (uptr->flags & UNIT_ATT) return SCPE_ALATT;
+if (uptr->flags & UNIT_ATT)
+    return SCPE_ALATT;
 uptr->capac = val? RK07_SIZE: RK06_SIZE;
 return SCPE_OK;
 }
@@ -1246,7 +1305,8 @@ t_stat hk_boot (int32 unitno, DEVICE *dptr)
 int32 i;
 extern int32 saved_PC;
 
-for (i = 0; i < BOOT_LEN; i++) M[(BOOT_START >> 1) + i] = boot_rom[i];
+for (i = 0; i < BOOT_LEN; i++)
+    M[(BOOT_START >> 1) + i] = boot_rom[i];
 M[BOOT_UNIT >> 1] = unitno & CS2_M_UNIT;
 M[BOOT_CSR >> 1] = hk_dib.ba & DMASK;
 saved_PC = BOOT_ENTRY;
