@@ -1,6 +1,6 @@
 /* pdp8_ct.c: PDP-8 cassette tape simulator
 
-   Copyright (c) 2006, Robert M Supnik
+   Copyright (c) 2006-2008, Robert M Supnik
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -25,6 +25,10 @@
 
    ct           TA8E/TU60 cassette tape
 
+   13-Aug-07    RMS     Fixed handling of BEOT
+   06-Aug-07    RMS     Foward op at BOT skips initial file gap
+   30-May-2007  RMS     Fixed typo (from Norm Lastovica)
+
    Magnetic tapes are represented as a series of variable records
    of the form:
 
@@ -43,7 +47,9 @@
    rather than file marks.  If the controller spaces or reads into a file
    gap and then reverses direction, the file gap is not seen again.  This
    is in contrast to magnetic tapes, where the file mark is a character
-   sequence and is seen again if direction is reversed.
+   sequence and is seen again if direction is reversed.  In addition,
+   cassettes have an initial file gap which is automatically skipped on
+   forward operations from beginning of tape.
 
    Note that the read and write sequences for the cassette are asymmetric:
 
@@ -132,6 +138,7 @@
 
 extern int32 int_req, stop_inst;
 extern UNIT cpu_unit;
+extern FILE *sim_deb;
 
 uint32 ct_sra = 0;                                      /* status reg A */
 uint32 ct_srb = 0;                                      /* status reg B */
@@ -219,7 +226,7 @@ DEVICE ct_dev = {
     CT_NUMDR, 10, 31, 1, 8, 8,
     NULL, NULL, &ct_reset,
     &ct_boot, &ct_attach, &ct_detach,
-    &ct_dib, DEV_DISABLE | DEV_DIS
+    &ct_dib, DEV_DISABLE | DEV_DIS | DEV_DEBUG
     };
 
 /* IOT routines */
@@ -237,11 +244,13 @@ switch (IR & 07) {                                      /* decode IR<9:11> */
         break;
 
     case 1:                                             /* KSDR */
-        if (ct_df) AC |= IOT_SKP;
+        if (ct_df)
+            AC |= IOT_SKP;
         break;
 
     case 2:                                             /* KSEN */
-        if (srb & SRB_ALLERR) AC |= IOT_SKP;
+        if (srb & SRB_ALLERR)
+            AC |= IOT_SKP;
         break;
 
     case 3:                                             /* KSBF */
@@ -252,7 +261,7 @@ switch (IR & 07) {                                      /* decode IR<9:11> */
     case 4:                                             /* KLSA */
         ct_sra = AC & 0377;
         ct_updsta (NULL);
-	return ct_sra ^ 0377;
+        return ct_sra ^ 0377;
 
     case 5:                                             /* KSAF */
         if (ct_df || (srb & (SRB_ALLERR|SRB_RDY)))
@@ -283,6 +292,9 @@ uint32 fnc = GET_FNC (ct_sra);
 uint32 flg = ct_fnc_tab[fnc];
 uint32 old_ust = uptr->UST;
 
+if (DEBUG_PRS (ct_dev)) fprintf (sim_deb,
+    ">>CT start: op=%o, old_sta = %o, pos=%d\n",
+    fnc, uptr->UST, uptr->pos);
 if ((ct_sra & SRA_ENAB) && (uptr->flags & UNIT_ATT)) {  /* enabled, att? */
     ct_srb &= ~(SRB_XFRERR|SRB_REW);                    /* clear err, rew */
     if (flg & OP_WRI) {                                 /* write-type op? */
@@ -297,12 +309,25 @@ if ((ct_sra & SRA_ENAB) && (uptr->flags & UNIT_ATT)) {  /* enabled, att? */
         ct_write = 0;
         ct_db = 0;
         }
-    if (fnc == SRA_REW) ct_srb |= SRB_REW;              /* rew? set flag */
+    ct_srb &= ~SRB_BEOT;                                /* tape in motion */
+    if (fnc == SRA_REW)                                 /* rew? set flag */
+        ct_srb |= SRB_REW;
     if ((fnc != SRA_REW) && !(flg & OP_WRI)) {          /* read cmd? */
+        t_mtrlnt t;
+        t_stat st;
         uptr->UST = flg & UST_REV;                      /* save direction */
+        if (sim_tape_bot (uptr) && (flg & OP_FWD)) {    /* spc/read fwd bot? */
+            st = sim_tape_rdrecf (uptr, ct_xb, &t, CT_MAXFR); /* skip file gap */
+            if (st != MTSE_TMK)                         /* not there? */
+                sim_tape_rewind (uptr);                 /* restore tap pos */
+            else old_ust = 0;                           /* defang next */
+            }
         if ((old_ust ^ uptr->UST) == (UST_REV|UST_GAP)) { /* rev in gap? */
-            t_mtrlnt t;                                 /* skip tape mark */
-            if (uptr->UST) sim_tape_rdrecr (uptr, ct_xb, &t, CT_MAXFR);
+            if (DEBUG_PRS (ct_dev)) fprintf (sim_deb,
+                ">>CT skip gap: op=%o, old_sta = %o, pos=%d\n",
+                fnc, uptr->UST, uptr->pos);
+            if (uptr->UST)                              /* skip file gap */
+                sim_tape_rdrecr (uptr, ct_xb, &t, CT_MAXFR);
             else sim_tape_rdrecf (uptr, ct_xb, &t, CT_MAXFR);
             }
         }
@@ -335,7 +360,8 @@ switch (fnc) {                                          /* case on function */
     case SRA_CRC:                                       /* CRC */
         if ((uptr->FNC & SRA_M_FNC) != SRA_CRC)         /* if not CRC */
             uptr->FNC = SRA_CRC;                        /* start CRC seq */
-        if (!ct_write) return ct_db;                    /* read? AC <- buf */
+        if (!ct_write)                                  /* read? AC <- buf */
+            return ct_db;
         break;
 
     default:
@@ -360,16 +386,18 @@ if ((uptr->flags & UNIT_ATT) == 0) {                    /* not attached? */
     }
 if (((flgs & OP_REV) && sim_tape_bot (uptr)) ||         /* rev at BOT or */
     ((flgs & OP_FWD) && sim_tape_eot (uptr))) {         /* fwd at EOT? */
+    ct_srb |= SRB_BEOT;                                 /* error */
     ct_updsta (uptr);                                   /* op done */
     return SCPE_OK;
-}
+    }
 
 r = SCPE_OK;
 switch (uptr->FNC) {                                    /* case on function */
 
     case SRA_READ:                                      /* read start */
         st = sim_tape_rdrecf (uptr, ct_xb, &ct_blnt, CT_MAXFR); /* get rec */
-        if (st == MTSE_RECE) ct_srb |= SRB_CRC;         /* rec in err? */
+        if (st == MTSE_RECE)                            /* rec in err? */
+            ct_srb |= SRB_CRC;
         else if (st != MTSE_OK) {                       /* other error? */
             r = ct_map_err (uptr, st);                  /* map error */
             break;
@@ -382,13 +410,15 @@ switch (uptr->FNC) {                                    /* case on function */
         return SCPE_OK;
 
     case SRA_READ|SRA_2ND:                              /* read char */
-        if (!ct_read_char ()) break;                    /* read, overrun? */
+        if (!ct_read_char ())                           /* read, overrun? */
+            break;
         ct_set_df (TRUE);                               /* set data flag */
         sim_activate (uptr, ct_ctime);                  /* sched next char */
         return SCPE_OK;
 
     case SRA_WRITE:                                     /* write start */
-        for (i = 0; i < CT_MAXFR; i++) ct_xb[i] = 0;    /* clear buffer */
+        for (i = 0; i < CT_MAXFR; i++)                  /* clear buffer */
+            ct_xb[i] = 0;
         uptr->FNC |= SRA_2ND;                           /* next state */
         sim_activate (uptr, ct_ctime);                  /* sched next char */
         return SCPE_OK;
@@ -416,7 +446,8 @@ switch (uptr->FNC) {                                    /* case on function */
     case SRA_CRC|SRA_2ND:                               /* second read CRC */
         if (ct_bptr != ct_blnt) {                       /* partial read? */
             crc = ct_crc (ct_xb, ct_bptr);              /* actual CRC */
-            if (crc != 0) ct_srb |= SRB_CRC;            /* must be zero */
+            if (crc != 0)                               /* must be zero */
+                ct_srb |= SRB_CRC;
             }
          break;                                         /* read done */
 
@@ -427,6 +458,7 @@ switch (uptr->FNC) {                                    /* case on function */
 
     case SRA_REW:                                       /* rewind */
         sim_tape_rewind (uptr);
+        ct_srb |= SRB_BEOT;                             /* set BOT */
         break;
 
     case SRA_SRB:                                       /* space rev blk */
@@ -449,6 +481,9 @@ switch (uptr->FNC) {                                    /* case on function */
         }                                               /* end case */
 
 ct_updsta (uptr);                                       /* update status */
+if (DEBUG_PRS (ct_dev)) fprintf (sim_deb,
+    ">>CT done: op=%o, statusA = %o, statusB = %o, pos=%d\n",
+    uptr->FNC, ct_sra, ct_srb, uptr->pos);
 return r;
 }
 
@@ -461,22 +496,22 @@ int32 srb;
 if (uptr == NULL) {                                     /* unit specified? */
     uptr = ct_busy ();                                  /* use busy unit */
     if ((uptr == NULL) && (ct_sra & SRA_ENAB))          /* none busy? */
-        uptr = uptr = ct_dev.units + GET_UNIT (ct_sra); /* use sel unit */
+        uptr = ct_dev.units + GET_UNIT (ct_sra);        /* use sel unit */
     }
-else if (ct_srb & SRB_EOF) uptr->UST |= UST_GAP;        /* save gap */
+else if (ct_srb & SRB_EOF)                              /* save gap */
+    uptr->UST |= UST_GAP;
 if (uptr) {                                             /* any unit? */
-    ct_srb &= ~(SRB_WLK|SRB_BEOT|SRB_EMP|SRB_RDY);      /* clear dyn flags */
+    ct_srb &= ~(SRB_WLK|SRB_EMP|SRB_RDY);               /* clear dyn flags */
     if ((uptr->flags & UNIT_ATT) == 0)                  /* unattached? */
         ct_srb = (ct_srb | SRB_EMP|SRB_WLK) & ~SRB_REW; /* empty, locked */
     if (!sim_is_active (uptr)) {                        /* not busy? */
         ct_srb = (ct_srb | SRB_RDY) & ~SRB_REW;         /* ready, ~rew */
-        if (sim_tape_bot (uptr) || sim_tape_eot (uptr)) /* update BEOT */
-            ct_srb |= SRB_BEOT;
         }
     if (sim_tape_wrp (uptr) || (ct_srb & SRB_REW))      /* locked or rew? */
         ct_srb |= SRB_WLK;                              /* set locked */
     }
-if (ct_sra & SRA_ENAB) srb = ct_srb;                    /* can TA see TU60? */
+if (ct_sra & SRA_ENAB)                                  /* can TA see TU60? */
+    srb = ct_srb;
 else srb = 0;                                           /* no */
 if ((ct_sra & SRA_IE) &&                                /* int enabled? */
     (ct_df || (srb & (SRB_ALLERR|SRB_RDY))))            /* any flag? */
@@ -489,9 +524,11 @@ return srb;
 
 void ct_set_df (t_bool timchk)
 {
-if (ct_df && timchk) ct_srb |= SRB_TIM;                 /* flag still set? */
+if (ct_df && timchk)                                    /* flag still set? */
+    ct_srb |= SRB_TIM;
 ct_df = 1;                                              /* set data flag */
-if (ct_sra & SRA_IE) int_req |= INT_CT;                 /* if ie, int req */
+if (ct_sra & SRA_IE)                                    /* if ie, int req */
+    int_req |= INT_CT;
 return;
 }
 
@@ -517,7 +554,8 @@ UNIT *uptr;
 
 for (u = 0; u < CT_NUMDR; u++) {                        /* loop thru units */
     uptr = ct_dev.units + u;
-    if (sim_is_active (uptr)) return uptr;
+    if (sim_is_active (uptr))
+        return uptr;
     }
 return NULL;
 }
@@ -532,7 +570,8 @@ crc = 0;
 for (i = 0; i < cnt; i++) {
     crc = crc ^ (((uint32) buf[i]) << 8);
     for (j = 0; j < 8; j++) {
-        if (crc & 1) crc = (crc >> 1) ^ 0xA001;
+        if (crc & 1)
+            crc = (crc >> 1) ^ 0xA001;
         else crc = crc >> 1;
         }
     }
@@ -557,7 +596,8 @@ switch (st) {
 
     case MTSE_IOERR:                                    /* IO error */
         ct_srb |= SRB_CRC;                              /* set crc err */
-        if (ct_stopioe) return SCPE_IOERR;
+        if (ct_stopioe)
+            return SCPE_IOERR;
         break;
 
     case MTSE_INVRL:                                    /* invalid rec lnt */
@@ -570,6 +610,7 @@ switch (st) {
         break;
 
     case MTSE_BOT:                                      /* reverse into BOT */
+        ct_srb |= SRB_BEOT;                             /* set BOT */
         break;
 
     case MTSE_WRP:                                      /* write protect */
@@ -600,8 +641,10 @@ for (u = 0; u < CT_NUMDR; u++) {                        /* loop thru units */
     sim_cancel (uptr);                                  /* cancel activity */
     sim_tape_reset (uptr);                              /* reset tape */
     }
-if (ct_xb == NULL) ct_xb = (uint8 *) calloc (CT_MAXFR + 2, sizeof (uint8));
-if (ct_xb == NULL) return SCPE_MEM;
+if (ct_xb == NULL)
+    ct_xb = (uint8 *) calloc (CT_MAXFR + 2, sizeof (uint8));
+if (ct_xb == NULL)
+    return SCPE_MEM;
 return SCPE_OK;
 }
 
@@ -612,7 +655,8 @@ t_stat ct_attach (UNIT *uptr, char *cptr)
 t_stat r;
 
 r = sim_tape_attach (uptr, cptr);
-if (r != SCPE_OK) return r;
+if (r != SCPE_OK)
+    return r;
 ct_updsta (NULL);
 uptr->UST = 0;
 return r;
@@ -624,7 +668,8 @@ t_stat ct_detach (UNIT* uptr)
 {
 t_stat r;
 
-if (!(uptr->flags & UNIT_ATT)) return SCPE_OK;          /* check attached */
+if (!(uptr->flags & UNIT_ATT))                          /* check attached */
+    return SCPE_OK;
 r = sim_tape_detach (uptr);
 ct_updsta (NULL);
 uptr->UST = 0;
@@ -679,7 +724,8 @@ extern uint16 M[];
 
 if ((ct_dib.dev != DEV_CT) || unitno)                   /* only std devno */
      return STOP_NOTSTD;
-for (i = 0; i < BOOT_LEN; i++) M[BOOT_START + i] = boot_rom[i];
+for (i = 0; i < BOOT_LEN; i++)
+    M[BOOT_START + i] = boot_rom[i];
 saved_PC = BOOT_START;
 return SCPE_OK;
 }
