@@ -1,6 +1,6 @@
 /* vax780_defs.h: VAX 780 model-specific definitions file
 
-   Copyright (c) 2004-2006, Robert M Supnik
+   Copyright (c) 2004-2008, Robert M Supnik
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -23,9 +23,12 @@
    used in advertising or otherwise to promote the sale, use or other dealings
    in this Software without prior written authorization from Robert M Supnik.
 
-   29-Oct-2006  RMS     Added clock coscheduler function
-   17-May-2006  RMS     Added CR11/CD11 support (from John Dundas)
-   10-May-2006  RMS     Added model-specific reserved operand check macros
+   19-Nov-08    RMS     Moved I/O support routines to I/O library
+   29-Apr-07    RMS     Modified model-specific reserved operand check macros
+                        to reflect 780 microcode patches (found by Naoki Hamada)
+   29-Oct-06    RMS     Added clock coscheduler function
+   17-May-06    RMS     Added CR11/CD11 support (from John Dundas)
+   10-May-06    RMS     Added model-specific reserved operand check macros
 
    This file covers the VAX 11/780, the first VAX.
 
@@ -119,10 +122,20 @@
 
 /* Machine specific reserved operand tests */
 
-#define ML_PA_TEST(r)   if ((r) & 0xC0000003) RSVD_OPND_FAULT
-#define ML_LR_TEST(r)   if ((uint32)(r) > 0x200000) RSVD_OPND_FAULT
-#define ML_BR_TEST(r)   if ((((r) & 0xC0000000) != 0x80000000) || \
+/* 780 microcode patch 37 - only test LR<23:0> for appropriate length */
+
+#define ML_LR_TEST(r)   if ((uint32)((r) & 0xFFFFFF) > 0x200000) RSVD_OPND_FAULT
+
+/* 780 microcode patch 38 - only test PxBR<31>=1 and xBR<1:0> = 0 */
+
+#define ML_PXBR_TEST(r) if ((((r) & 0x80000000) == 0) || \
                             ((r) & 0x00000003)) RSVD_OPND_FAULT
+#define ML_SBR_TEST(r)  if ((r) & 0x00000003) RSVD_OPND_FAULT
+
+/* 780 microcode patch 78 - only test xCBB<1:0> = 0 */
+
+#define ML_PA_TEST(r)   if ((r) & 0x00000003) RSVD_OPND_FAULT
+
 #define LP_AST_TEST(r)  if ((r) > AST_MAX) RSVD_OPND_FAULT
 #define LP_MBZ84_TEST(r) if ((r) & 0xF8C00000) RSVD_OPND_FAULT
 #define LP_MBZ92_TEST(r) if ((r) & 0x7FC00000) RSVD_OPND_FAULT
@@ -210,6 +223,8 @@
 #define DZ_MUXES        4                               /* max # of DZV muxes */
 #define DZ_LINES        8                               /* lines per DZV mux */
 #define VH_MUXES        4                               /* max # of DHQ muxes */
+#define DLX_LINES       16                              /* max # of KL11/DL11's */
+#define DCX_LINES       16                              /* max # of DC11's */
 #define MT_MAXFR        (1 << 16)                       /* magtape max rec */
 
 #define DEV_V_UBUS      (DEV_V_UF + 0)                  /* Unibus */
@@ -392,6 +407,22 @@ typedef struct {
 #define BOOT_UDA        17
 #define BOOT_TK         18
 
+/* Function prototypes for virtual memory interface */
+
+int32 Read (uint32 va, int32 lnt, int32 acc);
+void Write (uint32 va, int32 val, int32 lnt, int32 acc);
+
+/* Function prototypes for physical memory interface (inlined) */
+
+SIM_INLINE int32 ReadB (uint32 pa);
+SIM_INLINE int32 ReadW (uint32 pa);
+SIM_INLINE int32 ReadL (uint32 pa);
+SIM_INLINE int32 ReadLP (uint32 pa);
+SIM_INLINE void WriteB (uint32 pa, int32 val);
+SIM_INLINE void WriteW (uint32 pa, int32 val);
+SIM_INLINE void WriteL (uint32 pa, int32 val);
+void WriteLP (uint32 pa, int32 val);
+
 /* Function prototypes for I/O */
 
 int32 Map_ReadB (uint32 ba, int32 bc, uint8 *buf);
@@ -399,13 +430,6 @@ int32 Map_ReadW (uint32 ba, int32 bc, uint16 *buf);
 int32 Map_WriteB (uint32 ba, int32 bc, uint8 *buf);
 int32 Map_WriteW (uint32 ba, int32 bc, uint16 *buf);
 
-t_stat set_addr (UNIT *uptr, int32 val, char *cptr, void *desc);
-t_stat show_addr (FILE *st, UNIT *uptr, int32 val, void *desc);
-t_stat set_addr_flt (UNIT *uptr, int32 val, char *cptr, void *desc);
-t_stat set_vec (UNIT *uptr, int32 val, char *cptr, void *desc);
-t_stat show_vec (FILE *st, UNIT *uptr, int32 val, void *desc);
-t_stat auto_config (char *name, int32 num);
-
 int32 mba_rdbufW (uint32 mbus, int32 bc, uint16 *buf);
 int32 mba_wrbufW (uint32 mbus, int32 bc, uint16 *buf);
 int32 mba_chbufW (uint32 mbus, int32 bc, uint16 *buf);
@@ -421,4 +445,6 @@ t_stat show_nexus (FILE *st, UNIT *uptr, int32 val, void *desc);
 void sbi_set_errcnf (void);
 int32 clk_cosched (int32 wait);
 
+#include "pdp11_io_lib.h"
+
 #endif
