@@ -1,6 +1,6 @@
 /* vax_cpu1.c: VAX complex instructions
 
-   Copyright (c) 1998-2006, Robert M Supnik
+   Copyright (c) 1998-2008, Robert M Supnik
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -23,6 +23,8 @@
    used in advertising or otherwise to promote the sale, use or other dealings
    in this Software without prior written authorization from Robert M Supnik.
 
+   28-May-08    RMS     Inlined physical memory routines
+   29-Apr-07    RMS     Separated base register access checks for 11/780
    10-May-06    RMS     Added access check on system PTE for 11/780
                         Added mbz check in LDPCTX for 11/780
    22-Sep-06    RMS     Fixed declarations (from Sterling Garwood)
@@ -99,11 +101,7 @@ extern int32 ibcnt, ppc;
 extern FILE *sim_deb;
 extern DEVICE cpu_dev;
 
-extern int32 Read (uint32 va, int32 lnt, int32 acc);
-extern void Write (uint32 va, int32 val, int32 lnt, int32 acc);
 extern int32 Test (uint32 va, int32 acc, int32 *status);
-extern int32 ReadLP (uint32 pa);
-extern void WriteLP (uint32 pa, int32 val);
 extern void set_map_reg (void);
 extern void zap_tb (int stb);
 extern void zap_tb_ent (uint32 va);
@@ -111,7 +109,7 @@ extern t_bool chk_tb_ent (uint32 va);
 extern int32 ReadIPR (int32 rg);
 extern void WriteIPR (int32 rg, int32 val);
 extern t_bool BadCmPSL (int32 newpsl);
-extern int32 cpu_psl_ipl (int32 newpsl);
+extern int32 cpu_psl_ipl_idle (int32 newpsl);
 
 extern jmp_buf save_env;
 
@@ -131,7 +129,8 @@ int32 rn = opnd[1];
 int32 ea, by;
 
 if (rn >= 0) {                                          /* register? */
-    if (((uint32) pos) > 31) RSVD_OPND_FAULT;           /* pos > 31? fault */
+    if (((uint32) pos) > 31)                            /* pos > 31? fault */
+        RSVD_OPND_FAULT;
     return (R[rn] >> pos) & 1;                          /* get bit */
     }
 ea = opnd[2] + (pos >> 3);                              /* base byte addr */
@@ -147,7 +146,8 @@ int32 rn = opnd[1];
 int32 ea, by, bit;
 
 if (rn >= 0) {                                          /* register? */
-    if (((uint32) pos) > 31) RSVD_OPND_FAULT;           /* pos > 31? fault */
+    if (((uint32) pos) > 31)                            /* pos > 31? fault */
+        RSVD_OPND_FAULT;
     bit = (R[rn] >> pos) & 1;                           /* get bit */
     R[rn] = newb? (R[rn] | (1u << pos)): (R[rn] & ~(1u << pos));
     return bit;
@@ -179,21 +179,27 @@ int32 rn = opnd[2];
 uint32 wd = opnd[3];
 int32 ba, wd1 = 0;
 
-if (size == 0) return 0;                                /* size 0? field = 0 */
-if (size > 32) RSVD_OPND_FAULT;                         /* size > 32? fault */
+if (size == 0)                                          /* size 0? field = 0 */
+    return 0;
+if (size > 32)                                          /* size > 32? fault */
+    RSVD_OPND_FAULT;
 if (rn >= 0) {                                          /* register? */
-    if (((uint32) pos) > 31) RSVD_OPND_FAULT;           /* pos > 31? fault */
+    if (((uint32) pos) > 31)                            /* pos > 31? fault */
+        RSVD_OPND_FAULT;
     if (((pos + size) > 32) && (rn >= nSP))             /* span 2 reg, PC? */
         RSVD_ADDR_FAULT;                                /* fault */
-    if (pos) wd = (wd >> pos) | (((uint32) vfldrp1) << (32 - pos));
+    if (pos)
+        wd = (wd >> pos) | (((uint32) vfldrp1) << (32 - pos));
     }
 else {
     ba = wd + (pos >> 3);                               /* base byte addr */
     pos = (pos & 07) | ((ba & 03) << 3);                /* bit offset */
     ba = ba & ~03;                                      /* lw align base */
     wd = Read (ba, L_LONG, RA);                         /* read field */
-    if ((size + pos) > 32) wd1 = Read (ba + 4, L_LONG, RA);
-    if (pos) wd = (wd >> pos) | (((uint32) wd1) << (32 - pos));
+    if ((size + pos) > 32)
+        wd1 = Read (ba + 4, L_LONG, RA);
+    if (pos)
+        wd = (wd >> pos) | (((uint32) wd1) << (32 - pos));
     }
 return wd & byte_mask[size];
 }
@@ -217,12 +223,16 @@ int32 size = opnd[2];
 int32 rn = opnd[3];
 int32 val, mask, ba, wd, wd1;
 
-if (size == 0) return;                                  /* size = 0? done */
-if (size > 32) RSVD_OPND_FAULT;                         /* size > 32? fault */
+if (size == 0)                                          /* size = 0? done */
+    return;
+if (size > 32)                                          /* size > 32? fault */
+    RSVD_OPND_FAULT;
 if (rn >= 0) {                                          /* in registers? */
-    if (((uint32) pos) > 31) RSVD_OPND_FAULT;           /* pos > 31? fault */
+    if (((uint32) pos) > 31)                            /* pos > 31? fault */
+        RSVD_OPND_FAULT;
     if ((pos + size) > 32) {                            /* span two reg? */
-        if (rn >= nSP) RSVD_ADDR_FAULT;                 /* if PC, fault */
+        if (rn >= nSP)                                  /* if PC, fault */
+            RSVD_ADDR_FAULT;
         mask = byte_mask[pos + size - 32];              /* insert fragment */
         val = ins >> (32 - pos);
         R[rn + 1] = (vfldrp1 & ~mask) | (val & mask);
@@ -255,7 +265,10 @@ int32 op_ffs (uint32 wd, int32 size)
 {
 int32 i;
 
-for (i = 0; wd; i++, wd = wd >> 1) if (wd & 1) return i;
+for (i = 0; wd; i++, wd = wd >> 1) {
+    if (wd & 1)
+        return i;
+    }
 return size;
 }
 
@@ -347,7 +360,8 @@ int32 addr = opnd[1];
 int32 mask, stklen, tsp, wd;
 
 mask = Read (addr, L_WORD, RA);                         /* get proc mask */
-if (mask & CALL_MBZ) RSVD_OPND_FAULT;                   /* test mbz */
+if (mask & CALL_MBZ)                                    /* test mbz */
+    RSVD_OPND_FAULT;
 stklen = rcnt[mask & 077] + rcnt[(mask >> 6) & 077] + (gs? 24: 20);
 Read (SP - stklen, L_BYTE, WA);                         /* wchk stk */
 if (gs) {
@@ -374,7 +388,8 @@ wd = ((SP & CALL_M_SPA) << CALL_V_SPA) | (gs << CALL_V_S) |
     ((mask & CALL_MASK) << CALL_V_MASK) | (PSL & 0xFFE0);
 Write (tsp - 16, wd, L_LONG, WA);                       /* push spa/s/mask/psw */
 Write (tsp - 20, 0, L_LONG, WA);                        /* push cond hdlr */
-if (gs) AP = SP;                                        /* update AP */
+if (gs)                                                 /* update AP */
+    AP = SP;
 else AP = opnd[0];
 SP = FP = tsp - 20;                                     /* update FP, SP */
 PSL = (PSL & ~(PSW_DV | PSW_FU | PSW_IV)) |             /* update PSW */
@@ -390,7 +405,8 @@ int32 spamask, stklen, newpc, nargs;
 int32 tsp = FP;
 
 spamask = Read (tsp + 4, L_LONG, RA);                   /* spa/s/mask/psw */
-if (spamask & PSW_MBZ) RSVD_OPND_FAULT;                 /* test mbz */
+if (spamask & PSW_MBZ)                                  /* test mbz */
+    RSVD_OPND_FAULT;
 stklen = rcnt[(spamask >> CALL_V_MASK) & 077] +
     rcnt[(spamask >> (CALL_V_MASK + 6)) & 077] + ((spamask & CALL_S)? 23: 19);
 Read (tsp + stklen, L_BYTE, RA);                        /* rchk stk end */
@@ -428,7 +444,8 @@ void op_pushr (int32 *opnd, int32 acc)
 int32 mask = opnd[0] & 0x7FFF;
 int32 stklen, tsp;
 
-if (mask == 0) return;
+if (mask == 0)
+    return;
 stklen = rcnt[(mask >> 7) & 0177] + rcnt[mask & 0177] +
     ((mask & 0x4000)? 4: 0);
 Read (SP - stklen, L_BYTE, WA);                         /* wchk stk end */
@@ -457,7 +474,8 @@ void op_popr (int32 *opnd, int32 acc)
 int32 mask = opnd[0] & 0x7FFF;
 int32 stklen;
 
-if (mask == 0) return;
+if (mask == 0)
+    return;
 stklen = rcnt[(mask >> 7) & 0177] + rcnt[mask & 0177] +
     ((mask & 0x4000)? 4: 0);
 Read (SP + stklen - 1, L_BYTE, RA);                     /* rchk stk end */
@@ -475,7 +493,8 @@ POPR_POP (10);
 POPR_POP (11);
 POPR_POP (12);
 POPR_POP (13);
-if (mask & 0x4000) SP = Read (SP, L_LONG, RA);          /* if pop SP, no inc */
+if (mask & 0x4000)                                      /* if pop SP, no inc */
+    SP = Read (SP, L_LONG, RA);
 return;
 }
 
@@ -554,12 +573,14 @@ p = Read (e + 4, L_LONG, RA);                           /* p <- (e+4) */
 CC_CMP_L (s, p);                                        /* set cc's */
 if (e != p) {                                           /* queue !empty? */
     Read (s + 4, L_LONG, WA);                           /* wchk (s+4) */
-    if (opnd[1] < 0) Read (opnd[2], L_LONG, WA);        /* wchk dest */
+    if (opnd[1] < 0)                                    /* wchk dest */
+        Read (opnd[2], L_LONG, WA);
     Write (p, s, L_LONG, WA);                           /* (p) <- s */
     Write (s + 4, p, L_LONG, WA);                       /* (s+4) <- p */
     }
 else cc = cc | CC_V;                                    /* else set v */
-if (opnd[1] >= 0) R[opnd[1]] = e;                       /* store result */
+if (opnd[1] >= 0)                                       /* store result */
+    R[opnd[1]] = e;
 else Write (opnd[2], e, L_LONG, WA);
 return cc;
 }
@@ -600,14 +621,18 @@ int32 h = opnd[1];
 int32 d = opnd[0];
 int32 a, t;
 
-if ((h == d) || ((h | d) & 07)) RSVD_OPND_FAULT;        /* h, d quad align? */
+if ((h == d) || ((h | d) & 07))                         /* h, d quad align? */
+    RSVD_OPND_FAULT;
 Read (d, L_BYTE, WA);                                   /* wchk ent */
 a = Read (h, L_LONG, WA);                               /* a <- (h), wchk */
-if (a & 06) RSVD_OPND_FAULT;                            /* chk quad align */
-if (a & 01) return CC_C;                                /* busy, cc = 0001 */
+if (a & 06)                                             /* chk quad align */
+    RSVD_OPND_FAULT;
+if (a & 01)                                             /* busy, cc = 0001 */
+    return CC_C;
 Write (h, a | 1, L_LONG, WA);                           /* get interlock */
 a = a + h;                                              /* abs addr of a */
-if (Test (a, WA, &t) < 0) Write (h, a - h, L_LONG, WA); /* wtst a, rls if err */
+if (Test (a, WA, &t) < 0)                               /* wtst a, rls if err */
+    Write (h, a - h, L_LONG, WA);
 Write (a + 4, d - a, L_LONG, WA);                       /* (a+4) <- d-a, flt ok */
 Write (d, a - d, L_LONG, WA);                           /* (d) <- a-d */
 Write (d + 4, h - d, L_LONG, WA);                       /* (d+4) <- h-d */
@@ -621,19 +646,24 @@ int32 h = opnd[1];
 int32 d = opnd[0];
 int32 a, c, t;
 
-if ((h == d) || ((h | d) & 07)) RSVD_OPND_FAULT;        /* h, d quad align? */
+if ((h == d) || ((h | d) & 07))                         /* h, d quad align? */
+    RSVD_OPND_FAULT;
 Read (d, L_BYTE, WA);                                   /* wchk ent */
 a = Read (h, L_LONG, WA);                               /* a <- (h), wchk */
-if (a == 0) return op_insqhi (opnd, acc);               /* if empty, ins hd */
-if (a & 06) RSVD_OPND_FAULT;                            /* chk quad align */
-if (a & 01) return CC_C;                                /* busy, cc = 0001 */
+if (a == 0)                                             /* if empty, ins hd */
+    return op_insqhi (opnd, acc);
+if (a & 06)                                             /* chk quad align */
+    RSVD_OPND_FAULT;
+if (a & 01)                                             /* busy, cc = 0001 */
+    return CC_C;
 Write (h, a | 1, L_LONG, WA);                           /* acquire interlock */
 c = Read (h + 4, L_LONG, RA) + h;                       /* c <- (h+4) + h */
 if (c & 07) {                                           /* c quad aligned? */
     Write (h, a, L_LONG, WA);                           /* release interlock */
     RSVD_OPND_FAULT;                                    /* fault */
     }
-if (Test (c, WA, &t) < 0) Write (h, a, L_LONG, WA);     /* wtst c, rls if err */
+if (Test (c, WA, &t) < 0)                               /* wtst c, rls if err */
+    Write (h, a, L_LONG, WA);
 Write (c, d - c, L_LONG, WA);                           /* (c) <- d-c, flt ok */
 Write (d, h - d, L_LONG, WA);                           /* (d) <- h-d */
 Write (d + 4, c - d, L_LONG, WA);                       /* (d+4) <- c-d */
@@ -673,14 +703,18 @@ int32 op_remqhi (int32 *opnd, int32 acc)
 int32 h = opnd[0];
 int32 ar, a, b, t;
 
-if (h & 07) RSVD_OPND_FAULT;                            /* h quad aligned? */
+if (h & 07)                                             /* h quad aligned? */
+    RSVD_OPND_FAULT;
 if (opnd[1] < 0) {                                      /* mem destination? */
-    if (h == opnd[2]) RSVD_OPND_FAULT;                  /* hdr = dst? */
+    if (h == opnd[2])                                   /* hdr = dst? */
+        RSVD_OPND_FAULT;
     Read (opnd[2], L_LONG, WA);                         /* wchk dst */
     }
 ar = Read (h, L_LONG, WA);                              /* ar <- (h) */
-if (ar & 06) RSVD_OPND_FAULT;                           /* a quad aligned? */
-if (ar & 01) return CC_V | CC_C;                        /* busy, cc = 0011 */
+if (ar & 06)                                            /* a quad aligned? */
+    RSVD_OPND_FAULT;
+if (ar & 01)                                            /* busy, cc = 0011 */
+    return CC_V | CC_C;
 a = ar + h;                                             /* abs addr of a */
 if (ar) {                                               /* queue not empty? */
     Write (h, ar | 1, L_LONG, WA);                      /* acquire interlock */
@@ -696,9 +730,11 @@ if (ar) {                                               /* queue not empty? */
     Write (b + 4, h - b, L_LONG, WA);                   /* (b+4) <- h-b, flt ok */
     Write (h, b - h, L_LONG, WA);                       /* (h) <- b-h, rls int */
     }
-if (opnd[1] >= 0) R[opnd[1]] = a;                       /* store result */
+if (opnd[1] >= 0)                                       /* store result */
+    R[opnd[1]] = a;
 else Write (opnd[2], a, L_LONG, WA);
-if (ar == 0) return CC_Z | CC_V;                        /* empty, cc = 0110 */
+if (ar == 0)                                            /* empty, cc = 0110 */
+    return CC_Z | CC_V;
 return (b == h)? CC_Z: 0;                               /* if b = h, q empty */
 }
 
@@ -707,14 +743,18 @@ int32 op_remqti (int32 *opnd, int32 acc)
 int32 h = opnd[0];
 int32 ar, b, c, t;
 
-if (h & 07) RSVD_OPND_FAULT;                            /* h quad aligned? */
+if (h & 07)                                             /* h quad aligned? */
+    RSVD_OPND_FAULT;
 if (opnd[1] < 0) {                                      /* mem destination? */
-    if (h == opnd[2]) RSVD_OPND_FAULT;                  /* hdr = dst? */
+    if (h == opnd[2])                                   /* hdr = dst? */
+        RSVD_OPND_FAULT;
     Read (opnd[2], L_LONG, WA);                         /* wchk dst */
     }
 ar = Read (h, L_LONG, WA);                              /* a <- (h) */
-if (ar & 06) RSVD_OPND_FAULT;                           /* a quad aligned? */
-if (ar & 01) return CC_V | CC_C;                        /* busy, cc = 0011 */
+if (ar & 06)                                            /* a quad aligned? */
+    RSVD_OPND_FAULT;
+if (ar & 01)                                            /* busy, cc = 0011 */
+    return CC_V | CC_C;
 if (ar) {                                               /* queue not empty */
     Write (h, ar | 1, L_LONG, WA);                      /* acquire interlock */
     c = Read (h + 4, L_LONG, RA);                       /* c <- (h+4) */
@@ -741,9 +781,11 @@ if (ar) {                                               /* queue not empty */
     Write (h, ar, L_LONG, WA);                          /* release interlock */
     }
 else c = h;                                             /* empty, result = h */
-if (opnd[1] >= 0) R[opnd[1]] = c;                       /* store result */
+if (opnd[1] >= 0)                                       /* store result */
+    R[opnd[1]] = c;
 else Write (opnd[2], c, L_LONG, WA);
-if (ar == 0) return CC_Z | CC_V;                        /* empty, cc = 0110 */
+if (ar == 0)                                            /* empty, cc = 0110 */
+    return CC_Z | CC_V;
 return 0;                                               /* q can't be empty */
 }
 
@@ -788,7 +830,8 @@ if (PSL & PSL_FPD) {                                    /* FPD set? */
     SETPC (fault_PC + STR_GETDPC (R[0]));               /* reset PC */
     fill = STR_GETCHR (R[0]);                           /* get fill */
     R[2] = R[2] & STR_LNMASK;                           /* mask lengths */
-    if (R[4] > 0) R[4] = R[4] & STR_LNMASK;
+    if (R[4] > 0)
+        R[4] = R[4] & STR_LNMASK;
     }
 else {
     R[1] = opnd[1];                                     /* src addr */
@@ -833,7 +876,8 @@ switch (R[5] & MVC_M_STATE) {                           /* case on state */
 
     case MVC_FRWD:                                      /* move forward */
         mlnt[0] = (4 - R[3]) & 3;                       /* length to align */
-        if (mlnt[0] > R[2]) mlnt[0] = R[2];             /* cant exceed total */
+        if (mlnt[0] > R[2])                             /* cant exceed total */
+            mlnt[0] = R[2];
         mlnt[1] = (R[2] - mlnt[0]) & ~03;               /* aligned length */
         mlnt[2] = R[2] - mlnt[0] - mlnt[1];             /* tail */
         for (i = 0; i < 3; i++) {                       /* head, align, tail */
@@ -850,7 +894,8 @@ switch (R[5] & MVC_M_STATE) {                           /* case on state */
 
     case MVC_BACK:                                      /* move backward */
         mlnt[0] = R[3] & 03;                            /* length to align */
-        if (mlnt[0] > R[2]) mlnt[0] = R[2];             /* cant exceed total */
+        if (mlnt[0] > R[2])                             /* cant exceed total */
+            mlnt[0] = R[2];
         mlnt[1] = (R[2] - mlnt[0]) & ~03;               /* aligned length */
         mlnt[2] = R[2] - mlnt[0] - mlnt[1];             /* tail */
         for (i = 0; i < 3; i++) {                       /* head, align, tail */
@@ -868,17 +913,19 @@ switch (R[5] & MVC_M_STATE) {                           /* case on state */
 
     case MVC_FILL:                                      /* fill */
     FILL:
-        if (R[4] <= 0) break;                           /* any fill? */
+        if (R[4] <= 0)                                  /* any fill? */
+            break;
         R[5] = R[5] | MVC_FILL;                         /* set state */
         mlnt[0] = (4 - R[3]) & 3;                       /* length to align */
-        if (mlnt[0] > R[4]) mlnt[0] = R[4];             /* cant exceed total */
+        if (mlnt[0] > R[4])                             /* cant exceed total */
+            mlnt[0] = R[4];
         mlnt[1] = (R[4] - mlnt[0]) & ~03;               /* aligned length */
         mlnt[2] = R[4] - mlnt[0] - mlnt[1];             /* tail */
         for (i = 0; i < 3; i++) {                       /* head, align, tail */
             lnt = looplnt[i];                           /* length for loop */
             fill = fill & BMASK;                        /* fill for loop */
-            if (lnt == L_LONG) fill = 
-                (((uint32) fill) << 24) | (fill << 16) | (fill << 8) | fill;
+            if (lnt == L_LONG)
+                fill = (((uint32) fill) << 24) | (fill << 16) | (fill << 8) | fill;
             for (j = 0; j < mlnt[i]; j = j + lnt, sim_interval--) {
                 Write (R[3], fill, lnt, WA);            /* write fill */
                 R[3] = R[3] + lnt;                      /* inc dst addr */
@@ -944,11 +991,14 @@ else {
     }
 R[2] = R[2] & STR_LNMASK;                               /* mask src2len */
 for (s1 = s2 = 0; ((R[0] | R[2]) & STR_LNMASK) != 0; sim_interval--) {
-    if (R[0] & STR_LNMASK) s1 = Read (R[1], L_BYTE, RA);        /* src1? read */
+    if (R[0] & STR_LNMASK)                              /* src1? read */
+        s1 = Read (R[1], L_BYTE, RA);
     else s1 = fill;                                     /* no, use fill */
-    if (R[2]) s2 = Read (R[3], L_BYTE, RA);             /* src2? read */
+    if (R[2])                                           /* src2? read */
+        s2 = Read (R[3], L_BYTE, RA);
     else s2 = fill;                                     /* no, use fill */
-    if (s1 != s2) break;                                /* src1 = src2? */
+    if (s1 != s2)                                       /* src1 = src2? */
+        break;
     if (R[0] & STR_LNMASK) {                            /* if src1, decr */
         R[0] = (R[0] & ~STR_LNMASK) | ((R[0] - 1) & STR_LNMASK);
         R[1] = R[1] + 1;
@@ -992,7 +1042,8 @@ else {
     }
 for ( ; (R[0] & STR_LNMASK) != 0; sim_interval-- ) {    /* loop thru string */
     c = Read (R[1], L_BYTE, RA);                        /* get src byte */
-    if ((c == match) ^ skpc) break;                     /* match & locc? */
+    if ((c == match) ^ skpc)                            /* match & locc? */
+        break;
     R[0] = (R[0] & ~STR_LNMASK) | ((R[0] - 1) & STR_LNMASK);
     R[1] = R[1] + 1;                                    /* incr src1adr */
     }
@@ -1033,7 +1084,8 @@ else {
 for ( ; (R[0] & STR_LNMASK) != 0; sim_interval-- ) {    /* loop thru string */
     c = Read (R[1], L_BYTE, RA);                        /* get byte */
     t = Read (R[3] + c, L_BYTE, RA);                    /* get table ent */
-    if (((t & mask) != 0) ^ spanc) break;               /* test vs instr */
+    if (((t & mask) != 0) ^ spanc)                      /* test vs instr */
+        break;
     R[0] = (R[0] & ~STR_LNMASK) | ((R[0] - 1) & STR_LNMASK);
     R[1] = R[1] + 1;
     }
@@ -1067,9 +1119,12 @@ int32 acc;
 in_ie = 1;                                              /* flag int/exc */
 CLR_TRAPS;                                              /* clear traps */
 newpc = ReadLP ((SCBB + vec) & PAMASK);                 /* read new PC */
-if (ei < 0) newpc = newpc | 1;                          /* severe? on istk */
-if (newpc & 2) ABORT (STOP_ILLVEC);                     /* bad flags? */
-if (oldpsl & PSL_IS) newpsl = PSL_IS;                   /* on int stk? */
+if (ei < 0)                                             /* severe? on istk */
+    newpc = newpc | 1;
+if (newpc & 2)                                          /* bad flags? */
+    ABORT (STOP_ILLVEC);
+if (oldpsl & PSL_IS)                                    /* on int stk? */
+    newpsl = PSL_IS;
 else {
     STK[oldcur] = SP;                                   /* no, save cur stk */
     if (newpc & 1) {                                    /* to int stk? */
@@ -1081,12 +1136,13 @@ else {
         SP = KSP;                                       /* new stack */
         }
     }
-if (ei > 0) PSL = cpu_psl_ipl (newpsl | (ipl << PSL_V_IPL)); /* if int, new IPL */
-else PSL = cpu_psl_ipl (newpsl |
+if (ei > 0)                                             /* if int, new IPL */
+    PSL = cpu_psl_ipl_idle (newpsl | (ipl << PSL_V_IPL));
+else PSL = cpu_psl_ipl_idle (newpsl |                   /* exc, old IPL/1F */
     ((newpc & 1)? PSL_IPL1F: (oldpsl & PSL_IPL)) | (oldcur << PSL_V_PRV));
-if (DEBUG_PRI (cpu_dev, LOG_CPU_I)) fprintf (sim_deb,
-    ">>IEX: PC=%08x, PSL=%08x, SP=%08x, VEC=%08x, nPSL=%08x, nSP=%08x\n",
-    PC, oldpsl, oldsp, vec, PSL, SP);
+if (DEBUG_PRI (cpu_dev, LOG_CPU_I))
+    fprintf (sim_deb, ">>IEX: PC=%08x, PSL=%08x, SP=%08x, VEC=%08x, nPSL=%08x, nSP=%08x\n",
+             PC, oldpsl, oldsp, vec, PSL, SP);
 acc = ACC_MASK (KERN);                                  /* new mode is kernel */
 Write (SP - 4, oldpsl, L_LONG, WA);                     /* push old PSL */
 Write (SP - 8, PC, L_LONG, WA);                         /* push old PC */
@@ -1107,9 +1163,11 @@ int32 mode = opc & PSL_M_MODE;
 int32 cur = PSL_GETCUR (PSL);
 int32 tsp, newpc, acc, sta;
 
-if (PSL & PSL_IS) ABORT (STOP_CHMFI);
+if (PSL & PSL_IS)
+    ABORT (STOP_CHMFI);
 newpc = ReadLP ((SCBB + SCB_CHMK + (mode << 2)) & PAMASK);
-if (cur < mode) mode = cur;                             /* only inward */
+if (cur < mode)                                         /* only inward */
+    mode = cur;
 STK[cur] = SP;                                          /* save stack */
 tsp = STK[mode];                                        /* get new stk */
 acc = ACC_MASK (mode);                                  /* set new mode */
@@ -1162,7 +1220,8 @@ int32 oldcur = PSL_GETCUR (PSL);
 int32 newipl, i;
 
 if ((newpsl & PSL_MBZ) ||                               /* rule 8 */
-    (newcur < oldcur)) RSVD_OPND_FAULT;                 /* rule 1 */
+    (newcur < oldcur))                                  /* rule 1 */
+    RSVD_OPND_FAULT;
 if (newcur) {                                           /* to esu, skip 2,4,7 */
     if ((newpsl & (PSL_IS | PSL_IPL)) ||                /* rules 3,5 */
         (newcur > PSL_GETPRV (newpsl)))                 /* rule 6 */
@@ -1173,26 +1232,31 @@ else {                                                  /* to k, skip 3,5,6 */
     if ((newpsl & PSL_IS) &&                            /* setting IS? */
        (((PSL & PSL_IS) == 0) || (newipl == 0)))        /* test rules 2,4 */
         RSVD_OPND_FAULT;                                /* else skip 2,4 */
-    if (newipl > PSL_GETIPL (PSL)) RSVD_OPND_FAULT;     /* test rule 7 */
+    if (newipl > PSL_GETIPL (PSL))                      /* test rule 7 */
+        RSVD_OPND_FAULT;
     }                                                   /* end if kernel */
 if (newpsl & PSL_CM) {                                  /* setting cmode? */
-    if (BadCmPSL (newpsl)) RSVD_OPND_FAULT;             /* validate PSL */
-    for (i = 0; i < 7; i++) R[i] = R[i] & WMASK;        /* mask R0-R6, PC */
+    if (BadCmPSL (newpsl))                              /* validate PSL */
+        RSVD_OPND_FAULT;
+    for (i = 0; i < 7; i++)                             /* mask R0-R6, PC */
+        R[i] = R[i] & WMASK;
     newpc = newpc & WMASK;
     }
 SP = SP + 8;                                            /* pop stack */
-if (PSL & PSL_IS) IS = SP;                              /* save stack */
+if (PSL & PSL_IS)                                       /* save stack */
+    IS = SP;
 else STK[oldcur] = SP;
-if (DEBUG_PRI (cpu_dev, LOG_CPU_R)) fprintf (sim_deb,
-    ">>REI: PC=%08x, PSL=%08x, SP=%08x, nPC=%08x, nPSL=%08x, nSP=%08x\n",
-    PC, PSL, SP - 8, newpc, newpsl, ((newpsl & IS)? IS: STK[newcur]));
-PSL = cpu_psl_ipl ((PSL & PSL_TP) | (newpsl & ~CC_MASK)); /* set new PSL */
-if (PSL & PSL_IS) SP = IS;                              /* set new stack */
+if (DEBUG_PRI (cpu_dev, LOG_CPU_R))
+    fprintf (sim_deb, ">>REI: PC=%08x, PSL=%08x, SP=%08x, nPC=%08x, nPSL=%08x, nSP=%08x\n",
+             PC, PSL, SP - 8, newpc, newpsl, ((newpsl & IS)? IS: STK[newcur]));
+PSL = cpu_psl_ipl_idle ((PSL & PSL_TP) | (newpsl & ~CC_MASK)); /* set PSL */
+if (PSL & PSL_IS)                                       /* set new stack */
+    SP = IS;
 else {
     SP = STK[newcur];                                   /* if ~IS, chk AST */
     if (newcur >= ASTLVL) {
-        if (DEBUG_PRI (cpu_dev, LOG_CPU_R)) fprintf (sim_deb,
-            ">>REI: AST delivered\n");
+        if (DEBUG_PRI (cpu_dev, LOG_CPU_R))
+            fprintf (sim_deb, ">>REI: AST delivered\n");
         SISR = SISR | SISR_2;
         }
     }
@@ -1206,7 +1270,8 @@ void op_ldpctx (int32 acc)
 {
 int32 newpc, newpsl, pcbpa, t;
 
-if (PSL & PSL_CUR) RSVD_INST_FAULT;                     /* must be kernel */
+if (PSL & PSL_CUR)                                      /* must be kernel */
+    RSVD_INST_FAULT;
 pcbpa = PCBB & PAMASK;                                  /* phys address */
 KSP = ReadLP (pcbpa);                                   /* restore stk ptrs */
 ESP = ReadLP (pcbpa + 4);
@@ -1230,7 +1295,7 @@ newpc = ReadLP (pcbpa + 72);                            /* get PC, PSL */
 newpsl = ReadLP (pcbpa + 76);
 
 t = ReadLP (pcbpa + 80);
-ML_BR_TEST (t);                                         /* validate P0BR */
+ML_PXBR_TEST (t);                                       /* validate P0BR */
 P0BR = t & BR_MASK;                                     /* restore P0BR */
 t = ReadLP (pcbpa + 84);
 LP_MBZ84_TEST (t);                                      /* test mbz */
@@ -1240,7 +1305,7 @@ t = (t >> 24) & AST_MASK;
 LP_AST_TEST (t);                                        /* validate AST */
 ASTLVL = t;                                             /* restore AST */
 t = ReadLP (pcbpa + 88);
-ML_BR_TEST (t + 0x800000);                              /* validate P1BR */
+ML_PXBR_TEST (t + 0x800000);                            /* validate P1BR */
 P1BR = t & BR_MASK;                                     /* restore P1BR */
 t = ReadLP (pcbpa + 92);
 LP_MBZ92_TEST (t);                                      /* test MBZ */
@@ -1250,10 +1315,11 @@ pme = (t >> 31) & 1;                                    /* restore PME */
 
 zap_tb (0);                                             /* clear process TB */
 set_map_reg ();
-if (DEBUG_PRI (cpu_dev, LOG_CPU_P)) fprintf (sim_deb,
-    ">>LDP: PC=%08x, PSL=%08x, SP=%08x, nPC=%08x, nPSL=%08x, nSP=%08x\n",
-    PC, PSL, SP, newpc, newpsl, KSP);
-if (PSL & PSL_IS) IS = SP;                              /* if istk, */
+if (DEBUG_PRI (cpu_dev, LOG_CPU_P))
+    fprintf (sim_deb, ">>LDP: PC=%08x, PSL=%08x, SP=%08x, nPC=%08x, nPSL=%08x, nSP=%08x\n",
+             PC, PSL, SP, newpc, newpsl, KSP);
+if (PSL & PSL_IS)                                       /* if istk, */
+    IS = SP;
 PSL = PSL & ~PSL_IS;                                    /* switch to kstk */
 SP = KSP - 8;
 Write (SP, newpc, L_LONG, WA);                          /* push PC, PSL */
@@ -1267,18 +1333,20 @@ void op_svpctx (int32 acc)
 {
 int32 savpc, savpsl, pcbpa;
 
-if (PSL & PSL_CUR) RSVD_INST_FAULT;                     /* must be kernel */
+if (PSL & PSL_CUR)                                      /* must be kernel */
+    RSVD_INST_FAULT;
 savpc = Read (SP, L_LONG, RA);                          /* pop PC, PSL */
 savpsl = Read (SP + 4, L_LONG, RA);
-if (DEBUG_PRI (cpu_dev, LOG_CPU_P)) fprintf (sim_deb,
-    ">>SVP: PC=%08x, PSL=%08x, SP=%08x, oPC=%08x, oPSL=%08x\n",
-    PC, PSL, SP, savpc, savpsl);
-if (PSL & PSL_IS) SP = SP + 8;                          /* int stack? */
+if (DEBUG_PRI (cpu_dev, LOG_CPU_P))
+    fprintf (sim_deb, ">>SVP: PC=%08x, PSL=%08x, SP=%08x, oPC=%08x, oPSL=%08x\n",
+             PC, PSL, SP, savpc, savpsl);
+if (PSL & PSL_IS)                                       /* int stack? */
+    SP = SP + 8;
 else {
     KSP = SP + 8;                                       /* pop kernel stack */
     SP = IS;                                            /* switch to int stk */
     if ((PSL & PSL_IPL) == 0)                           /* make IPL > 0 */
-         PSL = cpu_psl_ipl (PSL | PSL_IPL1);
+         PSL = PSL | PSL_IPL1;
     PSL = PSL | PSL_IS;                                 /* set PSL<is> */
     }
 pcbpa = PCBB & PAMASK;
@@ -1320,7 +1388,8 @@ int32 ba = opnd[2];
 int32 prv = PSL_GETPRV (PSL);
 int32 acc, sta, sta1;
 
-if (prv > mode) mode = prv;                             /* maximize mode */
+if (prv > mode)                                         /* maximize mode */
+    mode = prv;
 acc = ACC_MASK (mode) << (rw? TLB_V_WACC: 0);           /* set acc mask */
 Test (ba, acc, &sta);                                   /* probe */
 switch (sta) {                                          /* case on status */
@@ -1367,13 +1436,16 @@ int32 val = opnd[0];
 int32 prn = opnd[1];
 int32 cc;
 
-if (PSL & PSL_CUR) RSVD_INST_FAULT;                     /* must be kernel */
-if (prn > 63) RSVD_OPND_FAULT;                          /* reg# > 63? fault */
+if (PSL & PSL_CUR)                                      /* must be kernel */
+    RSVD_INST_FAULT;
+if (prn > 63)                                           /* reg# > 63? fault */
+    RSVD_OPND_FAULT;
 CC_IIZZ_L (val);                                        /* set cc's */
 switch (prn) {                                          /* case on reg # */
 
     case MT_KSP:                                        /* KSP */
-        if (PSL & PSL_IS) KSP = val;                    /* on IS? store KSP */
+        if (PSL & PSL_IS)                               /* on IS? store KSP */
+            KSP = val;
         else SP = val;                                  /* else store SP */
         break;
 
@@ -1382,12 +1454,13 @@ switch (prn) {                                          /* case on reg # */
         break;
 
     case MT_IS:                                         /* IS */
-        if (PSL & PSL_IS) SP = val;                     /* on IS? store SP */
+        if (PSL & PSL_IS)                               /* on IS? store SP */
+            SP = val;
         else IS = val;                                  /* else store IS */
         break;
 
     case MT_P0BR:                                       /* P0BR */
-        ML_BR_TEST (val);                               /* validate */
+        ML_PXBR_TEST (val);                             /* validate */
         P0BR = val & BR_MASK;                           /* lw aligned */
         zap_tb (0);                                     /* clr proc TLB */
         set_map_reg ();
@@ -1401,7 +1474,7 @@ switch (prn) {                                          /* case on reg # */
         break;
 
     case MT_P1BR:                                       /* P1BR */
-        ML_BR_TEST (val + 0x800000);                    /* validate */
+        ML_PXBR_TEST (val + 0x800000);                  /* validate */
         P1BR = val & BR_MASK;                           /* lw aligned */
         zap_tb (0);                                     /* clr proc TLB */
         set_map_reg ();
@@ -1415,7 +1488,7 @@ switch (prn) {                                          /* case on reg # */
         break;
 
     case MT_SBR:                                        /* SBR */
-        ML_PA_TEST (val);                               /* validate */
+        ML_SBR_TEST (val);                              /* validate */
         SBR = val & BR_MASK;                            /* lw aligned */
         zap_tb (1);                                     /* clr entire TLB */
         set_map_reg ();
@@ -1439,16 +1512,18 @@ switch (prn) {                                          /* case on reg # */
         break;
 
     case MT_IPL:                                        /* IPL */
-        PSL = cpu_psl_ipl ((PSL & ~PSL_IPL) | ((val & PSL_M_IPL) << PSL_V_IPL));
+        PSL = (PSL & ~PSL_IPL) | ((val & PSL_M_IPL) << PSL_V_IPL);
         break;
 
     case MT_ASTLVL:                                     /* ASTLVL */
-        if (val > AST_MAX) RSVD_OPND_FAULT;             /* > 4? fault */
+        if (val > AST_MAX)                              /* > 4? fault */
+            RSVD_OPND_FAULT;
         ASTLVL = val;
         break;
 
     case MT_SIRR:                                       /* SIRR */
-        if ((val > 0xF) || (val == 0)) RSVD_OPND_FAULT;
+        if ((val > 0xF) || (val == 0))
+            RSVD_OPND_FAULT;
         SISR = SISR | (1 << val);                       /* set bit in SISR */
         break;
 
@@ -1467,7 +1542,8 @@ switch (prn) {                                          /* case on reg # */
         break;
 
     case MT_TBCHK:                                      /* TBCHK */
-        if (chk_tb_ent (val)) cc = cc | CC_V;
+        if (chk_tb_ent (val))
+            cc = cc | CC_V;
         break;
 
     case MT_PME:                                        /* PME */
@@ -1487,8 +1563,10 @@ int32 op_mfpr (int32 *opnd)
 int32 prn = opnd[0];
 int32 val;
 
-if (PSL & PSL_CUR) RSVD_INST_FAULT;                     /* must be kernel */
-if (prn > 63) RSVD_OPND_FAULT;                          /* reg# > 63? fault */
+if (PSL & PSL_CUR)                                      /* must be kernel */
+    RSVD_INST_FAULT;
+if (prn > 63)                                           /* reg# > 63? fault */
+    RSVD_OPND_FAULT;
 switch (prn) {                                          /* case on reg# */
 
     case MT_KSP:                                        /* KSP */
