@@ -1,6 +1,6 @@
 /* vax_fpa.c - VAX f_, d_, g_floating instructions
 
-   Copyright (c) 1998-2006, Robert M Supnik
+   Copyright (c) 1998-2008, Robert M Supnik
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -23,6 +23,7 @@
    used in advertising or otherwise to promote the sale, use or other dealings
    in this Software without prior written authorization from Robert M Supnik.
 
+   28-May-08    RMS     Inlined physical memory routines
    16-May-06    RMS     Fixed bug in 32b floating multiply routine
                         Fixed bug in 64b extended modulus routine
    03-May-06    RMS     Fixed POLYD, POLYG to clear R4, R5
@@ -59,8 +60,6 @@ extern int32 PSL;
 extern int32 p1;
 extern jmp_buf save_env;
 
-extern int32 Read (uint32 va, int32 size, int32 acc);
-
 #if defined (USE_INT64)
 
 #define M64             0xFFFFFFFFFFFFFFFF              /* 64b */
@@ -125,7 +124,8 @@ src = CONCAT (opnd[2], opnd[1]);                        /* build src */
 if (sc & BSIGN) {                                       /* right shift? */
     *flg = 0;                                           /* no ovflo */
     sc = 0x100 - sc;                                    /* |shift| */
-    if (sc > 63) r = (opnd[2] & LSIGN)? -1: 0;          /* sc > 63? */
+    if (sc > 63)                                        /* sc > 63? */
+        r = (opnd[2] & LSIGN)? -1: 0;
     else r = src >> sc;
     }
 else {
@@ -169,16 +169,21 @@ int32 quo, rem;
 *rh = 0;
 ldvr = ((opnd[0] & LSIGN)? -opnd[0]: opnd[0]) & LMASK;  /* |divisor| */
 ldvd = CONCAT (opnd[2], opnd[1]);                       /* 64b dividend */
-if (opnd[2] & LSIGN) ldvd = -ldvd;                      /* |dividend| */
-if (((ldvd >> 32) & LMASK) >= ldvr) return opnd[1];     /* divide work? */
+if (opnd[2] & LSIGN)                                    /* |dividend| */
+    ldvd = -ldvd;
+if (((ldvd >> 32) & LMASK) >= ldvr)                     /* divide work? */
+    return opnd[1];
 quo = (int32) (ldvd / ldvr);                            /* do divide */
 rem = (int32) (ldvd % ldvr);
 if ((opnd[0] ^ opnd[2]) & LSIGN) {                      /* result -? */
     quo = -quo;                                         /* negate */
-    if (quo && ((quo & LSIGN) == 0)) return opnd[1];    /* right sign? */
+    if (quo && ((quo & LSIGN) == 0))                    /* right sign? */
+        return opnd[1];
     }
-else if (quo & LSIGN) return opnd[1];
-if (opnd[2] & LSIGN) rem = -rem;                        /* sign of rem */
+else if (quo & LSIGN)
+    return opnd[1];
+if (opnd[2] & LSIGN)                                    /* sign of rem */
+    rem = -rem;
 *flg = 0;                                               /* no overflow */
 *rh = rem & LMASK;                                      /* set rem */
 return (quo & LMASK);                                   /* return quo */
@@ -191,17 +196,21 @@ int32 op_cmpfd (int32 h1, int32 l1, int32 h2, int32 l2)
 t_uint64 n1, n2;
 
 if ((h1 & FD_EXP) == 0) {
-    if (h1 & FPSIGN) RSVD_OPND_FAULT;
+    if (h1 & FPSIGN)
+        RSVD_OPND_FAULT;
     h1 = l1 = 0;
     }
 if ((h2 & FD_EXP) == 0) {
-    if (h2 & FPSIGN) RSVD_OPND_FAULT;
+    if (h2 & FPSIGN)
+        RSVD_OPND_FAULT;
     h2 = l2 = 0;
     }
-if ((h1 ^ h2) & FPSIGN) return ((h1 & FPSIGN)? CC_N: 0);
+if ((h1 ^ h2) & FPSIGN)
+    return ((h1 & FPSIGN)? CC_N: 0);
 n1 = UNSCRAM (h1, l1);
 n2 = UNSCRAM (h2, l2);
-if (n1 == n2) return CC_Z;
+if (n1 == n2)
+    return CC_Z;
 return (((n1 < n2) ^ ((h1 & FPSIGN) != 0))? CC_N: 0);
 }
 
@@ -210,17 +219,21 @@ int32 op_cmpg (int32 h1, int32 l1, int32 h2, int32 l2)
 t_uint64 n1, n2;
 
 if ((h1 & G_EXP) == 0) {
-    if (h1 & FPSIGN) RSVD_OPND_FAULT;
+    if (h1 & FPSIGN)
+        RSVD_OPND_FAULT;
     h1 = l1 = 0;
     }
 if ((h2 & G_EXP) == 0) {
-    if (h2 & FPSIGN) RSVD_OPND_FAULT;
+    if (h2 & FPSIGN)
+        RSVD_OPND_FAULT;
     h2 = l2 = 0;
     }
-if ((h1 ^ h2) & FPSIGN) return ((h1 & FPSIGN)? CC_N: 0);
+if ((h1 ^ h2) & FPSIGN)
+    return ((h1 & FPSIGN)? CC_N: 0);
 n1 = UNSCRAM (h1, l1);
 n2 = UNSCRAM (h2, l2);
-if (n1 == n2) return CC_Z;
+if (n1 == n2)
+    return CC_Z;
 return (((n1 < n2) ^ ((h1 & FPSIGN) != 0))? CC_N: 0);
 }
 
@@ -231,7 +244,8 @@ int32 op_cvtifdg (int32 val, int32 *rh, int32 opc)
 UFP a;
 
 if (val == 0) {
-    if (rh) *rh = 0;
+    if (rh)
+        *rh = 0;
     return 0;
     }
 if (val < 0) {
@@ -242,7 +256,8 @@ else a.sign = 0;
 a.exp = 32 + ((opc & 0x100)? G_BIAS: FD_BIAS);
 a.frac = ((t_uint64) val) << (UF_V_NM - 31);
 norm (&a);
-if (opc & 0x100) return rpackg (&a, rh);
+if (opc & 0x100)
+    return rpackg (&a, rh);
 return rpackfd (&a, rh);
 }
 
@@ -261,20 +276,25 @@ if (opc & 0x100) {
     ubexp = a.exp - G_BIAS;
     }
 else {
-    if (opc & 0x20) unpackd (opnd[0], opnd[1], &a);
+    if (opc & 0x20)
+        unpackd (opnd[0], opnd[1], &a);
     else unpackf (opnd[0], &a);
     ubexp = a.exp - FD_BIAS;
     }
-if ((a.exp == 0) || (ubexp < 0)) return 0;
+if ((a.exp == 0) || (ubexp < 0))
+    return 0;
 if (ubexp <= UF_V_NM) {
     a.frac = a.frac >> (UF_V_NM - ubexp);               /* leave rnd bit */
-    if ((opc & 03) == 03) a.frac = a.frac + 1;          /* if CVTR, round */
+    if ((opc & 03) == 03)                               /* if CVTR, round */
+        a.frac = a.frac + 1;
     a.frac = a.frac >> 1;                               /* now justified */
-    if (a.frac > (maxv[lnt] + (a.sign? 1: 0))) *flg = CC_V;
+    if (a.frac > (maxv[lnt] + (a.sign? 1: 0)))
+        *flg = CC_V;
     }
 else {
     *flg = CC_V;                                        /* set overflow */
-    if (ubexp > (UF_V_NM + 32)) return 0;
+    if (ubexp > (UF_V_NM + 32))
+        return 0;
     a.frac = a.frac << (ubexp - UF_V_NM - 1);           /* no rnd bit */
     }
 return ((int32) ((a.sign? (a.frac ^ LMASK) + 1: a.frac) & LMASK));
@@ -336,7 +356,8 @@ if (a->frac == 0) {                                     /* s1 = 0? */
     *a = *b;
     return;
     }
-if (b->frac == 0) return;                               /* s2 = 0? */
+if (b->frac == 0)                                       /* s2 = 0? */
+    return;
 if ((a->exp < b->exp) ||                                /* |s1| < |s2|? swap */
     ((a->exp == b->exp) && (a->frac < b->frac))) {
     t = *a;
@@ -346,7 +367,8 @@ if ((a->exp < b->exp) ||                                /* |s1| < |s2|? swap */
 ediff = a->exp - b->exp;                                /* exp diff */
 if (a->sign ^ b->sign) {                                /* eff sub? */
     if (ediff) {                                        /* exp diff? */
-        if (ediff > 63) b->frac = M64;                  /* retain sticky */
+        if (ediff > 63)                                 /* retain sticky */
+            b->frac = M64;
         else b->frac = ((-((t_int64) b->frac) >> ediff) | /* denormalize */
             (M64 << (64 - ediff)));                     /* preserve sign */
         a->frac = a->frac + b->frac;                    /* add frac */
@@ -355,8 +377,10 @@ if (a->sign ^ b->sign) {                                /* eff sub? */
     norm (a);                                           /* normalize */
     }
 else {
-    if (ediff > 63) b->frac = 0;                        /* add */
-    else if (ediff) b->frac = b->frac >> ediff;         /* denormalize */
+    if (ediff > 63)                                     /* add */
+        b->frac = 0;
+    else if (ediff)                                     /* denormalize */
+        b->frac = b->frac >> ediff;
     a->frac = a->frac + b->frac;                        /* add frac */
     if (a->frac < b->frac) {                            /* chk for carry */
         a->frac = UF_NM | (a->frac >> 1);               /* shift in carry */
@@ -390,9 +414,11 @@ if (qd) {                                               /* 64b needed? */
     rlo = al * bl;
     rhi = rhi + ((rmid1 >> 32) & LMASK) + ((rmid2 >> 32) & LMASK);
     rmid1 = rlo + (rmid1 << 32);                        /* add mid1 to lo */
-    if (rmid1 < rlo) rhi = rhi + 1;                     /* carry? incr hi */
+    if (rmid1 < rlo)                                    /* carry? incr hi */
+        rhi = rhi + 1;
     rmid2 = rmid1 + (rmid2 << 32);                      /* add mid2 to lo */
-    if (rmid2 < rmid1) rhi = rhi + 1;                   /* carry? incr hi */
+    if (rmid2 < rmid1)                                  /* carry? incr hi */
+        rhi = rhi + 1;
     }
 a->frac = rhi & ~mask;
 norm (a);                                               /* normalize */
@@ -411,7 +437,8 @@ return;
 
 void vax_fmod (UFP *a, int32 bias, int32 *intgr, int32 *flg)
 {
-if (a->exp <= bias) *intgr = *flg = 0;                  /* 0 or <1? int = 0 */
+if (a->exp <= bias)                                     /* 0 or <1? int = 0 */
+    *intgr = *flg = 0;
 else if (a->exp <= (bias + 64)) {                       /* in range [1,64]? */
     *intgr = (int32) (a->frac >> (64 - (a->exp - bias)));
     if ((a->exp > (bias + 32)) ||                       /* test ovflo */
@@ -419,8 +446,10 @@ else if (a->exp <= (bias + 64)) {                       /* in range [1,64]? */
          (((uint32) *intgr) > (a->sign? 0x80000000: 0x7FFFFFFF))))
         *flg = CC_V;
     else *flg = 0;
-    if (a->sign) *intgr = -*intgr;                      /* -? comp int */
-    if (a->exp == (bias + 64)) a->frac = 0;             /* special case 64 */
+    if (a->sign)                                        /* -? comp int */
+        *intgr = -*intgr;
+    if (a->exp == (bias + 64))                          /* special case 64 */
+        a->frac = 0;
     else a->frac = a->frac << (a->exp - bias);
     a->exp = bias;
     }
@@ -444,8 +473,10 @@ void vax_fdiv (UFP *a, UFP *b, int32 prec, int32 bias)
 int32 i;
 t_uint64 quo = 0;
 
-if (a->exp == 0) FLT_DZRO_FAULT;                        /* divr = 0? */
-if (b->exp == 0) return;                                /* divd = 0? */
+if (a->exp == 0)                                        /* divr = 0? */
+    FLT_DZRO_FAULT;
+if (b->exp == 0)                                        /* divd = 0? */
+    return;
 b->sign = b->sign ^ a->sign;                            /* result sign */
 b->exp = b->exp - a->exp + bias + 1;                    /* unbiased exp */
 a->frac = a->frac >> 1;                                 /* allow 1 bit left */
@@ -470,7 +501,8 @@ void unpackf (int32 hi, UFP *r)
 r->sign = hi & FPSIGN;                                  /* get sign */
 r->exp = FD_GETEXP (hi);                                /* get exponent */
 if (r->exp == 0) {                                      /* exp = 0? */
-    if (r->sign) RSVD_OPND_FAULT;                       /* if -, rsvd op */
+    if (r->sign)                                        /* if -, rsvd op */
+        RSVD_OPND_FAULT;
     r->frac = 0;                                        /* else 0 */
     return;
     }
@@ -484,7 +516,8 @@ void unpackd (int32 hi, int32 lo, UFP *r)
 r->sign = hi & FPSIGN;                                  /* get sign */
 r->exp = FD_GETEXP (hi);                                /* get exponent */
 if (r->exp == 0) {                                      /* exp = 0? */
-    if (r->sign) RSVD_OPND_FAULT;                       /* if -, rsvd op */
+    if (r->sign)                                        /* if -, rsvd op */
+        RSVD_OPND_FAULT;
     r->frac = 0;                                        /* else 0 */
     return;
     }
@@ -498,7 +531,8 @@ void unpackg (int32 hi, int32 lo, UFP *r)
 r->sign = hi & FPSIGN;                                  /* get sign */
 r->exp = G_GETEXP (hi);                                 /* get exponent */
 if (r->exp == 0) {                                      /* exp = 0? */
-    if (r->sign) RSVD_OPND_FAULT;                       /* if -, rsvd op */
+    if (r->sign)                                        /* if -, rsvd op */
+        RSVD_OPND_FAULT;
     r->frac = 0;                                        /* else 0 */
     return;
     }
@@ -522,7 +556,8 @@ if (r->frac == 0) {                                     /* if fraction = 0 */
     }
 while ((r->frac & UF_NM) == 0) {                        /* normalized? */
     for (i = 0; i < 5; i++) {                           /* find first 1 */
-        if (r->frac & normmask[i]) break;
+        if (r->frac & normmask[i])
+            break;
         }
     r->frac = r->frac << normtab[i];                    /* shift frac */
     r->exp = r->exp - normtab[i];                       /* decr exp */
@@ -532,37 +567,45 @@ return;
 
 int32 rpackfd (UFP *r, int32 *rh)
 {
-if (rh) *rh = 0;                                        /* assume 0 */
-if (r->frac == 0) return 0;                             /* result 0? */
+if (rh)                                                 /* assume 0 */
+    *rh = 0;
+if (r->frac == 0)                                       /* result 0? */
+    return 0;
 r->frac = r->frac + (rh? UF_DRND: UF_FRND);             /* round */
 if ((r->frac & UF_NM) == 0) {                           /* carry out? */
     r->frac = r->frac >> 1;                             /* renormalize */
     r->exp = r->exp + 1;
     }
-if (r->exp > (int32) FD_M_EXP) FLT_OVFL_FAULT;          /* ovflo? fault */
+if (r->exp > (int32) FD_M_EXP)                          /* ovflo? fault */
+    FLT_OVFL_FAULT;
 if (r->exp <= 0) {                                      /* underflow? */
-    if (PSL & PSW_FU) FLT_UNFL_FAULT;                   /* fault if fu */
+    if (PSL & PSW_FU)                                   /* fault if fu */
+        FLT_UNFL_FAULT;
     return 0;                                           /* else 0 */
     }
-if (rh) *rh = UF_GETFDLO (r->frac);                     /* get low */
+if (rh)                                                 /* get low */
+    *rh = UF_GETFDLO (r->frac);
 return r->sign | (r->exp << FD_V_EXP) | UF_GETFDHI (r->frac);
 }
 
 int32 rpackg (UFP *r, int32 *rh)
 {
 *rh = 0;                                                /* assume 0 */
-if (r->frac == 0) return 0;                             /* result 0? */
+if (r->frac == 0)                                       /* result 0? */
+    return 0;
 r->frac = r->frac + UF_GRND;                            /* round */
 if ((r->frac & UF_NM) == 0) {                           /* carry out? */
     r->frac = r->frac >> 1;                             /* renormalize */
     r->exp = r->exp + 1;
     }
-if (r->exp > (int32) G_M_EXP) FLT_OVFL_FAULT;           /* ovflo? fault */
+if (r->exp > (int32) G_M_EXP)                           /* ovflo? fault */
+    FLT_OVFL_FAULT;
 if (r->exp <= 0) {                                      /* underflow? */
-    if (PSL & PSW_FU) FLT_UNFL_FAULT;                   /* fault if fu */
+    if (PSL & PSW_FU)                                   /* fault if fu */
+        FLT_UNFL_FAULT;
     return 0;                                           /* else 0 */
     }
-if (rh) *rh = UF_GETGLO (r->frac);                      /* get low */
+*rh = UF_GETGLO (r->frac);                              /* get low */
 return r->sign | (r->exp << G_V_EXP) | UF_GETGHI (r->frac);
 }
 
@@ -645,10 +688,13 @@ int32 op_emul (int32 mpy, int32 mpc, int32 *rh)
 UDP r;
 int32 sign = mpy ^ mpc;                                 /* sign of result */
 
-if (mpy & LSIGN) mpy = -mpy;                            /* abs value */
-if (mpc & LSIGN) mpc = -mpc;
+if (mpy & LSIGN)                                        /* abs value */
+    mpy = -mpy;
+if (mpc & LSIGN)
+    mpc = -mpc;
 dp_imul (mpy & LMASK, mpc & LMASK, &r);                 /* 32b * 32b -> 64b */
-if (sign & LSIGN) dp_neg (&r);                          /* negative result? */
+if (sign & LSIGN)                                       /* negative result? */
+    dp_neg (&r);
 *rh = r.hi;
 return r.lo;
 }
@@ -669,9 +715,12 @@ dvd.lo = opnd[1];                                       /* get dividend */
 dvd.hi = opnd[2];
 *flg = CC_V;                                            /* assume error */
 *rh = 0;
-if (dvd.hi & LSIGN) dp_neg (&dvd);                      /* |dividend| */
-if (dvr & LSIGN) dvr = NEG (dvr);                       /* |divisor| */
-if (dvd.hi >= dvr) return opnd[1];                      /* divide work? */
+if (dvd.hi & LSIGN)                                     /* |dividend| */
+    dp_neg (&dvd);
+if (dvr & LSIGN)                                        /* |divisor| */
+    dvr = NEG (dvr);
+if (dvd.hi >= dvr)                                      /* divide work? */
+    return opnd[1];
 for (i = quo = 0; i < 32; i++) {                        /* 32 iterations */
     quo = quo << 1;                                     /* shift quotient */
     dp_lsh (&dvd, 1);                                   /* shift dividend */
@@ -682,10 +731,13 @@ for (i = quo = 0; i < 32; i++) {                        /* 32 iterations */
     }
 if ((opnd[0] ^ opnd[2]) & LSIGN) {                      /* result -? */
     quo = NEG (quo);                                    /* negate */
-    if (quo && ((quo & LSIGN) == 0)) return opnd[1];    /* right sign? */
+    if (quo && ((quo & LSIGN) == 0))                    /* right sign? */
+        return opnd[1];
     }
-else if (quo & LSIGN) return opnd[1];
-if (opnd[2] & LSIGN) *rh = NEG (dvd.hi);                /* sign of rem */
+else if (quo & LSIGN)
+    return opnd[1];
+if (opnd[2] & LSIGN)                                    /* sign of rem */
+    *rh = NEG (dvd.hi);
 else *rh = dvd.hi;
 *flg = 0;                                               /* no overflow */
 return quo;                                             /* return quo */
@@ -700,11 +752,15 @@ int32 r;
 
 unpackd (h1, l1, &a);
 unpackd (h2, l2, &b);
-if (a.sign != b.sign) return (a.sign? CC_N: 0);
+if (a.sign != b.sign)
+    return (a.sign? CC_N: 0);
 r = a.exp - b.exp;
-if (r == 0) r = dp_cmp (&a.frac, &b.frac);
-if (r < 0) return (a.sign? 0: CC_N);
-if (r > 0) return (a.sign? CC_N: 0);
+if (r == 0)
+    r = dp_cmp (&a.frac, &b.frac);
+if (r < 0)
+    return (a.sign? 0: CC_N);
+if (r > 0)
+    return (a.sign? CC_N: 0);
 return CC_Z;
 }
 
@@ -715,11 +771,15 @@ int32 r;
 
 unpackg (h1, l1, &a);
 unpackg (h2, l2, &b);
-if (a.sign != b.sign) return (a.sign? CC_N: 0);
+if (a.sign != b.sign)
+    return (a.sign? CC_N: 0);
 r = a.exp - b.exp;
-if (r == 0) r = dp_cmp (&a.frac, &b.frac);
-if (r < 0) return (a.sign? 0: CC_N);
-if (r > 0) return (a.sign? CC_N: 0);
+if (r == 0)
+    r = dp_cmp (&a.frac, &b.frac);
+if (r < 0)
+    return (a.sign? 0: CC_N);
+if (r > 0)
+    return (a.sign? CC_N: 0);
 return CC_Z;
 }
 
@@ -742,7 +802,8 @@ a.exp = 32 + ((opc & 0x100)? G_BIAS: FD_BIAS);          /* initial exp */
 a.frac.hi = val & LMASK;                                /* fraction */
 a.frac.lo = 0;
 norm (&a);                                              /* normalize */
-if (opc & 0x100) return rpackg (&a, rh);                /* pack and return */
+if (opc & 0x100)                                        /* pack and return */
+    return rpackg (&a, rh);
 return rpackfd (&a, rh);
 }
 
@@ -761,21 +822,26 @@ if (opc & 0x100) {                                      /* G? */
     ubexp = a.exp - G_BIAS;                             /* unbiased exp */
     }
 else {
-    if (opc & 0x20) unpackd (opnd[0], opnd[1], &a);     /* F or D */
+    if (opc & 0x20)                                     /* F or D */
+        unpackd (opnd[0], opnd[1], &a);
     else unpackf (opnd[0], &a);                         /* unpack */
     ubexp = a.exp - FD_BIAS;                            /* unbiased exp */
     }
-if ((a.exp == 0) || (ubexp < 0)) return 0;              /* true zero or frac? */
+if ((a.exp == 0) || (ubexp < 0))                        /* true zero or frac? */
+    return 0;
 if (ubexp <= UF_V_NM) {                                 /* exp in range? */
     dp_rsh (&a.frac, UF_V_NM - ubexp);                  /* leave rnd bit */
-    if (lnt == 03) dp_inc (&a.frac);                    /* if CVTR, round */
+    if (lnt == 03)                                      /* if CVTR, round */
+        dp_inc (&a.frac);
     dp_rsh (&a.frac, 1);                                /* now justified */
     if ((a.frac.hi != 0) ||
-        (a.frac.lo > (maxv[lnt] + (a.sign? 1: 0)))) *flg = CC_V;
+        (a.frac.lo > (maxv[lnt] + (a.sign? 1: 0))))
+        *flg = CC_V;
     }
 else {
     *flg = CC_V;                                        /* always ovflo */
-    if (ubexp > (UF_V_NM + 32)) return 0;               /* in ext range? */
+    if (ubexp > (UF_V_NM + 32))                         /* in ext range? */
+        return 0;
     dp_lsh (&a.frac, ubexp - UF_V_NM - 1);              /* no rnd bit */
     }
 return (a.sign? NEG (a.frac.lo): a.frac.lo);            /* return lo frac */
@@ -839,7 +905,8 @@ if ((a->frac.hi == 0) && (a->frac.lo == 0)) {           /* s1 = 0? */
     *a = *b;
     return;
     }
-if ((b->frac.hi == 0) && (b->frac.lo == 0)) return;     /* s2 = 0? */
+if ((b->frac.hi == 0) && (b->frac.lo == 0))             /* s2 = 0? */
+    return;
 if ((a->exp < b->exp) ||                                /* |s1| < |s2|? swap */
     ((a->exp == b->exp) && (dp_cmp (&a->frac, &b->frac) < 0))) {
     t = *a;
@@ -857,7 +924,8 @@ if (a->sign ^ b->sign) {                                /* eff sub? */
     norm (a);                                           /* normalize */
     }
 else {
-    if (ediff) dp_rsh (&b->frac, ediff);                /* add, denormalize */
+    if (ediff)                                          /* add, denormalize */
+        dp_rsh (&b->frac, ediff);
     dp_add (&a->frac, &b->frac);                        /* add frac */
     if (dp_cmp (&a->frac, &b->frac) < 0) {              /* chk for carry */
         dp_rsh (&a->frac, 1);                           /* renormalize */
@@ -893,9 +961,11 @@ if (qd) {                                               /* 64b needed? */
     if (rhi.lo < rmid2.hi)
          rhi.hi = (rhi.hi + 1) & LMASK;
     rlo.hi = (rlo.hi + rmid1.lo) & LMASK;               /* add mid1 to low res */
-    if (rlo.hi < rmid1.lo) dp_inc (&rhi);               /* carry? incr high res */
+    if (rlo.hi < rmid1.lo)                              /* carry? incr high res */
+        dp_inc (&rhi);
     rlo.hi = (rlo.hi + rmid2.lo) & LMASK;               /* add mid2 to low res */
-    if (rlo.hi < rmid2.lo) dp_inc (&rhi);               /* carry? incr high res */
+    if (rlo.hi < rmid2.lo)                              /* carry? incr high res */
+        dp_inc (&rhi);
     }
 a->frac.hi = rhi.hi & ~mhi;                             /* mask fraction */
 a->frac.lo = rhi.lo & ~mlo;
@@ -917,7 +987,8 @@ void vax_fmod (UFP *a, int32 bias, int32 *intgr, int32 *flg)
 {
 UDP ifr;
 
-if (a->exp <= bias) *intgr = *flg = 0;                  /* 0 or <1? int = 0 */
+if (a->exp <= bias)                                     /* 0 or <1? int = 0 */
+    *intgr = *flg = 0;
 else if (a->exp <= (bias + 64)) {                       /* in range [1,64]? */
     ifr = a->frac;
     dp_rsh (&ifr, 64 - (a->exp - bias));                /* separate integer */
@@ -927,7 +998,8 @@ else if (a->exp <= (bias + 64)) {                       /* in range [1,64]? */
         *flg = CC_V;
     else *flg = 0;
     *intgr = ifr.lo;
-    if (a->sign) *intgr = -*intgr;                      /* -? comp int */
+    if (a->sign)                                        /* -? comp int */
+        *intgr = -*intgr;
     dp_lsh (&a->frac, a->exp - bias);                   /* excise integer */
     a->exp = bias;
     }
@@ -951,8 +1023,10 @@ void vax_fdiv (UFP *a, UFP *b, int32 prec, int32 bias)
 int32 i;
 UDP quo = { 0, 0 };
 
-if (a->exp == 0) FLT_DZRO_FAULT;                        /* divr = 0? */
-if (b->exp == 0) return;                                /* divd = 0? */
+if (a->exp == 0)                                        /* divr = 0? */
+    FLT_DZRO_FAULT;
+if (b->exp == 0)                                        /* divd = 0? */
+    return;
 b->sign = b->sign ^ a->sign;                            /* result sign */
 b->exp = b->exp - a->exp + bias + 1;                    /* unbiased exp */
 dp_rsh (&a->frac, 1);                                   /* allow 1 bit left */
@@ -975,17 +1049,22 @@ return;
 
 int32 dp_cmp (UDP *a, UDP *b)
 {
-if (a->hi < b->hi) return -1;                           /* compare hi */
-if (a->hi > b->hi) return +1;
-if (a->lo < b->lo) return -1;                           /* hi =, compare lo */
-if (a->lo > b->lo) return +1;
+if (a->hi < b->hi)                                      /* compare hi */
+    return -1;
+if (a->hi > b->hi)
+    return +1;
+if (a->lo < b->lo)                                      /* hi =, compare lo */
+    return -1;
+if (a->lo > b->lo)
+    return +1;
 return 0;                                               /* hi, lo equal */
 }
 
 void dp_add (UDP *a, UDP *b)
 {
 a->lo = (a->lo + b->lo) & LMASK;                        /* add lo */
-if (a->lo < b->lo) a->hi = a->hi + 1;                   /* carry? */
+if (a->lo < b->lo)                                      /* carry? */
+    a->hi = a->hi + 1;
 a->hi = (a->hi + b->hi) & LMASK;                        /* add hi */
 return;
 }
@@ -993,13 +1072,15 @@ return;
 void dp_inc (UDP *a)
 {
 a->lo = (a->lo + 1) & LMASK;                            /* inc lo */
-if (a->lo == 0) a->hi = (a->hi + 1) & LMASK;            /* carry? inc hi */
+if (a->lo == 0)                                         /* carry? inc hi */
+    a->hi = (a->hi + 1) & LMASK;
 return;
 }
 
 void dp_sub (UDP *a, UDP *b)
 {
-if (a->lo < b->lo) a->hi = a->hi - 1;                   /* borrow? decr hi */
+if (a->lo < b->lo)                                      /* borrow? decr hi */
+    a->hi = a->hi - 1;
 a->lo = (a->lo - b->lo) & LMASK;                        /* sub lo */
 a->hi = (a->hi - b->hi) & LMASK;                        /* sub hi */
 return;
@@ -1007,7 +1088,8 @@ return;
 
 void dp_lsh (UDP *r, uint32 sc)
 {
-if (sc > 63) r->hi = r->lo = 0;                         /* > 63? result 0 */
+if (sc > 63)                                            /* > 63? result 0 */
+    r->hi = r->lo = 0;
 else if (sc > 31) {                                     /* [32,63]? */
     r->hi = (r->lo << (sc - 32)) & LMASK;
     r->lo = 0;
@@ -1021,7 +1103,8 @@ return;
 
 void dp_rsh (UDP *r, uint32 sc)
 {
-if (sc > 63) r->hi = r->lo = 0;                         /* > 63? result 0 */
+if (sc > 63)                                            /* > 63? result 0 */
+    r->hi = r->lo = 0;
 else if (sc > 31) {                                     /* [32,63]? */
     r->lo = (r->hi >> (sc - 32)) & LMASK;
     r->hi = 0;
@@ -1037,7 +1120,8 @@ void dp_rsh_s (UDP *r, uint32 sc, uint32 neg)
 {
 dp_rsh (r, sc);                                         /* do unsigned right */
 if (neg && sc) {                                        /* negative? */
-    if (sc > 63) r->hi = r->lo = LMASK;                 /* > 63? result -1 */
+    if (sc > 63)                                        /* > 63? result -1 */
+        r->hi = r->lo = LMASK;
     else {
         UDP ones = { LMASK, LMASK };
         dp_lsh (&ones, 64 - sc);                        /* shift ones */
@@ -1066,9 +1150,11 @@ rmid2 = al * bh;
 rlo = al * bl;
 rhi = rhi + ((rmid1 >> 16) & WMASK) + ((rmid2 >> 16) & WMASK);
 rmid1 = (rlo + (rmid1 << 16)) & LMASK;                  /* add mid1 to lo */
-if (rmid1 < rlo) rhi = rhi + 1;                         /* carry? incr hi */
+if (rmid1 < rlo)                                        /* carry? incr hi */
+    rhi = rhi + 1;
 rmid2 = (rmid1 + (rmid2 << 16)) & LMASK;                /* add mid2 to to */
-if (rmid2 < rmid1) rhi = rhi + 1;                       /* carry? incr hi */
+if (rmid2 < rmid1)                                      /* carry? incr hi */
+    rhi = rhi + 1;
 r->hi = rhi & LMASK;                                    /* mask result */
 r->lo = rmid2;
 return;
@@ -1088,7 +1174,8 @@ void unpackf (uint32 hi, UFP *r)
 r->sign = hi & FPSIGN;                                  /* get sign */
 r->exp = FD_GETEXP (hi);                                /* get exponent */
 if (r->exp == 0) {                                      /* exp = 0? */
-    if (r->sign) RSVD_OPND_FAULT;                       /* if -, rsvd op */
+    if (r->sign)                                        /* if -, rsvd op */
+        RSVD_OPND_FAULT;
     r->frac.hi = r->frac.lo = 0;                        /* else 0 */
     return;
     }
@@ -1103,7 +1190,8 @@ void unpackd (uint32 hi, uint32 lo, UFP *r)
 r->sign = hi & FPSIGN;                                  /* get sign */
 r->exp = FD_GETEXP (hi);                                /* get exponent */
 if (r->exp == 0) {                                      /* exp = 0? */
-    if (r->sign) RSVD_OPND_FAULT;                       /* if -, rsvd op */
+    if (r->sign)                                        /* if -, rsvd op */
+        RSVD_OPND_FAULT;
     r->frac.hi = r->frac.lo = 0;                        /* else 0 */
     return;
       }
@@ -1118,7 +1206,8 @@ void unpackg (uint32 hi, uint32 lo, UFP *r)
 r->sign = hi & FPSIGN;                                  /* get sign */
 r->exp = G_GETEXP (hi);                                 /* get exponent */
 if (r->exp == 0) {                                      /* exp = 0? */
-    if (r->sign) RSVD_OPND_FAULT;                       /* if -, rsvd op */
+    if (r->sign)                                        /* if -, rsvd op */
+        RSVD_OPND_FAULT;
     r->frac.hi = r->frac.lo = 0;                        /* else 0 */
     return;
     }
@@ -1142,7 +1231,8 @@ if ((r->frac.hi == 0) && (r->frac.lo == 0)) {           /* if fraction = 0 */
     }
 while ((r->frac.hi & UF_NM_H) == 0) {                   /* normalized? */
     for (i = 0; i < 5; i++) {                           /* find first 1 */
-        if (r->frac.hi & normmask[i]) break;
+        if (r->frac.hi & normmask[i])
+            break;
         }
     dp_lsh (&r->frac, normtab[i]);                      /* shift frac */
     r->exp = r->exp - normtab[i];                       /* decr exp */
@@ -1155,21 +1245,27 @@ int32 rpackfd (UFP *r, int32 *rh)
 static UDP f_round = { UF_FRND_L, UF_FRND_H };
 static UDP d_round = { UF_DRND_L, UF_DRND_H };
 
-if (rh) *rh = 0;                                        /* assume 0 */
-if ((r->frac.hi == 0) && (r->frac.lo == 0)) return 0;   /* result 0? */
-if (rh) dp_add (&r->frac, &d_round);                    /* round */
+if (rh)                                                 /* assume 0 */
+    *rh = 0;
+if ((r->frac.hi == 0) && (r->frac.lo == 0))             /* result 0? */
+    return 0;
+if (rh)                                                 /* round */
+    dp_add (&r->frac, &d_round);
 else dp_add (&r->frac, &f_round);
 if ((r->frac.hi & UF_NM_H) == 0) {                      /* carry out? */
     dp_rsh (&r->frac, 1);                               /* renormalize */
     r->exp = r->exp + 1;
     }
-if (r->exp > (int32) FD_M_EXP) FLT_OVFL_FAULT;          /* ovflo? fault */
+if (r->exp > (int32) FD_M_EXP)                          /* ovflo? fault */
+    FLT_OVFL_FAULT;
 if (r->exp <= 0) {                                      /* underflow? */
-    if (PSL & PSW_FU) FLT_UNFL_FAULT;                   /* fault if fu */
+    if (PSL & PSW_FU)                                   /* fault if fu */
+        FLT_UNFL_FAULT;
     return 0;                                           /* else 0 */
     }
 dp_rsh (&r->frac, FD_GUARD);                            /* remove guard */
-if (rh) *rh = WORDSWAP (r->frac.lo);                    /* get low */
+if (rh)                                                 /* get low */
+    *rh = WORDSWAP (r->frac.lo);
 return r->sign | (r->exp << FD_V_EXP) |
     (WORDSWAP (r->frac.hi) & ~(FD_HB | FPSIGN | FD_EXP));
 }
@@ -1179,15 +1275,18 @@ int32 rpackg (UFP *r, int32 *rh)
 static UDP g_round = { UF_GRND_L, UF_GRND_H };
 
 *rh = 0;                                                /* assume 0 */
-if ((r->frac.hi == 0) && (r->frac.lo == 0)) return 0;   /* result 0? */
+if ((r->frac.hi == 0) && (r->frac.lo == 0))             /* result 0? */
+    return 0;
 dp_add (&r->frac, &g_round);                            /* round */
 if ((r->frac.hi & UF_NM_H) == 0) {                      /* carry out? */
     dp_rsh (&r->frac, 1);                               /* renormalize */
     r->exp = r->exp + 1;
     }
-if (r->exp > (int32) G_M_EXP) FLT_OVFL_FAULT;           /* ovflo? fault */
+if (r->exp > (int32) G_M_EXP)                           /* ovflo? fault */
+FLT_OVFL_FAULT;
 if (r->exp <= 0) {                                      /* underflow? */
-    if (PSL & PSW_FU) FLT_UNFL_FAULT;                   /* fault if fu */
+    if (PSL & PSW_FU)                                   /* fault if fu */
+        FLT_UNFL_FAULT;
     return 0;                                           /* else 0 */
     }
 dp_rsh (&r->frac, G_GUARD);                             /* remove guard */
@@ -1208,29 +1307,37 @@ return r->sign | (r->exp << G_V_EXP) |
 
 int32 op_movfd (int32 val)
 {
-if (val & FD_EXP) return val;
-if (val & FPSIGN) RSVD_OPND_FAULT;
+if (val & FD_EXP)
+    return val;
+if (val & FPSIGN)
+    RSVD_OPND_FAULT;
 return 0;
 }
 
 int32 op_mnegfd (int32 val)
 {
-if (val & FD_EXP) return (val ^ FPSIGN);
-if (val & FPSIGN) RSVD_OPND_FAULT;
+if (val & FD_EXP)
+    return (val ^ FPSIGN);
+if (val & FPSIGN)
+    RSVD_OPND_FAULT;
 return 0;
 }
 
 int32 op_movg (int32 val)
 {
-if (val & G_EXP) return val;
-if (val & FPSIGN) RSVD_OPND_FAULT;
+if (val & G_EXP)
+    return val;
+if (val & FPSIGN)
+    RSVD_OPND_FAULT;
 return 0;
 }
 
 int32 op_mnegg (int32 val)
 {
-if (val & G_EXP) return (val ^ FPSIGN);
-if (val & FPSIGN) RSVD_OPND_FAULT;
+if (val & G_EXP)
+    return (val ^ FPSIGN);
+if (val & FPSIGN)
+    RSVD_OPND_FAULT;
 return 0;
 }
 
@@ -1270,7 +1377,8 @@ UFP a, b;
 
 unpackf (opnd[0], &a);                                  /* F format */
 unpackf (opnd[1], &b);
-if (sub) a.sign = a.sign ^ FPSIGN;                      /* sub? -s1 */
+if (sub)                                                /* sub? -s1 */
+    a.sign = a.sign ^ FPSIGN;
 vax_fadd (&a, &b);                                      /* add fractions */
 return rpackfd (&a, NULL);
 }
@@ -1281,7 +1389,8 @@ UFP a, b;
 
 unpackd (opnd[0], opnd[1], &a);
 unpackd (opnd[2], opnd[3], &b);
-if (sub) a.sign = a.sign ^ FPSIGN;                      /* sub? -s1 */
+if (sub)                                                /* sub? -s1 */
+    a.sign = a.sign ^ FPSIGN;
 vax_fadd (&a, &b);                                      /* add fractions */
 return rpackfd (&a, rh);
 }
@@ -1292,7 +1401,8 @@ UFP a, b;
 
 unpackg (opnd[0], opnd[1], &a);
 unpackg (opnd[2], opnd[3], &b);
-if (sub) a.sign = a.sign ^ FPSIGN;                      /* sub? -s1 */
+if (sub)                                                /* sub? -s1 */
+    a.sign = a.sign ^ FPSIGN;
 vax_fadd (&a, &b);                                   /* add fractions */
 return rpackg (&a, rh);                                 /* round and pack */
 }
@@ -1376,7 +1486,8 @@ int32 deg = opnd[1];
 int32 ptr = opnd[2];
 int32 i, wd, res;
 
-if (deg > 31) RSVD_OPND_FAULT;                          /* degree > 31? fault */
+if (deg > 31)                                           /* degree > 31? fault */
+    RSVD_OPND_FAULT;
 unpackf (opnd[0], &a);                                  /* unpack arg */
 wd = Read (ptr, L_LONG, RD);                            /* get C0 */
 ptr = ptr + 4;
@@ -1404,7 +1515,8 @@ int32 deg = opnd[2];
 int32 ptr = opnd[3];
 int32 i, wd, wd1, res, resh;
 
-if (deg > 31) RSVD_OPND_FAULT;                          /* degree > 31? fault */
+if (deg > 31)                                           /* degree > 31? fault */
+    RSVD_OPND_FAULT;
 unpackd (opnd[0], opnd[1], &a);                         /* unpack arg */
 wd = Read (ptr, L_LONG, RD);                            /* get C0 */
 wd1 = Read (ptr + 4, L_LONG, RD);
@@ -1437,7 +1549,8 @@ int32 deg = opnd[2];
 int32 ptr = opnd[3];
 int32 i, wd, wd1, res, resh;
 
-if (deg > 31) RSVD_OPND_FAULT;                          /* degree > 31? fault */
+if (deg > 31)                                           /* degree > 31? fault */
+    RSVD_OPND_FAULT;
 unpackg (opnd[0], opnd[1], &a);                         /* unpack arg */
 wd = Read (ptr, L_LONG, RD);                            /* get C0 */
 wd1 = Read (ptr + 4, L_LONG, RD);
