@@ -1,6 +1,6 @@
 /* vax_mmu.c - VAX memory management
 
-   Copyright (c) 1998-2005, Robert M Supnik
+   Copyright (c) 1998-2008, Robert M Supnik
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -23,6 +23,9 @@
    used in advertising or otherwise to promote the sale, use or other dealings
    in this Software without prior written authorization from Robert M Supnik.
 
+   21-Jul-08    RMS     Removed inlining support
+   28-May-08    RMS     Inlined physical memory routines
+   29-Apr-07    RMS     Added address masking for system page table reads
    22-Sep-05    RMS     Fixed declarations (from Sterling Garwood)
    30-Sep-04    RMS     Comment and formating changes
    19-Sep-03    RMS     Fixed upper/lower case linkage problems on VMS
@@ -100,14 +103,6 @@ t_stat tlb_dep (t_value val, t_addr addr, UNIT *uptr, int32 sw);
 t_stat tlb_reset (DEVICE *dptr);
 
 TLBENT fill (uint32 va, int32 lnt, int32 acc, int32 *stat);
-int32 ReadB (uint32 pa);
-void WriteB (uint32 pa, int32 val);
-int32 ReadW (uint32 pa);
-void WriteW (uint32 pa, int32 val);
-int32 ReadL (uint32 pa);
-void WriteL (uint32 pa, int32 val);
-int32 ReadLP (uint32 pa);
-void WriteLP (uint32 pa, int32 val);
 extern int32 ReadIO (uint32 pa, int32 lnt);
 extern void WriteIO (uint32 pa, int32 val, int32 lnt);
 extern int32 ReadReg (uint32 pa, int32 lnt);
@@ -184,8 +179,10 @@ if (mapen) {                                            /* mapping on? */
     }
 else pa = va & PAMASK;
 if ((pa & (lnt - 1)) == 0) {                            /* aligned? */
-    if (lnt >= L_LONG) return ReadL (pa);               /* long, quad? */
-    if (lnt == L_WORD) return ReadW (pa);               /* word? */
+    if (lnt >= L_LONG)                                  /* long, quad? */
+        return ReadL (pa);
+    if (lnt == L_WORD)                                  /* word? */
+        return ReadW (pa);
     return ReadB (pa);                                  /* byte */
     }
 if (mapen && ((off + lnt) > VA_PAGSIZE)) {              /* cross page? */
@@ -205,7 +202,8 @@ if (lnt >= L_LONG) {                                    /* lw unaligned? */
     wh = ReadL (pa1);                                   /* extract */
     return ((((wl >> sc) & align[bo]) | (wh << (32 - sc))) & LMASK);
     }
-else if (bo == 1) return ((ReadL (pa) >> 8) & WMASK);
+else if (bo == 1)
+    return ((ReadL (pa) >> 8) & WMASK);
 else {
     wl = ReadL (pa);                                    /* word cross lw */
     wh = ReadL (pa1);                                   /* read, extract */
@@ -243,8 +241,10 @@ if (mapen) {
     }
 else pa = va & PAMASK;
 if ((pa & (lnt - 1)) == 0) {                            /* aligned? */
-    if (lnt >= L_LONG) WriteL (pa, val);                /* long, quad? */
-    else if (lnt == L_WORD) WriteW (pa, val);           /* word? */
+    if (lnt >= L_LONG)                                  /* long, quad? */
+        WriteL (pa, val);
+    else if (lnt == L_WORD)                             /* word? */
+        WriteW (pa, val);
     else WriteB (pa, val);                              /* byte */
     return;
     }
@@ -298,7 +298,8 @@ if (mapen) {                                            /* mapping on? */
     if ((xpte.pte & acc) && (xpte.tag == vpn))          /* TB hit, acc ok? */ 
         return (xpte.pte & TLB_PFN) | off;
     xpte = fill (va, L_BYTE, acc, status);              /* fill TB */
-    if (*status == PR_OK) return (xpte.pte & TLB_PFN) | off;
+    if (*status == PR_OK)
+        return (xpte.pte & TLB_PFN) | off;
     else return -1;
     }
 return va & PAMASK;                                     /* ret phys addr */
@@ -312,46 +313,53 @@ return va & PAMASK;                                     /* ret phys addr */
         returned data, right justified in 32b longword
 */
 
-int32 ReadB (uint32 pa)
+SIM_INLINE int32 ReadB (uint32 pa)
 {
 int32 dat;
 
-if (ADDR_IS_MEM (pa)) dat = M[pa >> 2];
+if (ADDR_IS_MEM (pa))
+    dat = M[pa >> 2];
 else {
     mchk_ref = REF_V;
-    if (ADDR_IS_IO (pa)) dat = ReadIO (pa, L_BYTE);
+    if (ADDR_IS_IO (pa))
+        dat = ReadIO (pa, L_BYTE);
     else dat = ReadReg (pa, L_BYTE);
     }
 return ((dat >> ((pa & 3) << 3)) & BMASK);
 }
 
-int32 ReadW (uint32 pa)
+SIM_INLINE int32 ReadW (uint32 pa)
 {
 int32 dat;
 
-if (ADDR_IS_MEM (pa)) dat = M[pa >> 2];
+if (ADDR_IS_MEM (pa))
+    dat = M[pa >> 2];
 else {
     mchk_ref = REF_V;
-    if (ADDR_IS_IO (pa)) dat = ReadIO (pa, L_WORD);
+    if (ADDR_IS_IO (pa))
+        dat = ReadIO (pa, L_WORD);
     else dat = ReadReg (pa, L_WORD);
     }
 return ((dat >> ((pa & 2)? 16: 0)) & WMASK);
 }
 
-int32 ReadL (uint32 pa)
+SIM_INLINE int32 ReadL (uint32 pa)
 {
-if (ADDR_IS_MEM (pa)) return M[pa >> 2];
+if (ADDR_IS_MEM (pa))
+    return M[pa >> 2];
 mchk_ref = REF_V;
 if (ADDR_IS_IO (pa)) return ReadIO (pa, L_LONG);
 return ReadReg (pa, L_LONG);
 }
 
-int32 ReadLP (uint32 pa)
+SIM_INLINE int32 ReadLP (uint32 pa)
 {
-if (ADDR_IS_MEM (pa)) return M[pa >> 2];
+if (ADDR_IS_MEM (pa))
+    return M[pa >> 2];
 mchk_va = pa;
 mchk_ref = REF_P;
-if (ADDR_IS_IO (pa)) return ReadIO (pa, L_LONG);
+if (ADDR_IS_IO (pa))
+    return ReadIO (pa, L_LONG);
 return ReadReg (pa, L_LONG);
 }
 
@@ -364,7 +372,7 @@ return ReadReg (pa, L_LONG);
         none
 */
 
-void WriteB (uint32 pa, int32 val)
+SIM_INLINE void WriteB (uint32 pa, int32 val)
 {
 if (ADDR_IS_MEM (pa)) {
     int32 id = pa >> 2;
@@ -374,13 +382,14 @@ if (ADDR_IS_MEM (pa)) {
     }
 else {
     mchk_ref = REF_V;
-    if (ADDR_IS_IO (pa)) WriteIO (pa, val, L_BYTE);
+    if (ADDR_IS_IO (pa))
+        WriteIO (pa, val, L_BYTE);
     else WriteReg (pa, val, L_BYTE);
     }
 return;
 }
 
-void WriteW (uint32 pa, int32 val)
+SIM_INLINE void WriteW (uint32 pa, int32 val)
 {
 if (ADDR_IS_MEM (pa)) {
     int32 id = pa >> 2;
@@ -389,18 +398,21 @@ if (ADDR_IS_MEM (pa)) {
     }
 else {
     mchk_ref = REF_V;
-    if (ADDR_IS_IO (pa)) WriteIO (pa, val, L_WORD);
+    if (ADDR_IS_IO (pa))
+        WriteIO (pa, val, L_WORD);
     else WriteReg (pa, val, L_WORD);
     }
 return;
 }
 
-void WriteL (uint32 pa, int32 val)
+SIM_INLINE void WriteL (uint32 pa, int32 val)
 {
-if (ADDR_IS_MEM (pa)) M[pa >> 2] = val;
+if (ADDR_IS_MEM (pa))
+    M[pa >> 2] = val;
 else {
     mchk_ref = REF_V;
-    if (ADDR_IS_IO (pa)) WriteIO (pa, val, L_LONG);
+    if (ADDR_IS_IO (pa))
+        WriteIO (pa, val, L_LONG);
     else WriteReg (pa, val, L_LONG);
     }
 return;
@@ -408,11 +420,13 @@ return;
 
 void WriteLP (uint32 pa, int32 val)
 {
-if (ADDR_IS_MEM (pa)) M[pa >> 2] = val;
+if (ADDR_IS_MEM (pa))
+    M[pa >> 2] = val;
 else {
     mchk_va = pa;
     mchk_ref = REF_P;
-    if (ADDR_IS_IO (pa)) WriteIO (pa, val, L_LONG);
+    if (ADDR_IS_IO (pa))
+        WriteIO (pa, val, L_LONG);
     else WriteReg (pa, val, L_LONG);
     }
 return;
@@ -430,7 +444,10 @@ return;
 */
 
 #define MM_ERR(param) { \
-    if (stat) { *stat = param; return zero_pte; } \
+    if (stat) { \
+        *stat = param; \
+        return zero_pte; \
+        } \
     p1 = MM_PARAM (acc & TLB_WACC, param); \
     p2 = va; \
     ABORT ((param & PR_TNV)? ABORT_TNV: ABORT_ACV); }
@@ -444,15 +461,17 @@ static TLBENT zero_pte = { 0, 0 };
 if (va & VA_S0) {                                       /* system space? */
     if (ptidx >= d_slr)                                 /* system */
         MM_ERR (PR_LNV);
-    ptead = d_sbr + ptidx;
+    ptead = (d_sbr + ptidx) & PAMASK;
     }
 else {
     if (va & VA_P1) {                                   /* P1? */
-        if (ptidx < d_p1lr) MM_ERR (PR_LNV);
+        if (ptidx < d_p1lr)
+            MM_ERR (PR_LNV);
         ptead = d_p1br + ptidx;
         }
     else {                                              /* P0 */
-        if (ptidx >= d_p0lr) MM_ERR (PR_LNV);
+        if (ptidx >= d_p0lr)
+            MM_ERR (PR_LNV);
         ptead = d_p0br + ptidx;
         }
     if ((ptead & VA_S0) == 0)
@@ -463,11 +482,13 @@ else {
         ptidx = ((uint32) ptead) >> 7;                  /* xlate like sys */
         if (ptidx >= d_slr)
             MM_ERR (PR_PLNV);
-        pte = ReadLP (d_sbr + ptidx);                   /* get system pte */
+        pte = ReadLP ((d_sbr + ptidx) & PAMASK);        /* get system pte */
 #if defined (VAX_780)
-        if ((pte & PTE_ACC) == 0) MM_ERR (PR_PACV);     /* spte ACV? */
+        if ((pte & PTE_ACC) == 0)                       /* spte ACV? */
+            MM_ERR (PR_PACV);
 #endif
-        if ((pte & PTE_V) == 0) MM_ERR (PR_PTNV);       /* spte TNV? */
+        if ((pte & PTE_V) == 0)                         /* spte TNV? */
+            MM_ERR (PR_PTNV);
         stlb[tbi].tag = vpn;                            /* set stlb tag */
         stlb[tbi].pte = cvtacc[PTE_GETACC (pte)] |
             ((pte << VA_N_OFF) & TLB_PFN);              /* set stlb data */
@@ -477,10 +498,13 @@ else {
 pte = ReadL (ptead);                                    /* read pte */
 tlbpte = cvtacc[PTE_GETACC (pte)] |                     /* cvt access */
     ((pte << VA_N_OFF) & TLB_PFN);                      /* set addr */
-if ((tlbpte & acc) == 0) MM_ERR (PR_ACV);               /* chk access */
-if ((pte & PTE_V) == 0) MM_ERR (PR_TNV);                /* check valid */
+if ((tlbpte & acc) == 0)                                /* chk access */
+    MM_ERR (PR_ACV);
+if ((pte & PTE_V) == 0)                                 /* check valid */
+    MM_ERR (PR_TNV);
 if (acc & TLB_WACC) {                                   /* write? */
-    if ((pte & PTE_M) == 0) WriteL (ptead, pte | PTE_M);
+    if ((pte & PTE_M) == 0)
+        WriteL (ptead, pte | PTE_M);
     tlbpte = tlbpte | TLB_M;                            /* set M */
     }
 vpn = VA_GETVPN (va);
@@ -516,7 +540,8 @@ int32 i;
 
 for (i = 0; i < VA_TBSIZE; i++) {
     ptlb[i].tag = ptlb[i].pte = -1;
-    if (stb) stlb[i].tag = stlb[i].pte = -1;
+    if (stb)
+        stlb[i].tag = stlb[i].pte = -1;
     }
 return;
 }
@@ -527,7 +552,8 @@ void zap_tb_ent (uint32 va)
 {
 int32 tbi = VA_GETTBI (VA_GETVPN (va));
 
-if (va & VA_S0) stlb[tbi].tag = stlb[tbi].pte = -1;
+if (va & VA_S0)
+    stlb[tbi].tag = stlb[tbi].pte = -1;
 else ptlb[tbi].tag = ptlb[tbi].pte = -1;
 return;
 }
@@ -541,7 +567,8 @@ int32 tbi = VA_GETTBI (vpn);
 TLBENT xpte;
 
 xpte = (va & VA_S0)? stlb[tbi]: ptlb[tbi];
-if (xpte.tag == vpn) return TRUE;
+if (xpte.tag == vpn)
+    return TRUE;
 return FALSE;
 }
 
@@ -552,8 +579,10 @@ t_stat tlb_ex (t_value *vptr, t_addr addr, UNIT *uptr, int32 sw)
 int32 tlbn = uptr - tlb_unit;
 int32 idx = (uint32) addr >> 1;
 
-if (idx >= VA_TBSIZE) return SCPE_NXM;
-if (addr & 1) *vptr = ((uint32) (tlbn? stlb[idx].pte: ptlb[idx].pte));
+if (idx >= VA_TBSIZE)
+    return SCPE_NXM;
+if (addr & 1)
+    *vptr = ((uint32) (tlbn? stlb[idx].pte: ptlb[idx].pte));
 else *vptr = ((uint32) (tlbn? stlb[idx].tag: ptlb[idx].tag));
 return SCPE_OK;
 }
@@ -565,7 +594,8 @@ t_stat tlb_dep (t_value val, t_addr addr, UNIT *uptr, int32 sw)
 int32 tlbn = uptr - tlb_unit;
 int32 idx = (uint32) addr >> 1;
 
-if (idx >= VA_TBSIZE) return SCPE_NXM;
+if (idx >= VA_TBSIZE)
+    return SCPE_NXM;
 if (addr & 1) {
     if (tlbn) stlb[idx].pte = (int32) val;
     else ptlb[idx].pte = (int32) val;
