@@ -1,6 +1,6 @@
 /* vax_syscm.c: PDP-11 compatibility mode symbolic decode and parse
 
-   Copyright (c) 1993-2005, Robert M Supnik
+   Copyright (c) 1993-2008, Robert M Supnik
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -23,7 +23,8 @@
    used in advertising or otherwise to promote the sale, use or other dealings
    in this Software without prior written authorization from Robert M Supnik.
 
-   27-Sep-05	RMS	Fixed warnings compiling with 64b addresses
+   12-Nov-06    RMS     Fixed operand order in EIS instructions (found by W.F.J. Mueller)
+   27-Sep-05	RMS     Fixed warnings compiling with 64b addresses
    15-Sep-04    RMS     Cloned from pdp11_sys.c
 */
 
@@ -49,6 +50,7 @@ extern UNIT cpu_unit;
 #define I_V_DOP         9                               /* double operand */
 #define I_V_CCC         10                              /* CC clear */
 #define I_V_CCS         11                              /* CC set */
+#define I_V_SOPR        12                              /* operand, reg */
 #define I_NPN           (I_V_NPN << I_V_CL)
 #define I_REG           (I_V_REG << I_V_CL)
 #define I_SOP           (I_V_SOP << I_V_CL)
@@ -61,11 +63,13 @@ extern UNIT cpu_unit;
 #define I_DOP           (I_V_DOP << I_V_CL)
 #define I_CCC           (I_V_CCC << I_V_CL)
 #define I_CCS           (I_V_CCS << I_V_CL)
+#define I_SOPR          (I_V_SOPR << I_V_CL)
 
 static const int32 masks[] = {
  0177777, 0177770, 0177700, 0177770,
  0177000, 0177400, 0177700, 0177000,
- 0177400, 0170000, 0177777, 0177777
+ 0177400, 0170000, 0177777, 0177777,
+ 0177000
  };
 
 static const char *opcode[] = {
@@ -145,7 +149,7 @@ static const int32 opc_val[] = {
 0007000+I_SOP,                0007200+I_SOP, 0007300+I_SOP,
 0010000+I_DOP, 0020000+I_DOP, 0030000+I_DOP, 0040000+I_DOP,
 0050000+I_DOP, 0060000+I_DOP,
-0070000+I_RSOP, 0071000+I_RSOP, 0072000+I_RSOP, 0073000+I_RSOP,
+0070000+I_SOPR, 0071000+I_SOPR, 0072000+I_SOPR, 0073000+I_SOPR,
 0074000+I_RSOP,
 0075000+I_REG, 0075010+I_REG, 0075020+I_REG, 0075030+I_REG,
 0076020+I_REG,
@@ -216,12 +220,14 @@ switch (mode) {
         break;
 
     case 2:
-        if (reg != 7) fprintf (of, "(%s)+", rname[reg]);
+        if (reg != 7)
+            fprintf (of, "(%s)+", rname[reg]);
         else fprintf (of, "#%-X", nval);
         break;
 
     case 3:
-        if (reg != 7) fprintf (of, "@(%s)+", rname[reg]);
+        if (reg != 7)
+            fprintf (of, "@(%s)+", rname[reg]);
         else fprintf (of, "@#%-X", nval);
         break;
 
@@ -234,12 +240,14 @@ switch (mode) {
         break;
 
     case 6:
-        if (reg != 7) fprintf (of, "%-X(%s)", nval, rname[reg]);
+        if (reg != 7)
+            fprintf (of, "%-X(%s)", nval, rname[reg]);
         else fprintf (of, "%-X", (nval + addr + 4) & 0177777);
         break;
 
     case 7:
-        if (reg != 7) fprintf (of, "@%-X(%s)", nval, rname[reg]);
+        if (reg != 7)
+            fprintf (of, "@%-X(%s)", nval, rname[reg]);
         else fprintf (of, "@%-X", (nval + addr + 4) & 0177777);
         break;
         }                                               /* end case */
@@ -270,12 +278,13 @@ for (i = j = 0; i < 3; i++, j = j + 2)
     val[i] = (int32) (bytes[j] | (bytes[j + 1] << 8));
     
 if (sw & SWMASK ('R')) {                                /* radix 50? */
-    if (val[0] > 0174777) return SCPE_ARG;              /* max value */
+    if (val[0] > 0174777)                               /* max value */
+        return SCPE_ARG;
     c3 = val[0] % 050;
     c2 = (val[0] / 050) % 050;
     c1 = val[0] / (050 * 050);
     fprintf (of, "%c%c%c", r50_to_asc[c1],
-            r50_to_asc[c2], r50_to_asc[c3]);
+             r50_to_asc[c2], r50_to_asc[c3]);
     return -1;
     }
 if (!(sw & SWMASK ('P')) || (addr & 1) || (addr > WMASK))
@@ -335,6 +344,12 @@ for (i = 0; opc_val[i] >= 0; i++) {                     /* loop thru ops */
                 wd1 = fprint_spec (of, addr, dstm, val[1]);
                 break;
 
+            case I_V_SOPR:                              /* sopr */
+                fprintf (of, "%s ", opcode[i]);
+                wd1 = fprint_spec (of, addr, dstm, val[1]);
+                fprintf (of, ",%s", rname[srcr]);
+                break;
+
             case I_V_DOP:                               /* dop */
                 fprintf (of, "%s ", opcode[i]);
                 wd1 = fprint_spec (of, addr, srcm, val[1]);
@@ -372,9 +387,11 @@ int32 get_reg (char *cptr, char mchar)
 {
 int32 i;
 
-if (*(cptr + 2) != mchar) return -1;
+if (*(cptr + 2) != mchar)
+    return -1;
 for (i = 0; i < 8; i++) {
-    if (strncmp (cptr, rname[i], 2) == 0) return i;
+    if (strncmp (cptr, rname[i], 2) == 0)
+        return i;
     }
 return -1;
 }
@@ -415,11 +432,13 @@ if (*cptr == '-') {                                     /* -? */
 errno = 0;
 val = strtoul (cptr, &tptr, 16);
 if (cptr == tptr) {                                     /* no number? */
-    if (*pflag == (A_REL + A_NUM)) return NULL;         /* .+, .-? */
+    if (*pflag == (A_REL + A_NUM))                      /* .+, .-? */
+        return NULL;
     *dptr = 0;
     return cptr;
     }
-if (errno || (*pflag == A_REL)) return NULL;            /* .n? */
+if (errno || (*pflag == A_REL))                         /* .n? */
+    return NULL;
 *dptr = (minus? -val: val) & 0177777;
 *pflag = *pflag | A_NUM;
 return tptr;
@@ -459,10 +478,12 @@ if (strncmp (cptr, "-(", 2) == 0) {                     /* autodecrement? */
     pflag = pflag | A_MIN;
     cptr++;
     }
-else if ((cptr = get_addr (cptr, &disp, &pflag)) == NULL) return 1;
+else if ((cptr = get_addr (cptr, &disp, &pflag)) == NULL)
+    return 1;
 if (*cptr == '(') {                                     /* register index? */
     pflag = pflag | A_PAR;
-    if ((reg = get_reg (cptr + 1, ')')) < 0) return 1;
+    if ((reg = get_reg (cptr + 1, ')')) < 0)
+        return 1;
     cptr = cptr + 4;
     if (*cptr == '+') {                                 /* autoincrement? */
         pflag = pflag | A_PLS;
@@ -473,7 +494,8 @@ else if ((reg = get_reg (cptr, 0)) >= 0) {
     pflag = pflag | A_REG;
     cptr = cptr + 2;
     }
-if (*cptr != 0) return 1;                               /* all done? */
+if (*cptr != 0)                                         /* all done? */
+    return 1;
 
 switch (pflag) {                                        /* case on syntax */
 
@@ -546,14 +568,16 @@ int32 ad32 = (int32) addr;
 t_stat r;
 char *tptr, gbuf[CBUFSIZE];
 
-if (sw & SWMASK ('R')) return SCPE_ARG;                 /* radix 50 */
+if (sw & SWMASK ('R'))                                  /* radix 50 */
+    return SCPE_ARG;
 if (!(sw & SWMASK ('P')) || (ad32 & 1) || (ad32 > WMASK))
     return SCPE_ARG;
 
 cptr = get_glyph (cptr, gbuf, 0);                       /* get opcode */
 n1 = n2 = pflag = 0;
 for (i = 0; (opcode[i] != NULL) && (strcmp (opcode[i], gbuf) != 0) ; i++) ;
-if (opcode[i] == NULL) return SCPE_ARG;
+if (opcode[i] == NULL)
+    return SCPE_ARG;
 val[0] = opc_val[i] & 0177777;                          /* get value */
 j = (opc_val[i] >> I_V_CL) & I_M_CL;                    /* get class */
 
@@ -564,43 +588,51 @@ switch (j) {                                            /* case on class */
 
     case I_V_REG:                                       /* register */
         cptr = get_glyph (cptr, gbuf, 0);               /* get glyph */
-        if ((reg = get_reg (gbuf, 0)) < 0) return SCPE_ARG;
+        if ((reg = get_reg (gbuf, 0)) < 0)
+            return SCPE_ARG;
         val[0] = val[0] | reg;
         break;
 
     case I_V_3B: case I_V_6B: case I_V_8B:              /* xb literal */
         cptr = get_glyph (cptr, gbuf, 0);               /* get literal */
         d = (int32) get_uint (gbuf, 16, (1 << j) - 1, &r);
-        if (r != SCPE_OK) return SCPE_ARG;
+        if (r != SCPE_OK)
+            return SCPE_ARG;
         val[0] = val[0] | d;                            /* put in place */
         break;
 
     case I_V_BR:                                        /* cond br */
         cptr = get_glyph (cptr, gbuf, 0);               /* get address */
         tptr = get_addr (gbuf, &disp, &pflag);          /* parse */
-        if ((tptr == NULL) || (*tptr != 0)) return SCPE_ARG;
+        if ((tptr == NULL) || (*tptr != 0))
+            return SCPE_ARG;
         if ((pflag & A_REL) == 0)
             disp = (disp - ad32) & 0177777;
-        if ((disp & 1) || (disp > 0400) && (disp < 0177402)) return SCPE_ARG;
+        if ((disp & 1) || (disp > 0400) && (disp < 0177402))
+            return SCPE_ARG;
         val[0] = val[0] | (((disp - 2) >> 1) & 0377);
         break;
 
     case I_V_SOB:                                       /* sob */
         cptr = get_glyph (cptr, gbuf, ',');             /* get glyph */
-        if ((reg = get_reg (gbuf, 0)) < 0) return SCPE_ARG;
+        if ((reg = get_reg (gbuf, 0)) < 0)
+            return SCPE_ARG;
         val[0] = val[0] | (reg << 6);
         cptr = get_glyph (cptr, gbuf, 0);               /* get address */
         tptr = get_addr (gbuf, &disp, &pflag);          /* parse */
-        if ((tptr == NULL) || (*tptr != 0)) return SCPE_ARG;
+        if ((tptr == NULL) || (*tptr != 0))
+            return SCPE_ARG;
         if ((pflag & A_REL) == 0)
             disp = (disp - ad32) & 0177777;
-        if ((disp & 1) || ((disp > 2) && (disp < 0177604))) return SCPE_ARG;
+        if ((disp & 1) || ((disp > 2) && (disp < 0177604)))
+            return SCPE_ARG;
         val[0] = val[0] | (((2 - disp) >> 1) & 077);
         break;
 
     case I_V_RSOP:                                      /* reg, sop */
         cptr = get_glyph (cptr, gbuf, ',');             /* get glyph */
-        if ((reg = get_reg (gbuf, 0)) < 0) return SCPE_ARG;
+        if ((reg = get_reg (gbuf, 0)) < 0)
+            return SCPE_ARG;
         val[0] = val[0] | (reg << 6);                   /* fall through */
     case I_V_SOP:                                       /* sop */
         cptr = get_glyph (cptr, gbuf, 0);               /* get glyph */
@@ -609,6 +641,17 @@ switch (j) {                                            /* case on class */
         val[0] = val[0] | spec;
         break;
 
+    case I_V_SOPR:                                      /* dop, reg */
+        cptr = get_glyph (cptr, gbuf, ',');             /* get glyph */
+        if ((n1 = get_spec (gbuf, ad32, 0, &spec, &val[1])) > 0)
+            return SCPE_ARG;
+        val[0] = val[0] | spec;
+        cptr = get_glyph (cptr, gbuf, 0);               /* get glyph */
+        if ((reg = get_reg (gbuf, 0)) < 0)
+            return SCPE_ARG;
+        val[0] = val[0] | (reg << 6);
+        break;
+
     case I_V_DOP:                                       /* double op */
         cptr = get_glyph (cptr, gbuf, ',');             /* get glyph */
         if ((n1 = get_spec (gbuf, ad32, 0, &spec, &val[1])) > 0)
@@ -626,8 +669,9 @@ switch (j) {                                            /* case on class */
             for (i = 0; (opcode[i] != NULL) &&
                 (strcmp (opcode[i], gbuf) != 0) ; i++) ;
             if ((((opc_val[i] >> I_V_CL) & I_M_CL) != j) ||
-                (opcode[i] == NULL)) return SCPE_ARG;
-                val[0] = val[0] | (opc_val[i] & 0177777);
+                (opcode[i] == NULL))
+                return SCPE_ARG;
+            val[0] = val[0] | (opc_val[i] & 0177777);
             }
         break;
 
