@@ -1,6 +1,6 @@
 /* vaxmod_defs.h: VAX model-specific definitions file
 
-   Copyright (c) 1998-2006, Robert M Supnik
+   Copyright (c) 1998-2007, Robert M Supnik
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -23,6 +23,7 @@
    used in advertising or otherwise to promote the sale, use or other dealings
    in this Software without prior written authorization from Robert M Supnik.
 
+   29-Apr-07    RMS     Separated checks for PxBR and SBR
    17-May-06    RMS     Added CR11/CD11 support
    10-May-06    RMS     Added NOP'd reserved operand checking macros
    05-Oct-05    RMS     Added XU definitions for autoconfigure
@@ -204,7 +205,8 @@
 
 #define ML_PA_TEST(r)
 #define ML_LR_TEST(r)
-#define ML_BR_TEST(r)
+#define ML_SBR_TEST(r)
+#define ML_PXBR_TEST(r)
 #define LP_AST_TEST(r)
 #define LP_MBZ84_TEST(r)
 #define LP_MBZ92_TEST(r)
@@ -237,6 +239,8 @@
 #define DZ_MUXES        4                               /* max # of DZV muxes */
 #define DZ_LINES        4                               /* lines per DZV mux */
 #define VH_MUXES        4                               /* max # of DHQ muxes */
+#define DLX_LINES       16                              /* max # of KL11/DL11's */
+#define DCX_LINES       16                              /* max # of DC11's */
 #define MT_MAXFR        (1 << 16)                       /* magtape max rec */
 #define AUTO_LNT        34                              /* autoconfig ranks */
 
@@ -439,6 +443,22 @@ typedef struct {
 #define LOG_CPU_R       0x2                             /* REI */
 #define LOG_CPU_P       0x4                             /* context */
 
+/* Function prototypes for virtual memory interface */
+
+int32 Read (uint32 va, int32 lnt, int32 acc);
+void Write (uint32 va, int32 val, int32 lnt, int32 acc);
+
+/* Function prototypes for physical memory interface (inlined) */
+
+SIM_INLINE int32 ReadB (uint32 pa);
+SIM_INLINE int32 ReadW (uint32 pa);
+SIM_INLINE int32 ReadL (uint32 pa);
+SIM_INLINE int32 ReadLP (uint32 pa);
+SIM_INLINE void WriteB (uint32 pa, int32 val);
+SIM_INLINE void WriteW (uint32 pa, int32 val);
+SIM_INLINE void WriteL (uint32 pa, int32 val);
+void WriteLP (uint32 pa, int32 val);
+
 /* Function prototypes for I/O */
 
 int32 Map_ReadB (uint32 ba, int32 bc, uint8 *buf);
@@ -446,13 +466,8 @@ int32 Map_ReadW (uint32 ba, int32 bc, uint16 *buf);
 int32 Map_WriteB (uint32 ba, int32 bc, uint8 *buf);
 int32 Map_WriteW (uint32 ba, int32 bc, uint16 *buf);
 
-t_stat set_addr (UNIT *uptr, int32 val, char *cptr, void *desc);
-t_stat show_addr (FILE *st, UNIT *uptr, int32 val, void *desc);
-t_stat set_addr_flt (UNIT *uptr, int32 val, char *cptr, void *desc);
-t_stat set_vec (UNIT *uptr, int32 val, char *cptr, void *desc);
-t_stat show_vec (FILE *st, UNIT *uptr, int32 val, void *desc);
-t_stat auto_config (char *name, int32 num);
-
 int32 clk_cosched (int32 wait);
 
+#include "pdp11_io_lib.h"
+
 #endif
