@@ -1,6 +1,6 @@
 /* sim_defs.h: simulator definitions
 
-   Copyright (c) 1993-2006, Robert M Supnik
+   Copyright (c) 1993-2008, Robert M Supnik
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -23,6 +23,13 @@
    used in advertising or otherwise to promote the sale, use or other dealings
    in this Software without prior written authorization from Robert M Supnik.
 
+   21-Jul-08    RMS     Removed inlining support
+   28-May-08    RMS     Added inlining support
+   28-Jun-07    RMS     Added IA64 VMS support (from Norm Lastovica)
+   18-Jun-07    RMS     Added UNIT_IDLE flag
+   18-Mar-07    RMS     Added UNIT_TEXT flag
+   07-Mar-07    JDB     Added DEBUG_PRJ macro
+   18-Oct-06    RMS     Added limit check for clock synchronized keyboard waits
    13-Jul-06    RMS     Guarantee CBUFSIZE is at least 256
    07-Jan-06    RMS     Added support for breakpoint spaces
                         Added REG_FIT flag
@@ -128,7 +135,7 @@ typedef unsigned long long      t_uint64;
 #elif defined (_WIN32)                                  /* Windows */
 typedef signed __int64          t_int64;
 typedef unsigned __int64        t_uint64;
-#elif defined (__ALPHA) && defined (VMS)                /* Alpha VMS */
+#elif (defined (__ALPHA) || defined (__ia64)) && defined (VMS) /* 64b VMS */
 typedef signed __int64          t_int64;
 typedef unsigned __int64        t_uint64;
 #elif defined (__ALPHA) && defined (__unix__)           /* Alpha UNIX */
@@ -155,6 +162,10 @@ typedef uint32          t_addr;
 #define T_ADDR_W        32
 #endif                                                  /* end 64b address */
 
+/* Stubs for inlining */
+
+#define SIM_INLINE
+
 /* System independent definitions */
 
 #define FLIP_SIZE       (1 << 16)                       /* flip buf size */
@@ -243,9 +254,12 @@ typedef uint32          t_addr;
 /* Default timing parameters */
 
 #define KBD_POLL_WAIT   5000                            /* keyboard poll */
+#define KBD_MAX_WAIT    500000
 #define SERIAL_IN_WAIT  100                             /* serial in time */
 #define SERIAL_OUT_WAIT 100                             /* serial output */
 #define NOQUEUE_WAIT    10000                           /* min check time */
+#define KBD_LIM_WAIT(x) (((x) > KBD_MAX_WAIT)? KBD_MAX_WAIT: (x))
+#define KBD_WAIT(w,s)   ((w)? w: KBD_LIM_WAIT (s))
 
 /* Convert switch letter to bit mask */
 
@@ -359,6 +373,8 @@ struct sim_unit {
 #define UNIT_DISABLE    002000                          /* disable-able */
 #define UNIT_DIS        004000                          /* disabled */
 #define UNIT_RAW        010000                          /* raw mode */
+#define UNIT_TEXT       020000                          /* text mode */
+#define UNIT_IDLE       040000                          /* idle eligible */
 
 #define UNIT_UFMASK_31  (((1u << UNIT_V_RSV) - 1) & ~((1u << UNIT_V_UF_31) - 1))
 #define UNIT_UFMASK     (((1u << UNIT_V_RSV) - 1) & ~((1u << UNIT_V_UF) - 1))
@@ -466,6 +482,7 @@ struct sim_debtab {
 #define DEBUG_PRS(d)    (sim_deb && d.dctrl)
 #define DEBUG_PRD(d)    (sim_deb && d->dctrl)
 #define DEBUG_PRI(d,m)  (sim_deb && (d.dctrl & (m)))
+#define DEBUG_PRJ(d,m)  (sim_deb && (d->dctrl & (m)))
 
 /* The following macros define structure contents */
 
